pub struct Compact<T>(pub T);Expand description
Compact-encoded variant of T. This is more space-efficient but less compute-efficient.
Tuple Fields
0: TTrait Implementations
Sourceimpl CompactLen<u128> for Compact<u128>
impl CompactLen<u128> for Compact<u128>
Sourcefn compact_len(val: &u128) -> usize
fn compact_len(val: &u128) -> usize
Returns the compact encoded length for the given value.
Sourceimpl CompactLen<u16> for Compact<u16>
impl CompactLen<u16> for Compact<u16>
Sourcefn compact_len(val: &u16) -> usize
fn compact_len(val: &u16) -> usize
Returns the compact encoded length for the given value.
Sourceimpl CompactLen<u32> for Compact<u32>
impl CompactLen<u32> for Compact<u32>
Sourcefn compact_len(val: &u32) -> usize
fn compact_len(val: &u32) -> usize
Returns the compact encoded length for the given value.
Sourceimpl CompactLen<u64> for Compact<u64>
impl CompactLen<u64> for Compact<u64>
Sourcefn compact_len(val: &u64) -> usize
fn compact_len(val: &u64) -> usize
Returns the compact encoded length for the given value.
Sourceimpl CompactLen<u8> for Compact<u8>
impl CompactLen<u8> for Compact<u8>
Sourcefn compact_len(val: &u8) -> usize
fn compact_len(val: &u8) -> usize
Returns the compact encoded length for the given value.
Sourceimpl Decode for Compact<()>
impl Decode for Compact<()>
Sourcefn decode<I>(_input: &mut I) -> Result<Compact<()>, Error>where
I: Input,
fn decode<I>(_input: &mut I) -> Result<Compact<()>, Error>where
I: Input,
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl<T> Decode for Compact<T>
impl<T> Decode for Compact<T>
Sourcefn decode<I>(input: &mut I) -> Result<Compact<T>, Error>where
I: Input,
fn decode<I>(input: &mut I) -> Result<Compact<T>, Error>where
I: Input,
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Decode for Compact<u128>
impl Decode for Compact<u128>
Sourcefn decode<I>(input: &mut I) -> Result<Compact<u128>, Error>where
I: Input,
fn decode<I>(input: &mut I) -> Result<Compact<u128>, Error>where
I: Input,
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Decode for Compact<u16>
impl Decode for Compact<u16>
Sourcefn decode<I>(input: &mut I) -> Result<Compact<u16>, Error>where
I: Input,
fn decode<I>(input: &mut I) -> Result<Compact<u16>, Error>where
I: Input,
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Decode for Compact<u32>
impl Decode for Compact<u32>
Sourcefn decode<I>(input: &mut I) -> Result<Compact<u32>, Error>where
I: Input,
fn decode<I>(input: &mut I) -> Result<Compact<u32>, Error>where
I: Input,
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Decode for Compact<u64>
impl Decode for Compact<u64>
Sourcefn decode<I>(input: &mut I) -> Result<Compact<u64>, Error>where
I: Input,
fn decode<I>(input: &mut I) -> Result<Compact<u64>, Error>where
I: Input,
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Decode for Compact<u8>
impl Decode for Compact<u8>
Sourcefn decode<I>(input: &mut I) -> Result<Compact<u8>, Error>where
I: Input,
fn decode<I>(input: &mut I) -> Result<Compact<u8>, Error>where
I: Input,
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl<'de, T> Deserialize<'de> for Compact<T>where
T: Deserialize<'de>,
Available on crate feature serde only.
impl<'de, T> Deserialize<'de> for Compact<T>where
T: Deserialize<'de>,
Available on crate feature
serde only.Sourcefn deserialize<D>(
deserializer: D,
) -> Result<Compact<T>, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<Compact<T>, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<T> Encode for Compact<T>where
CompactRef<'a, T>: for<'a> Encode,
impl<T> Encode for Compact<T>where
CompactRef<'a, T>: for<'a> Encode,
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<W>(&self, dest: &mut W)
fn encode_to<W>(&self, dest: &mut W)
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
Sourceimpl<'a, T> EncodeAsRef<'a, T> for Compact<T>
impl<'a, T> EncodeAsRef<'a, T> for Compact<T>
Sourcetype RefType = CompactRef<'a, T>
type RefType = CompactRef<'a, T>
The reference type that is used for encoding.
Sourceimpl From<Compact<Perquintill>> for Perquintill
impl From<Compact<Perquintill>> for Perquintill
Sourcefn from(x: Compact<Perquintill>) -> Perquintill
fn from(x: Compact<Perquintill>) -> Perquintill
Converts to this type from the input type.
Sourceimpl<T, D> From<Compact<TypeWithDefault<T, D>>> for TypeWithDefault<T, D>where
D: Get<T>,
impl<T, D> From<Compact<TypeWithDefault<T, D>>> for TypeWithDefault<T, D>where
D: Get<T>,
Sourcefn from(c: Compact<TypeWithDefault<T, D>>) -> TypeWithDefault<T, D>
fn from(c: Compact<TypeWithDefault<T, D>>) -> TypeWithDefault<T, D>
Converts to this type from the input type.
Sourceimpl MaxEncodedLen for Compact<()>
impl MaxEncodedLen for Compact<()>
Sourcefn max_encoded_len() -> usize
fn max_encoded_len() -> usize
Upper bound, in bytes, of the maximum encoded size of this item.
Sourceimpl MaxEncodedLen for Compact<u128>
impl MaxEncodedLen for Compact<u128>
Sourcefn max_encoded_len() -> usize
fn max_encoded_len() -> usize
Upper bound, in bytes, of the maximum encoded size of this item.
Sourceimpl MaxEncodedLen for Compact<u16>
impl MaxEncodedLen for Compact<u16>
Sourcefn max_encoded_len() -> usize
fn max_encoded_len() -> usize
Upper bound, in bytes, of the maximum encoded size of this item.
Sourceimpl MaxEncodedLen for Compact<u32>
impl MaxEncodedLen for Compact<u32>
Sourcefn max_encoded_len() -> usize
fn max_encoded_len() -> usize
Upper bound, in bytes, of the maximum encoded size of this item.
Sourceimpl MaxEncodedLen for Compact<u64>
impl MaxEncodedLen for Compact<u64>
Sourcefn max_encoded_len() -> usize
fn max_encoded_len() -> usize
Upper bound, in bytes, of the maximum encoded size of this item.
Sourceimpl MaxEncodedLen for Compact<u8>
impl MaxEncodedLen for Compact<u8>
Sourcefn max_encoded_len() -> usize
fn max_encoded_len() -> usize
Upper bound, in bytes, of the maximum encoded size of this item.
Sourceimpl<T> Ord for Compact<T>where
T: Ord,
impl<T> Ord for Compact<T>where
T: Ord,
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PalletError for Compact<u128>
impl PalletError for Compact<u128>
Sourceconst MAX_ENCODED_SIZE: usize = 17
const MAX_ENCODED_SIZE: usize = 17
The maximum encoded size for the implementing type. Read more
Sourceimpl PalletError for Compact<u16>
impl PalletError for Compact<u16>
Sourceconst MAX_ENCODED_SIZE: usize = 4
const MAX_ENCODED_SIZE: usize = 4
The maximum encoded size for the implementing type. Read more
Sourceimpl PalletError for Compact<u32>
impl PalletError for Compact<u32>
Sourceconst MAX_ENCODED_SIZE: usize = 5
const MAX_ENCODED_SIZE: usize = 5
The maximum encoded size for the implementing type. Read more
Sourceimpl PalletError for Compact<u64>
impl PalletError for Compact<u64>
Sourceconst MAX_ENCODED_SIZE: usize = 9
const MAX_ENCODED_SIZE: usize = 9
The maximum encoded size for the implementing type. Read more
Sourceimpl PalletError for Compact<u8>
impl PalletError for Compact<u8>
Sourceconst MAX_ENCODED_SIZE: usize = 2
const MAX_ENCODED_SIZE: usize = 2
The maximum encoded size for the implementing type. Read more
Sourceimpl<T> PartialOrd for Compact<T>where
T: PartialOrd,
impl<T> PartialOrd for Compact<T>where
T: PartialOrd,
Sourceimpl<T> Serialize for Compact<T>where
T: Serialize,
Available on crate feature serde only.
impl<T> Serialize for Compact<T>where
T: Serialize,
Available on crate feature
serde only.Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl<T> Copy for Compact<T>where
T: Copy,
impl DecodeWithMemTracking for Compact<()>
impl<T> DecodeWithMemTracking for Compact<T>
impl DecodeWithMemTracking for Compact<u128>
impl DecodeWithMemTracking for Compact<u16>
impl DecodeWithMemTracking for Compact<u32>
impl DecodeWithMemTracking for Compact<u64>
impl DecodeWithMemTracking for Compact<u8>
impl<T> EncodeLike for Compact<T>where
CompactRef<'a, T>: for<'a> Encode,
impl<T> Eq for Compact<T>where
T: Eq,
impl<T> StructuralPartialEq for Compact<T>