pub struct CountedInput<'a, I>where
I: Input,{ /* private fields */ }Expand description
A wrapper for Input which tracks the number fo bytes that are successfully read.
If inner Input fails to read, the counter is not incremented.
It can count until u64::MAX - 1 accurately then saturate.
Implementations