pub struct IoReader<R>(pub R)
where
R: Read;Expand description
Wrapper that implements Input for any Read type.
Tuple Fields
0: RTrait Implementations
Sourceimpl<R> Input for IoReader<R>where
R: Read,
Available on crate feature std only.
impl<R> Input for IoReader<R>where
R: Read,
Available on crate feature
std only.Sourcefn remaining_len(&mut self) -> Result<Option<usize>, Error>
fn remaining_len(&mut self) -> Result<Option<usize>, Error>
Should return the remaining length of the input data. If no information about the input
length is available,
None should be returned. Read moreSourcefn read(&mut self, into: &mut [u8]) -> Result<(), Error>
fn read(&mut self, into: &mut [u8]) -> Result<(), Error>
Read the exact number of bytes required to fill the given buffer. Read more
Sourcefn descend_ref(&mut self) -> Result<(), Error>
fn descend_ref(&mut self) -> Result<(), Error>
Descend into nested reference when decoding.
This is called when decoding a new refence-based instance,
such as
Vec or Box. Currently, all such types are
allocated on the heap.Sourcefn ascend_ref(&mut self)
fn ascend_ref(&mut self)
Ascend to previous structure level when decoding.
This is called when decoding reference-based type is finished.