pub struct OptionBool(pub Option<bool>);Expand description
Shim type because we can’t do a specialised implementation for Option<bool> directly.
Tuple Fields
0: Option<bool>Trait Implementations
Sourceimpl Clone for OptionBool
impl Clone for OptionBool
Sourcefn clone(&self) -> OptionBool
fn clone(&self) -> OptionBool
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OptionBool
impl Debug for OptionBool
Sourceimpl Decode for OptionBool
impl Decode for OptionBool
Sourcefn decode<I>(input: &mut I) -> Result<OptionBool, Error>where
I: Input,
fn decode<I>(input: &mut I) -> Result<OptionBool, Error>where
I: Input,
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Encode for OptionBool
impl Encode for OptionBool
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encode_to<T>(&self, dest: &mut T)
fn encode_to<T>(&self, dest: &mut T)
Convert self to a slice and append it to the destination.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
Sourceimpl PartialEq for OptionBool
impl PartialEq for OptionBool
impl Copy for OptionBool
impl DecodeWithMemTracking for OptionBool
impl EncodeLike for OptionBool
impl Eq for OptionBool
impl StructuralPartialEq for OptionBool