pub struct Ref<'a, T, U>(/* private fields */)
where
T: EncodeLike<U>,
U: Encode;Expand description
Reference wrapper that implement encode like any type that is encoded like its inner type.
Example
fn foo<T: EncodeLike<u8>>(t: T) -> T {
store_t(Ref::from(&t)); // Store t without moving it, but only using a reference.
t
}
fn store_t<T: EncodeLike<u8>>(t: T) {
}Trait Implementations
Sourceimpl<'a, T: EncodeLike<U> + TupleToEncodedIter, U: Encode> TupleToEncodedIter for Ref<'a, T, U>
impl<'a, T: EncodeLike<U> + TupleToEncodedIter, U: Encode> TupleToEncodedIter for Ref<'a, T, U>
impl<T, U> EncodeLike<U> for &Ref<'_, T, U>where
T: EncodeLike<U>,
U: Encode,
impl<T, U> EncodeLike<U> for Ref<'_, T, U>where
T: EncodeLike<U>,
U: Encode,
impl<'a, T: EncodeLike<U> + EncodeLikeTuple<U>, U: Encode> EncodeLikeTuple<U> for Ref<'a, T, U>
impl<T, U> WrapperTypeEncode for Ref<'_, T, U>where
T: EncodeLike<U>,
U: Encode,