pub struct CheckedExtrinsic<AccountId, Call, Extension> {
pub format: ExtrinsicFormat<AccountId, Extension>,
pub function: Call,
}Expand description
Definition of something that the external world might want to say; its existence implies that it has been checked and is good, particularly with regards to the signature.
This is typically passed into traits::Applyable::apply, which should execute
CheckedExtrinsic::function, alongside all other bits and bobs.
Fields
format: ExtrinsicFormat<AccountId, Extension>Who this purports to be from and the number of extrinsics have come before from the same signer, if anyone (note this is not a signature).
function: CallThe function that should be called.
Implementations
Sourceimpl<AccountId, Call, Extension> CheckedExtrinsic<AccountId, Call, Extension>where
Call: Dispatchable,
Extension: TransactionExtension<Call>,
impl<AccountId, Call, Extension> CheckedExtrinsic<AccountId, Call, Extension>where
Call: Dispatchable,
Extension: TransactionExtension<Call>,
Sourcepub fn extension_weight(&self) -> Weight
pub fn extension_weight(&self) -> Weight
Returns the weight of the extension of this transaction, if present. If the transaction doesn’t use any extension, the weight returned is equal to zero.