pub struct UncheckedExtrinsic<Address, Call, Signature, Extension, const MAX_CALL_SIZE: usize = subsoil::::runtime::generic::unchecked_extrinsic::UncheckedExtrinsic::{constant#0}> {
pub preamble: Preamble<Address, Signature, Extension>,
pub function: Call,
pub encoded_call: Option<Vec<u8>>,
}Expand description
An extrinsic right from the external world. This is unchecked and so can contain a signature.
An extrinsic is formally described as any external data that is originating from the outside of the runtime and fed into the runtime as a part of the block-body.
Inherents are special types of extrinsics that are placed into the block by the block-builder. They are unsigned because the assertion is that they are “inherently true” by virtue of getting past all validators.
Transactions are all other statements provided by external entities that the chain deems values and decided to include in the block. This value is typically in the form of fee payment, but it could in principle be any other interaction. Transactions are either signed or unsigned. A sensible transaction pool should ensure that only transactions that are worthwhile are considered for block-building.
flowchart TD
E(Extrinsic) ---> I(Inherent);
E --> T(Transaction)
T --> ST("Signed (aka. Transaction)")
T --> UT(Unsigned)
This type is by no means enforced within Substrate, but given its genericness, it is highly likely that for most use-cases it will suffice. Thus, the encoding of this type will dictate exactly what bytes should be sent to a runtime to transact with it.
This can be checked using Checkable, yielding a CheckedExtrinsic, which is the
counterpart of this type after its signature (and other non-negotiable validity checks) have
passed.
Fields
preamble: Preamble<Address, Signature, Extension>Information regarding the type of extrinsic this is (inherent or transaction) as well as
associated extension (Extension) data if it’s a transaction and a possible signature.
function: CallThe function that should be called.
encoded_call: Option<Vec<u8>>Stores the raw encoded call.
This is mainly interesting if this extrinsic was created by decoding it from bytes. In this
case this field should be set to Some holding the original bytes used to decode the
Self::function. This is done to protect against decode implementations of Call that
are not bijective (encodes to the exact same bytes it was encoded from). If this field
is set, it is being used when re-encoding this transaction.
Implementations
Sourceimpl<Address, Call, Signature, Extension, const MAX_CALL_SIZE: usize> UncheckedExtrinsic<Address, Call, Signature, Extension, MAX_CALL_SIZE>
impl<Address, Call, Signature, Extension, const MAX_CALL_SIZE: usize> UncheckedExtrinsic<Address, Call, Signature, Extension, MAX_CALL_SIZE>
Sourcepub fn new_unsigned(
function: Call,
) -> UncheckedExtrinsic<Address, Call, Signature, Extension, MAX_CALL_SIZE>
👎Deprecated: Use new_bare instead
pub fn new_unsigned( function: Call, ) -> UncheckedExtrinsic<Address, Call, Signature, Extension, MAX_CALL_SIZE>
New instance of a bare (ne unsigned) extrinsic. This could be used for an inherent or an old-school “unsigned transaction” (which are new being deprecated in favour of general transactions).
Sourcepub fn is_inherent(&self) -> bool
pub fn is_inherent(&self) -> bool
Returns true if this extrinsic instance is an inherent, `false`` otherwise.
Sourcepub fn is_signed(&self) -> bool
pub fn is_signed(&self) -> bool
Returns true if this extrinsic instance is an old-school signed transaction, false
otherwise.
Sourcepub fn from_parts(
function: Call,
preamble: Preamble<Address, Signature, Extension>,
) -> UncheckedExtrinsic<Address, Call, Signature, Extension, MAX_CALL_SIZE>
pub fn from_parts( function: Call, preamble: Preamble<Address, Signature, Extension>, ) -> UncheckedExtrinsic<Address, Call, Signature, Extension, MAX_CALL_SIZE>
Create an UncheckedExtrinsic from a Preamble and the actual Call.
Sourcepub fn new_bare(
function: Call,
) -> UncheckedExtrinsic<Address, Call, Signature, Extension, MAX_CALL_SIZE>
pub fn new_bare( function: Call, ) -> UncheckedExtrinsic<Address, Call, Signature, Extension, MAX_CALL_SIZE>
New instance of a bare (ne unsigned) extrinsic.
Sourcepub fn new_bare_legacy(
function: Call,
) -> UncheckedExtrinsic<Address, Call, Signature, Extension, MAX_CALL_SIZE>
pub fn new_bare_legacy( function: Call, ) -> UncheckedExtrinsic<Address, Call, Signature, Extension, MAX_CALL_SIZE>
New instance of a bare (ne unsigned) extrinsic on extrinsic format version 4.
Sourcepub fn new_signed(
function: Call,
signed: Address,
signature: Signature,
tx_ext: Extension,
) -> UncheckedExtrinsic<Address, Call, Signature, Extension, MAX_CALL_SIZE>
pub fn new_signed( function: Call, signed: Address, signature: Signature, tx_ext: Extension, ) -> UncheckedExtrinsic<Address, Call, Signature, Extension, MAX_CALL_SIZE>
New instance of an old-school signed transaction on extrinsic format version 4.
Sourcepub fn new_transaction(
function: Call,
tx_ext: Extension,
) -> UncheckedExtrinsic<Address, Call, Signature, Extension, MAX_CALL_SIZE>
pub fn new_transaction( function: Call, tx_ext: Extension, ) -> UncheckedExtrinsic<Address, Call, Signature, Extension, MAX_CALL_SIZE>
New instance of a new-school unsigned transaction.
Sourceimpl<Address, Call, Signature, Extension> UncheckedExtrinsic<Address, Call, Signature, Extension>where
Call: Dispatchable,
Extension: TransactionExtension<Call>,
impl<Address, Call, Signature, Extension> UncheckedExtrinsic<Address, Call, Signature, Extension>where
Call: Dispatchable,
Extension: TransactionExtension<Call>,
Sourcepub fn extension_weight(&self) -> Weight
pub fn extension_weight(&self) -> Weight
Returns the weight of the extension of this transaction, if present. If the transaction doesn’t use any extension, the weight returned is equal to zero.