pub enum PathError {
MissingSegments,
InvalidIdentifier {
segment: usize,
},
}Expand description
An error that may be encountered upon constructing namespaces.
Variants
MissingSegments
If the module path does not at least have one segment.
InvalidIdentifier
If a segment within a module path is not a proper Rust identifier.