Field

Struct Field 

pub struct Field<T = MetaForm>
where T: Form,
{ pub name: Option<<T as Form>::String>, pub ty: <T as Form>::Type, pub type_name: Option<<T as Form>::String>, pub docs: Vec<<T as Form>::String>, }
A field of a struct-like data type.

Name is optional so it can represent both named and unnamed fields.

This can be a named field of a struct type or an enum struct variant, or an unnamed field of a tuple struct.

Type name

The type_name field contains a string which is the name of the type of the field as it appears in the source code. The exact contents and format of the type name are not specified, but in practice will be the name of any valid type for a field e.g.

  • Concrete types e.g "u32", "bool", "Foo" etc.
  • Type parameters e.g "T", "U"
  • Generic types e.g "Vec<u32>", "Vec<T>"
  • Associated types e.g. "T::MyType", "<T as MyTrait>::MyType"
  • Type aliases e.g. "MyTypeAlias", "MyTypeAlias<T>"
  • Other built in Rust types e.g. arrays, references etc.

Note that the type name doesn’t correspond to the underlying type of the field, unless using a concrete type directly. Any given type may be referred to by multiple field type names, when using generic type parameters and type aliases.

This is intended for informational and diagnostic purposes only. Although it is possible to infer certain properties e.g. whether a type name is a type alias, there are no guarantees provided, and the type name representation may change.

Fields

name: Option<<T as Form>::String>

The name of the field. None for unnamed fields.

ty: <T as Form>::Type

The type of the field.

type_name: Option<<T as Form>::String>

The name of the type of the field as it appears in the source code.

docs: Vec<<T as Form>::String>

Documentation

Implementations

Source

impl<T> Field<T>
where T: Form,

pub fn builder() -> FieldBuilder<T>

Returns a new FieldBuilder for constructing a field.

pub fn new( name: Option<<T as Form>::String>, ty: <T as Form>::Type, type_name: Option<<T as Form>::String>, docs: Vec<<T as Form>::String>, ) -> Field<T>

Creates a new field.

Use this constructor if you want to instantiate from a given meta type.

Source

impl<T> Field<T>
where T: Form,

pub fn name(&self) -> Option<&<T as Form>::String>

👎Deprecated since 2.5.0: Prefer to access the fields directly; this getter will be removed in the next major version

Returns the name of the field. None for unnamed fields.

pub fn ty(&self) -> &<T as Form>::Type

👎Deprecated since 2.5.0: Prefer to access the fields directly; this getter will be removed in the next major version

Returns the type of the field.

pub fn type_name(&self) -> Option<&<T as Form>::String>

👎Deprecated since 2.5.0: Prefer to access the fields directly; this getter will be removed in the next major version

Returns a string which is the name of the type of the field as it appears in the source code. The exact contents and format of the type name are not specified, but in practice will be the name of any valid type for a field. This is intended for informational and diagnostic purposes only.

pub fn docs(&self) -> &[<T as Form>::String]

👎Deprecated since 2.5.0: Prefer to access the fields directly; this getter will be removed in the next major version

Returns the documentation of the field.