pub struct Path<T = MetaForm>where
T: Form,{
pub segments: Vec<<T as Form>::String>,
}Expand description
Represents the path of a type definition.
This consists of several segments that each have to be a valid Rust
identifier. The first segment represents the crate name in which the type
has been defined. The last segment is the identifier accessed with ident().
Rust prelude type may have an empty namespace definition.
Fields
segments: Vec<<T as Form>::String>The segments of the namespace.
Implementations
Sourceimpl Path
impl Path
Sourcepub fn new_with_replace(
ident: &'static str,
module_path: &'static str,
segment_replace: &[(&'static str, &'static str)],
) -> Path
pub fn new_with_replace( ident: &'static str, module_path: &'static str, segment_replace: &[(&'static str, &'static str)], ) -> Path
Create a new Path
The segment_replace is a list of (search, replace) items. Every
search item that appears in the module_path is replaced by the
replace item. This can be used for example to replace the crate name
or even the name of the type in the final Path.
Panics
- If the type identifier, module path or replace contain invalid Rust identifiers
Sourceimpl<T> Path<T>where
T: Form,
impl<T> Path<T>where
T: Form,
Sourcepub fn from_segments_unchecked<I>(segments: I) -> Path<T>
pub fn from_segments_unchecked<I>(segments: I) -> Path<T>
Create a Path from the given segments.
Does not check that the segments are valid Rust identifiers.