pub struct Variant<T = MetaForm>where
T: Form,{
pub name: <T as Form>::String,
pub fields: Vec<Field<T>>,
pub index: u8,
pub docs: Vec<<T as Form>::String>,
}Expand description
A struct enum variant with either named (struct) or unnamed (tuple struct) fields.
Example
enum Operation {
Zero,
// ^^^^ this is a unit struct enum variant
Add(i32, i32),
// ^^^^^^^^^^^^^ this is a tuple-struct enum variant
Minus { source: i32 }
// ^^^^^^^^^^^^^^^^^^^^^ this is a struct enum variant
}Fields
name: <T as Form>::StringThe name of the variant.
fields: Vec<Field<T>>The fields of the variant.
index: u8Index of the variant, used in parity-scale-codec.
The value of this will be, in order of precedence:
1. The explicit index defined by a #[codec(index = N)] attribute.
2. The implicit index from the position of the variant in the enum definition.
docs: Vec<<T as Form>::String>Documentation
Implementations
Sourceimpl<T> Variant<T>where
T: Form,
impl<T> Variant<T>where
T: Form,
Sourcepub fn name(&self) -> &<T as Form>::String
👎Deprecated since 2.5.0: Prefer to access the fields directly; this getter will be removed in the next major version
pub fn name(&self) -> &<T as Form>::String
Returns the name of the variant.
Sourcepub fn fields(&self) -> &[Field<T>]
👎Deprecated since 2.5.0: Prefer to access the fields directly; this getter will be removed in the next major version
pub fn fields(&self) -> &[Field<T>]
Returns the fields of the struct variant.