Global

Struct Global 

pub struct Global;
๐Ÿ”ฌThis is a nightly-only experimental API. (allocator_api)
The global memory allocator.

This type implements the Allocator trait by forwarding calls to the allocator registered with the #[global_allocator] attribute if there is one, or the std crateโ€™s default.

Note: while this type is unstable, the functionality it provides can be accessed through the free functions in alloc.