Ord

Trait Ord 

1.0.0 (const: unstable) · Source
pub trait Ord: Eq + PartialOrd {
    // Required method
    fn cmp(&self, other: &Self) -> Ordering;

    // Provided methods
    fn max(self, other: Self) -> Self
       where Self: Sized { ... }
    fn min(self, other: Self) -> Self
       where Self: Sized { ... }
    fn clamp(self, min: Self, max: Self) -> Self
       where Self: Sized { ... }
}
Trait for types that form a total order.

Implementations must be consistent with the PartialOrd implementation, and ensure max, min, and clamp are consistent with cmp:

  • partial_cmp(a, b) == Some(cmp(a, b)).
  • max(a, b) == max_by(a, b, cmp) (ensured by the default implementation).
  • min(a, b) == min_by(a, b, cmp) (ensured by the default implementation).
  • For a.clamp(min, max), see the method docs (ensured by the default implementation).

Violating these requirements is a logic error. The behavior resulting from a logic error is not specified, but users of the trait must ensure that such logic errors do not result in undefined behavior. This means that unsafe code must not rely on the correctness of these methods.

Corollaries

From the above and the requirements of PartialOrd, it follows that for all a, b and c:

  • exactly one of a < b, a == b or a > b is true; and
  • < is transitive: a < b and b < c implies a < c. The same must hold for both == and >.

Mathematically speaking, the < operator defines a strict weak order. In cases where == conforms to mathematical equality, it also defines a strict total order.

Derivable

This trait can be used with #[derive].

When derived on structs, it will produce a lexicographic ordering based on the top-to-bottom declaration order of the struct’s members.

When derived on enums, variants are ordered primarily by their discriminants. Secondarily, they are ordered by their fields. By default, the discriminant is smallest for variants at the top, and largest for variants at the bottom. Here’s an example:

#[derive(PartialEq, Eq, PartialOrd, Ord)]
enum E {
    Top,
    Bottom,
}

assert!(E::Top < E::Bottom);

However, manually setting the discriminants can override this default behavior:

#[derive(PartialEq, Eq, PartialOrd, Ord)]
enum E {
    Top = 2,
    Bottom = 1,
}

assert!(E::Bottom < E::Top);

Lexicographical comparison

Lexicographical comparison is an operation with the following properties:

  • Two sequences are compared element by element.
  • The first mismatching element defines which sequence is lexicographically less or greater than the other.
  • If one sequence is a prefix of another, the shorter sequence is lexicographically less than the other.
  • If two sequences have equivalent elements and are of the same length, then the sequences are lexicographically equal.
  • An empty sequence is lexicographically less than any non-empty sequence.
  • Two empty sequences are lexicographically equal.

How can I implement Ord?

Ord requires that the type also be PartialOrd, PartialEq, and Eq.

Because Ord implies a stronger ordering relationship than PartialOrd, and both Ord and PartialOrd must agree, you must choose how to implement Ord first. You can choose to derive it, or implement it manually. If you derive it, you should derive all four traits. If you implement it manually, you should manually implement all four traits, based on the implementation of Ord.

Here’s an example where you want to define the Character comparison by health and experience only, disregarding the field mana:

use std::cmp::Ordering;

struct Character {
    health: u32,
    experience: u32,
    mana: f32,
}

impl Ord for Character {
    fn cmp(&self, other: &Self) -> Ordering {
        self.experience
            .cmp(&other.experience)
            .then(self.health.cmp(&other.health))
    }
}

impl PartialOrd for Character {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        Some(self.cmp(other))
    }
}

impl PartialEq for Character {
    fn eq(&self, other: &Self) -> bool {
        self.health == other.health && self.experience == other.experience
    }
}

impl Eq for Character {}

If all you need is to slice::sort a type by a field value, it can be simpler to use slice::sort_by_key.

Examples of incorrect Ord implementations

use std::cmp::Ordering;

#[derive(Debug)]
struct Character {
    health: f32,
}

impl Ord for Character {
    fn cmp(&self, other: &Self) -> std::cmp::Ordering {
        if self.health < other.health {
            Ordering::Less
        } else if self.health > other.health {
            Ordering::Greater
        } else {
            Ordering::Equal
        }
    }
}

impl PartialOrd for Character {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        Some(self.cmp(other))
    }
}

impl PartialEq for Character {
    fn eq(&self, other: &Self) -> bool {
        self.health == other.health
    }
}

impl Eq for Character {}

let a = Character { health: 4.5 };
let b = Character { health: f32::NAN };

// Mistake: floating-point values do not form a total order and using the built-in comparison
// operands to implement `Ord` irregardless of that reality does not change it. Use
// `f32::total_cmp` if you need a total order for floating-point values.

// Reflexivity requirement of `Ord` is not given.
assert!(a == a);
assert!(b != b);

// Antisymmetry requirement of `Ord` is not given. Only one of a < c and c < a is allowed to be
// true, not both or neither.
assert_eq!((a < b) as u8 + (b < a) as u8, 0);
use std::cmp::Ordering;

#[derive(Debug)]
struct Character {
    health: u32,
    experience: u32,
}

impl PartialOrd for Character {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        Some(self.cmp(other))
    }
}

impl Ord for Character {
    fn cmp(&self, other: &Self) -> std::cmp::Ordering {
        if self.health < 50 {
            self.health.cmp(&other.health)
        } else {
            self.experience.cmp(&other.experience)
        }
    }
}

// For performance reasons implementing `PartialEq` this way is not the idiomatic way, but it
// ensures consistent behavior between `PartialEq`, `PartialOrd` and `Ord` in this example.
impl PartialEq for Character {
    fn eq(&self, other: &Self) -> bool {
        self.cmp(other) == Ordering::Equal
    }
}

impl Eq for Character {}

let a = Character {
    health: 3,
    experience: 5,
};
let b = Character {
    health: 10,
    experience: 77,
};
let c = Character {
    health: 143,
    experience: 2,
};

// Mistake: The implementation of `Ord` compares different fields depending on the value of
// `self.health`, the resulting order is not total.

// Transitivity requirement of `Ord` is not given. If a is smaller than b and b is smaller than
// c, by transitive property a must also be smaller than c.
assert!(a < b && b < c && c < a);

// Antisymmetry requirement of `Ord` is not given. Only one of a < c and c < a is allowed to be
// true, not both or neither.
assert_eq!((a < c) as u8 + (c < a) as u8, 2);

The documentation of PartialOrd contains further examples, for example it’s wrong for PartialOrd and PartialEq to disagree.

Required Methods

1.0.0 · Source

fn cmp(&self, other: &Self) -> Ordering

This method returns an Ordering between self and other.

By convention, self.cmp(&other) returns the ordering matching the expression self <operator> other if true.

Examples
use std::cmp::Ordering;

assert_eq!(5.cmp(&10), Ordering::Less);
assert_eq!(10.cmp(&5), Ordering::Greater);
assert_eq!(5.cmp(&5), Ordering::Equal);

Provided Methods

1.21.0 · Source

fn max(self, other: Self) -> Self
where Self: Sized,

Compares and returns the maximum of two values.

Returns the second argument if the comparison determines them to be equal.

Examples
assert_eq!(1.max(2), 2);
assert_eq!(2.max(2), 2);
use std::cmp::Ordering;

#[derive(Eq)]
struct Equal(&'static str);

impl PartialEq for Equal {
    fn eq(&self, other: &Self) -> bool { true }
}
impl PartialOrd for Equal {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> { Some(Ordering::Equal) }
}
impl Ord for Equal {
    fn cmp(&self, other: &Self) -> Ordering { Ordering::Equal }
}

assert_eq!(Equal("self").max(Equal("other")).0, "other");
1.21.0 · Source

fn min(self, other: Self) -> Self
where Self: Sized,

Compares and returns the minimum of two values.

Returns the first argument if the comparison determines them to be equal.

Examples
assert_eq!(1.min(2), 1);
assert_eq!(2.min(2), 2);
use std::cmp::Ordering;

#[derive(Eq)]
struct Equal(&'static str);

impl PartialEq for Equal {
    fn eq(&self, other: &Self) -> bool { true }
}
impl PartialOrd for Equal {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> { Some(Ordering::Equal) }
}
impl Ord for Equal {
    fn cmp(&self, other: &Self) -> Ordering { Ordering::Equal }
}

assert_eq!(Equal("self").min(Equal("other")).0, "self");
1.50.0 · Source

fn clamp(self, min: Self, max: Self) -> Self
where Self: Sized,

Restrict a value to a certain interval.

Returns max if self is greater than max, and min if self is less than min. Otherwise this returns self.

Panics

Panics if min > max.

Examples
assert_eq!((-3).clamp(-2, 1), -2);
assert_eq!(0.clamp(-2, 1), 0);
assert_eq!(2.clamp(-2, 1), 1);

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl Ord for ChildInfo

Source

impl Ord for CallContext

Source

impl Ord for MultiSigner

Source

impl Ord for TypeDefPrimitive

Source

impl Ord for MetaForm

Source

impl Ord for PortableForm

1.34.0 (const: unstable) · Source

impl Ord for Infallible

1.0.0 (const: unstable) · Source

impl Ord for Ordering

Source

impl Ord for AsciiChar

1.7.0 · Source

impl Ord for IpAddr

1.0.0 · Source

impl Ord for SocketAddr

1.0.0 · Source

impl Ord for ErrorKind

Source

impl Ord for Language

Source

impl Ord for byteorder::BigEndian

Source

impl Ord for byteorder::LittleEndian

Source

impl Ord for const_oid::error::Error

Source

impl Ord for Class

Source

impl Ord for Tag

Source

impl Ord for TagMode

Source

impl Ord for SectionId

Source

impl Ord for ColumnType

Source

impl Ord for log::Level

Source

impl Ord for log::LevelFilter

Source

impl Ord for Locale

Source

impl Ord for regex_syntax::utf8::Utf8Sequence

Source

impl Ord for regex_syntax::utf8::Utf8Sequence

Source

impl Ord for All

Source

impl Ord for SignOnly

Source

impl Ord for VerifyOnly

Source

impl Ord for ElligatorSwiftParty

Source

impl Ord for secp256k1::Error

Source

impl Ord for Parity

Source

impl Ord for TokenRegistry

Source

impl Ord for subsoil::keyring::ed25519::Keyring

Source

impl Ord for subsoil::keyring::sr25519::Keyring

Source

impl Ord for Month

Source

impl Ord for zerocopy::byteorder::BigEndian

Source

impl Ord for zerocopy::byteorder::LittleEndian

1.0.0 (const: unstable) · Source

impl Ord for bool

1.0.0 (const: unstable) · Source

impl Ord for char

1.0.0 (const: unstable) · Source

impl Ord for i8

1.0.0 (const: unstable) · Source

impl Ord for i16

1.0.0 (const: unstable) · Source

impl Ord for i32

1.0.0 (const: unstable) · Source

impl Ord for i64

1.0.0 (const: unstable) · Source

impl Ord for i128

1.0.0 (const: unstable) · Source

impl Ord for isize

Source

impl Ord for !

1.0.0 · Source

impl Ord for str

Implements ordering of strings.

Strings are ordered lexicographically by their byte values. This orders Unicode code points based on their positions in the code charts. This is not necessarily the same as “alphabetical” order, which varies by language and locale. Sorting strings according to culturally-accepted standards requires locale-specific data that is outside the scope of the str type.

1.0.0 (const: unstable) · Source

impl Ord for u8

1.0.0 (const: unstable) · Source

impl Ord for u16

1.0.0 (const: unstable) · Source

impl Ord for u32

1.0.0 (const: unstable) · Source

impl Ord for u64

1.0.0 (const: unstable) · Source

impl Ord for u128

1.0.0 (const: unstable) · Source

impl Ord for ()

1.0.0 (const: unstable) · Source

impl Ord for usize

Source

impl Ord for CrateVersion

Source

impl Ord for PalletInfoData

Source

impl Ord for StorageVersion

Source

impl Ord for TrackedStorageKey

Source

impl Ord for WithdrawReasons

Source

impl Ord for ByteStr

Source

impl Ord for ByteString

1.64.0 · Source

impl Ord for CString

Source

impl Ord for ChildTrieParentKeyId

Source

impl Ord for PrefixedStorageKey

Source

impl Ord for StorageData

Source

impl Ord for StorageKey

Source

impl Ord for topsoil_core::runtime::app_crypto::core_::Bytes

Source

impl Ord for H160

Source

impl Ord for H512

Source

impl Ord for OpaquePeerId

Source

impl Ord for U256

Source

impl Ord for U512

Source

impl Ord for topsoil_core::runtime::app_crypto::ecdsa::AppPublic

Source

impl Ord for topsoil_core::runtime::app_crypto::ed25519::AppPublic

Source

impl Ord for topsoil_core::runtime::app_crypto::sr25519::AppPublic

Source

impl Ord for BigUint

Source

impl Ord for Capabilities

Source

impl Ord for topsoil_core::runtime::offchain::Duration

Source

impl Ord for HttpRequestId

Source

impl Ord for topsoil_core::runtime::offchain::Timestamp

1.8.0 · Source

impl Ord for Instant

1.8.0 · Source

impl Ord for SystemTime

Source

impl Ord for MetaType

Source

impl Ord for AccountId32

Source

impl Ord for CryptoTypeId

Source

impl Ord for FixedI64

Source

impl Ord for FixedI128

Source

impl Ord for FixedU64

Source

impl Ord for FixedU128

Source

impl Ord for KeyTypeId

Source

impl Ord for PerU16

Source

impl Ord for Perbill

Source

impl Ord for Percent

Source

impl Ord for Permill

Source

impl Ord for Perquintill

Source

impl Ord for Rational128

Source

impl Ord for H256

Source

impl Ord for UintAuthorityId

1.0.0 · Source

impl Ord for TypeId

1.0.0 · Source

impl Ord for topsoil_core::runtime::std::fmt::Error

1.33.0 · Source

impl Ord for PhantomPinned

Source

impl Ord for Alignment

1.3.0 · Source

impl Ord for topsoil_core::runtime::std::time::Duration

1.0.0 · Source

impl Ord for String

1.27.0 · Source

impl Ord for CpuidResult

1.0.0 · Source

impl Ord for CStr

1.0.0 · Source

impl Ord for Ipv4Addr

1.0.0 · Source

impl Ord for Ipv6Addr

1.0.0 · Source

impl Ord for SocketAddrV4

1.0.0 · Source

impl Ord for SocketAddrV6

1.10.0 · Source

impl Ord for Location<'_>

1.0.0 · Source

impl Ord for OsStr

1.0.0 · Source

impl Ord for OsString

1.0.0 · Source

impl Ord for Components<'_>

1.0.0 · Source

impl Ord for std::path::Path

1.0.0 · Source

impl Ord for PathBuf

1.0.0 · Source

impl Ord for PrefixComponent<'_>

Source

impl Ord for aho_corasick::util::primitives::PatternID

Source

impl Ord for aho_corasick::util::primitives::StateID

Source

impl Ord for Mnemonic

Source

impl Ord for bitcoin_hashes::hash160::Hash

Source

impl Ord for bitcoin_hashes::ripemd160::Hash

Source

impl Ord for bitcoin_hashes::sha1::Hash

Source

impl Ord for bitcoin_hashes::sha256::Hash

Source

impl Ord for Midstate

Source

impl Ord for bitcoin_hashes::sha256d::Hash

Source

impl Ord for bitcoin_hashes::sha384::Hash

Source

impl Ord for bitcoin_hashes::sha512::Hash

Source

impl Ord for bitcoin_hashes::sha512_256::Hash

Source

impl Ord for bitcoin_hashes::siphash24::Hash

Source

impl Ord for bytes::bytes::Bytes

Source

impl Ord for BytesMut

Source

impl Ord for ObjectIdentifier

Source

impl Ord for Limb

Source

impl Ord for Any

Source

impl Ord for BitString

Source

impl Ord for BmpString

Source

impl Ord for GeneralizedTime

Source

impl Ord for Ia5String

Source

impl Ord for Int

Source

impl Ord for der::asn1::integer::uint::allocating::Uint

Source

impl Ord for Null

Source

impl Ord for OctetString

Source

impl Ord for PrintableString

Source

impl Ord for TeletexString

Source

impl Ord for UtcTime

Source

impl Ord for DateTime

Source

impl Ord for IndefiniteLength

Source

impl Ord for Length

Source

impl Ord for TagNumber

Source

impl Ord for ecdsa::recovery::RecoveryId

Source

impl Ord for VerificationKeyBytes

Source

impl Ord for Register

Source

impl Ord for DwAccess

Source

impl Ord for DwAddr

Source

impl Ord for DwAt

Source

impl Ord for DwAte

Source

impl Ord for DwCc

Source

impl Ord for DwCfa

Source

impl Ord for DwChildren

Source

impl Ord for DwDefaulted

Source

impl Ord for DwDs

Source

impl Ord for DwDsc

Source

impl Ord for DwEhPe

Source

impl Ord for DwEnd

Source

impl Ord for DwForm

Source

impl Ord for DwId

Source

impl Ord for DwIdx

Source

impl Ord for DwInl

Source

impl Ord for DwLang

Source

impl Ord for DwLle

Source

impl Ord for DwLnct

Source

impl Ord for DwLne

Source

impl Ord for DwLns

Source

impl Ord for DwMacinfo

Source

impl Ord for DwMacro

Source

impl Ord for DwOp

Source

impl Ord for DwOrd

Source

impl Ord for DwRle

Source

impl Ord for DwSect

Source

impl Ord for DwSectV2

Source

impl Ord for DwTag

Source

impl Ord for DwUt

Source

impl Ord for DwVirtuality

Source

impl Ord for DwVis

Source

impl Ord for ArangeEntry

Source

impl Ord for Range

Source

impl Ord for k256::arithmetic::scalar::Scalar

Source

impl Ord for Secp256k1

Source

impl Ord for libsecp256k1_core::field::Field

Source

impl Ord for H128

Source

impl Ord for H384

Source

impl Ord for H768

Source

impl Ord for primitive_types::U128

Source

impl Ord for LazyStateID

Source

impl Ord for Unit

Source

impl Ord for NonMaxUsize

Source

impl Ord for regex_automata::util::primitives::PatternID

Source

impl Ord for SmallIndex

Source

impl Ord for regex_automata::util::primitives::StateID

Source

impl Ord for regex_syntax::ast::Position

Source

impl Ord for regex_syntax::ast::Position

Source

impl Ord for regex_syntax::ast::Span

Source

impl Ord for regex_syntax::ast::Span

Source

impl Ord for regex_syntax::hir::literal::Literal

Source

impl Ord for regex_syntax::hir::literal::Literal

Source

impl Ord for regex_syntax::hir::ClassBytesRange

Source

impl Ord for regex_syntax::hir::ClassBytesRange

Source

impl Ord for regex_syntax::hir::ClassUnicodeRange

Source

impl Ord for regex_syntax::hir::ClassUnicodeRange

Source

impl Ord for regex_syntax::utf8::Utf8Range

Source

impl Ord for regex_syntax::utf8::Utf8Range

Source

impl Ord for schnorrkel::keys::PublicKey

Source

impl Ord for RistrettoBoth

Source

impl Ord for VRFInOut

Source

impl Ord for VRFPreOut

Source

impl Ord for secp256k1_sys::recovery::RecoverableSignature

Available on non-secp256k1_fuzz only.
Source

impl Ord for secp256k1_sys::ElligatorSwift

Source

impl Ord for secp256k1_sys::Keypair

Available on non-secp256k1_fuzz only.
Source

impl Ord for secp256k1_sys::PublicKey

Available on non-secp256k1_fuzz only.
Source

impl Ord for secp256k1_sys::Signature

Available on non-secp256k1_fuzz only.
Source

impl Ord for secp256k1_sys::XOnlyPublicKey

Available on non-secp256k1_fuzz only.
Source

impl Ord for SharedSecret

Source

impl Ord for secp256k1::ecdsa::recovery::RecoverableSignature

Source

impl Ord for secp256k1::ecdsa::recovery::RecoveryId

Source

impl Ord for SerializedSignature

Source

impl Ord for secp256k1::ecdsa::Signature

Source

impl Ord for secp256k1::ellswift::ElligatorSwift

Source

impl Ord for ElligatorSwiftSharedSecret

Source

impl Ord for InvalidParityValue

Source

impl Ord for secp256k1::key::Keypair

Source

impl Ord for secp256k1::key::PublicKey

Source

impl Ord for secp256k1::key::XOnlyPublicKey

Source

impl Ord for secp256k1::scalar::Scalar

Source

impl Ord for secp256k1::schnorr::Signature

Source

impl Ord for Message

Source

impl Ord for Token

Source

impl Ord for TokenAmount

Source

impl Ord for RationalInfinite

Source

impl Ord for subsoil::consensus::beefy::ecdsa_crypto::Public

Source

impl Ord for Payload

Source

impl Ord for Slot

Source

impl Ord for SlotDuration

Source

impl Ord for ElectionScore

Source

impl Ord for OffenceSeverity

Source

impl Ord for subsoil::timestamp::Timestamp

Source

impl Ord for Date

Source

impl Ord for time::duration::Duration

Source

impl Ord for OffsetDateTime

Source

impl Ord for PrimitiveDateTime

Source

impl Ord for Time

Source

impl Ord for UtcDateTime

Source

impl Ord for UtcOffset

Source

impl Ord for tracing_core::metadata::Level

Source

impl Ord for tracing_core::metadata::LevelFilter

Source

impl Ord for Directive

Source

impl Ord for FmtSpan

Source

impl Ord for trie_db::Bytes

Source

impl Ord for ATerm

Source

impl Ord for B0

Source

impl Ord for B1

Source

impl Ord for Z0

Source

impl Ord for Equal

Source

impl Ord for Greater

Source

impl Ord for Less

Source

impl Ord for UTerm

Source

impl<'a> Ord for OpaqueDigestItemId<'a>

1.0.0 · Source

impl<'a> Ord for Component<'a>

1.0.0 · Source

impl<'a> Ord for Prefix<'a>

Source

impl<'a> Ord for PhantomContravariantLifetime<'a>

Source

impl<'a> Ord for PhantomCovariantLifetime<'a>

Source

impl<'a> Ord for PhantomInvariantLifetime<'a>

Source

impl<'a> Ord for AnyRef<'a>

Source

impl<'a> Ord for BitStringRef<'a>

Source

impl<'a> Ord for Ia5StringRef<'a>

Source

impl<'a> Ord for IntRef<'a>

Source

impl<'a> Ord for UintRef<'a>

Source

impl<'a> Ord for OctetStringRef<'a>

Source

impl<'a> Ord for PrintableStringRef<'a>

Source

impl<'a> Ord for TeletexStringRef<'a>

Source

impl<'a> Ord for Utf8StringRef<'a>

Source

impl<'a> Ord for VideotexStringRef<'a>

Source

impl<'a> Ord for Metadata<'a>

Source

impl<'a> Ord for MetadataBuilder<'a>

Source

impl<'a> Ord for DecimalStr<'a>

Source

impl<'a> Ord for InfinityStr<'a>

Source

impl<'a> Ord for MinusSignStr<'a>

Source

impl<'a> Ord for NanStr<'a>

Source

impl<'a> Ord for PlusSignStr<'a>

Source

impl<'a> Ord for SeparatorStr<'a>

Source

impl<'a> Ord for NibbleSlice<'a>

Source

impl<'a, T> Ord for Symbol<'a, T>
where T: Ord + 'a,

Source

impl<'a, T> Ord for ContextSpecificRef<'a, T>
where T: Ord,

Source

impl<'a, T, Bound> Ord for BoundedSlice<'a, T, Bound>
where T: Ord, Bound: Get<u32>,

Source

impl<'buf> Ord for AllPreallocated<'buf>

Source

impl<'buf> Ord for SignOnlyPreallocated<'buf>

Source

impl<'buf> Ord for VerifyOnlyPreallocated<'buf>

Source

impl<'s, T> Ord for SliceVec<'s, T>
where T: Ord,

Source

impl<A> Ord for TinyVec<A>
where A: Array, <A as Array>::Item: Ord,

1.0.0 (const: unstable) · Source

impl<A> Ord for &A
where A: Ord + ?Sized,

1.0.0 (const: unstable) · Source

impl<A> Ord for &mut A
where A: Ord + ?Sized,

Source

impl<A> Ord for SmallVec<A>
where A: Array, <A as Array>::Item: Ord,

Source

impl<A> Ord for tinyvec::arrayvec::ArrayVec<A>
where A: Array, <A as Array>::Item: Ord,

Source

impl<AccountId, Balance> Ord for Exposure<AccountId, Balance>
where AccountId: Ord, Balance: Ord + HasCompact,

Source

impl<AccountId, Balance> Ord for ExposurePage<AccountId, Balance>
where AccountId: Ord, Balance: Ord + HasCompact,

Source

impl<AccountId, Balance> Ord for IndividualExposure<AccountId, Balance>
where AccountId: Ord, Balance: Ord + HasCompact,

Source

impl<AssetId: Ord> Ord for NativeOrWithId<AssetId>

1.0.0 · Source

impl<B> Ord for Cow<'_, B>
where B: Ord + ToOwned + ?Sized,

Source

impl<Balance> Ord for PagedExposureMetadata<Balance>
where Balance: Ord + HasCompact + MaxEncodedLen,

Source

impl<C> Ord for VerifyingKey<C>

Source

impl<C> Ord for elliptic_curve::public_key::PublicKey<C>

Available on crate feature sec1 only.
Source

impl<C> Ord for ScalarPrimitive<C>
where C: Curve,

Source

impl<Dyn> Ord for DynMetadata<Dyn>
where Dyn: ?Sized,

Source

impl<E> Ord for I16Bytes<E>
where E: Ord + Endian,

Source

impl<E> Ord for I32Bytes<E>
where E: Ord + Endian,

Source

impl<E> Ord for I64Bytes<E>
where E: Ord + Endian,

Source

impl<E> Ord for U16Bytes<E>
where E: Ord + Endian,

Source

impl<E> Ord for U32Bytes<E>
where E: Ord + Endian,

Source

impl<E> Ord for U64Bytes<E>
where E: Ord + Endian,

1.4.0 · Source

impl<F> Ord for F
where F: FnPtr,

1.0.0 · Source

impl<K, V, A> Ord for BTreeMap<K, V, A>
where K: Ord, V: Ord, A: Allocator + Clone,

Source

impl<K, V, S> Ord for BoundedBTreeMap<K, V, S>
where BTreeMap<K, V>: Ord, S: Get<u32>,

Source

impl<L, R> Ord for Either<L, R>
where L: Ord, R: Ord,

Source

impl<O> Ord for I16<O>
where O: ByteOrder,

Source

impl<O> Ord for I32<O>
where O: ByteOrder,

Source

impl<O> Ord for I64<O>
where O: ByteOrder,

Source

impl<O> Ord for I128<O>
where O: ByteOrder,

Source

impl<O> Ord for Isize<O>
where O: ByteOrder,

Source

impl<O> Ord for U16<O>
where O: ByteOrder,

Source

impl<O> Ord for U32<O>
where O: ByteOrder,

Source

impl<O> Ord for U64<O>
where O: ByteOrder,

Source

impl<O> Ord for zerocopy::byteorder::U128<O>
where O: ByteOrder,

Source

impl<O> Ord for Usize<O>
where O: ByteOrder,

Source

impl<Params> Ord for AlgorithmIdentifier<Params>
where Params: Ord,

1.41.0 · Source

impl<Ptr> Ord for Pin<Ptr>
where Ptr: Deref, <Ptr as Deref>::Target: Ord,

Source

impl<Size> Ord for EncodedPoint<Size>
where Size: ModulusSize,

Source

impl<T> Ord for TypeDef<T>
where T: Ord + Form,

1.0.0 (const: unstable) · Source

impl<T> Ord for Option<T>
where T: Ord,

1.36.0 · Source

impl<T> Ord for Poll<T>
where T: Ord,

Source

impl<T> Ord for UnitSectionOffset<T>
where T: Ord,

1.0.0 · Source

impl<T> Ord for *const T
where T: ?Sized,

Pointer comparison is by address, as produced by the [<*const T>::addr](pointer::addr) method.

1.0.0 · Source

impl<T> Ord for *mut T
where T: ?Sized,

Pointer comparison is by address, as produced by the <*mut T>::addr method.

1.0.0 · Source

impl<T> Ord for [T]
where T: Ord,

Implements comparison of slices lexicographically.

1.0.0 (const: unstable) · Source

impl<T> Ord for (T₁, T₂, …, Tₙ)
where T: Ord,

This trait is implemented for tuples up to twelve items long.

1.0.0 · Source

impl<T> Ord for PhantomData<T>
where T: ?Sized,

Source

impl<T> Ord for topsoil_core::runtime::codec::Compact<T>
where T: Ord,

Source

impl<T> Ord for UntrackedSymbol<T>
where T: Ord,

Source

impl<T> Ord for topsoil_core::runtime::scale_info::Field<T>
where T: Ord + Form, <T as Form>::String: Ord, <T as Form>::Type: Ord,

Source

impl<T> Ord for topsoil_core::runtime::scale_info::Path<T>
where T: Ord + Form, <T as Form>::String: Ord,

Source

impl<T> Ord for Type<T>
where T: Ord + Form, <T as Form>::String: Ord,

Source

impl<T> Ord for TypeDefArray<T>
where T: Ord + Form, <T as Form>::Type: Ord,

Source

impl<T> Ord for TypeDefBitSequence<T>
where T: Ord + Form, <T as Form>::Type: Ord,

Source

impl<T> Ord for TypeDefCompact<T>
where T: Ord + Form, <T as Form>::Type: Ord,

Source

impl<T> Ord for TypeDefComposite<T>
where T: Ord + Form,

Source

impl<T> Ord for TypeDefSequence<T>
where T: Ord + Form, <T as Form>::Type: Ord,

Source

impl<T> Ord for TypeDefTuple<T>
where T: Ord + Form, <T as Form>::Type: Ord,

Source

impl<T> Ord for TypeDefVariant<T>
where T: Ord + Form,

Source

impl<T> Ord for TypeParameter<T>
where T: Ord + Form, <T as Form>::String: Ord, <T as Form>::Type: Ord,

Source

impl<T> Ord for Variant<T>
where T: Ord + Form, <T as Form>::String: Ord,

1.10.0 · Source

impl<T> Ord for Cell<T>
where T: Ord + Copy,

1.10.0 · Source

impl<T> Ord for RefCell<T>
where T: Ord + ?Sized,

Source

impl<T> Ord for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> Ord for PhantomCovariant<T>
where T: ?Sized,

Source

impl<T> Ord for PhantomInvariant<T>
where T: ?Sized,

1.20.0 · Source

impl<T> Ord for ManuallyDrop<T>
where T: Ord + ?Sized,

1.28.0 (const: unstable) · Source

impl<T> Ord for topsoil_core::runtime::std::num::NonZero<T>

1.74.0 · Source

impl<T> Ord for Saturating<T>
where T: Ord,

1.0.0 · Source

impl<T> Ord for topsoil_core::runtime::std::num::Wrapping<T>
where T: Ord,

1.19.0 (const: unstable) · Source

impl<T> Ord for Reverse<T>
where T: Ord,

1.25.0 · Source

impl<T> Ord for NonNull<T>
where T: ?Sized,

Source

impl<T> Ord for Exclusive<T>
where T: Sync + Ord + ?Sized,

Source

impl<T> Ord for CapacityError<T>
where T: Ord,

Source

impl<T> Ord for Hmac<T>
where T: Ord + Hash,

Source

impl<T> Ord for bitcoin_hashes::sha256t::Hash<T>
where T: Tag,

Source

impl<T> Ord for crypto_bigint::non_zero::NonZero<T>
where T: Ord + Zero,

Source

impl<T> Ord for crypto_bigint::wrapping::Wrapping<T>
where T: Ord,

Source

impl<T> Ord for ContextSpecific<T>
where T: Ord,

Source

impl<T> Ord for SetOfVec<T>
where T: Ord + DerOrd,

Source

impl<T> Ord for AllowStdIo<T>
where T: Ord,

Source

impl<T> Ord for DebugInfoOffset<T>
where T: Ord,

Source

impl<T> Ord for DebugTypesOffset<T>
where T: Ord,

Source

impl<T> Ord for UnitOffset<T>
where T: Ord,

Source

impl<T> Ord for jam_codec::compact::Compact<T>
where T: Ord,

Source

impl<T> Ord for Unalign<T>
where T: Unaligned + Ord,

1.0.0 · Source

impl<T, A> Ord for LinkedList<T, A>
where T: Ord, A: Allocator,

1.0.0 · Source

impl<T, A> Ord for topsoil_core::runtime::Vec<T, A>
where T: Ord, A: Allocator,

Implements ordering of vectors, lexicographically.

1.0.0 · Source

impl<T, A> Ord for BTreeSet<T, A>
where T: Ord, A: Allocator + Clone,

1.0.0 · Source

impl<T, A> Ord for VecDeque<T, A>
where T: Ord, A: Allocator,

1.0.0 · Source

impl<T, A> Ord for topsoil_core::runtime::std::prelude::Box<T, A>
where T: Ord + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Ord for Rc<T, A>
where T: Ord + ?Sized, A: Allocator,

Source

impl<T, A> Ord for UniqueRc<T, A>
where T: Ord + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Ord for Arc<T, A>
where T: Ord + ?Sized, A: Allocator,

Source

impl<T, A> Ord for UniqueArc<T, A>
where T: Ord + ?Sized, A: Allocator,

Source

impl<T, A> Ord for allocator_api2::stable::boxed::Box<T, A>
where T: Ord + ?Sized, A: Allocator,

Source

impl<T, A> Ord for allocator_api2::stable::vec::Vec<T, A>
where T: Ord, A: Allocator,

Implements ordering of vectors, lexicographically.

Source

impl<T, B> Ord for Ref<B, T>

Source

impl<T, Bound> Ord for BoundedVec<T, Bound>
where T: Ord, Bound: Get<u32>,

Source

impl<T, D> Ord for TypeWithDefault<T, D>
where T: Ord, D: Get<T>,

1.0.0 (const: unstable) · Source

impl<T, E> Ord for Result<T, E>
where T: Ord, E: Ord,

Source

impl<T, N> Ord for GenericArray<T, N>
where T: Ord, N: ArrayLength<T>,

Source

impl<T, S> Ord for BoundedBTreeSet<T, S>
where BTreeSet<T>: Ord, S: Get<u32>,

Source

impl<T, S> Ord for WeakBoundedVec<T, S>
where T: Ord, S: Get<u32>,

Source

impl<T, const CAP: usize> Ord for arrayvec::arrayvec::ArrayVec<T, CAP>
where T: Ord,

1.0.0 · Source

impl<T, const N: usize> Ord for [T; N]
where T: Ord,

Implements comparison of arrays lexicographically.

Source

impl<T, const N: usize> Ord for Simd<T, N>
where T: SimdElement + Ord,

Lexicographic order. For the SIMD elementwise minimum and maximum, use simd_min and simd_max instead.

Source

impl<T, const N: usize> Ord for SetOf<T, N>
where T: Ord + DerOrd,

Source

impl<TBlockNumber> Ord for Commitment<TBlockNumber>
where TBlockNumber: Ord,

Source

impl<U> Ord for NInt<U>
where U: Ord + Unsigned + NonZero,

Source

impl<U> Ord for PInt<U>
where U: Ord + Unsigned + NonZero,

Source

impl<U, B> Ord for UInt<U, B>
where U: Ord, B: Ord,

Source

impl<V, A> Ord for TArr<V, A>
where V: Ord, A: Ord,

Source

impl<Y, R> Ord for CoroutineState<Y, R>
where Y: Ord, R: Ord,

Source

impl<const CAP: usize> Ord for ArrayString<CAP>

Source

impl<const LIMBS: usize> Ord for crypto_bigint::uint::Uint<LIMBS>

Source

impl<const MIN: i8, const MAX: i8> Ord for OptionRangedI8<MIN, MAX>

Source

impl<const MIN: i8, const MAX: i8> Ord for RangedI8<MIN, MAX>

Source

impl<const MIN: i16, const MAX: i16> Ord for OptionRangedI16<MIN, MAX>

Source

impl<const MIN: i16, const MAX: i16> Ord for RangedI16<MIN, MAX>

Source

impl<const MIN: i32, const MAX: i32> Ord for OptionRangedI32<MIN, MAX>

Source

impl<const MIN: i32, const MAX: i32> Ord for RangedI32<MIN, MAX>

Source

impl<const MIN: i64, const MAX: i64> Ord for OptionRangedI64<MIN, MAX>

Source

impl<const MIN: i64, const MAX: i64> Ord for RangedI64<MIN, MAX>

Source

impl<const MIN: i128, const MAX: i128> Ord for OptionRangedI128<MIN, MAX>

Source

impl<const MIN: i128, const MAX: i128> Ord for RangedI128<MIN, MAX>

Source

impl<const MIN: isize, const MAX: isize> Ord for OptionRangedIsize<MIN, MAX>

Source

impl<const MIN: isize, const MAX: isize> Ord for RangedIsize<MIN, MAX>

Source

impl<const MIN: u8, const MAX: u8> Ord for OptionRangedU8<MIN, MAX>

Source

impl<const MIN: u8, const MAX: u8> Ord for RangedU8<MIN, MAX>

Source

impl<const MIN: u16, const MAX: u16> Ord for OptionRangedU16<MIN, MAX>

Source

impl<const MIN: u16, const MAX: u16> Ord for RangedU16<MIN, MAX>

Source

impl<const MIN: u32, const MAX: u32> Ord for OptionRangedU32<MIN, MAX>

Source

impl<const MIN: u32, const MAX: u32> Ord for RangedU32<MIN, MAX>

Source

impl<const MIN: u64, const MAX: u64> Ord for OptionRangedU64<MIN, MAX>

Source

impl<const MIN: u64, const MAX: u64> Ord for RangedU64<MIN, MAX>

Source

impl<const MIN: u128, const MAX: u128> Ord for OptionRangedU128<MIN, MAX>

Source

impl<const MIN: u128, const MAX: u128> Ord for RangedU128<MIN, MAX>

Source

impl<const MIN: usize, const MAX: usize> Ord for OptionRangedUsize<MIN, MAX>

Source

impl<const MIN: usize, const MAX: usize> Ord for RangedUsize<MIN, MAX>

Source

impl<const N: usize, T> Ord for CryptoBytes<N, T>

Source

impl<const N: usize, const UPPERCASE: bool> Ord for serdect::array::HexOrBin<N, UPPERCASE>

Source

impl<const SIZE: usize> Ord for WriteBuffer<SIZE>

Source

impl<const UPPERCASE: bool> Ord for serdect::slice::HexOrBin<UPPERCASE>