Hash

Trait Hash 

1.0.0 · Source
pub trait Hash {
    // Required method
    fn hash<H>(&self, state: &mut H)
       where H: Hasher;

    // Provided method
    fn hash_slice<H>(data: &[Self], state: &mut H)
       where H: Hasher,
             Self: Sized { ... }
}
A hashable type.

Types implementing Hash are able to be hashed with an instance of Hasher.

Implementing Hash

You can derive Hash with #[derive(Hash)] if all fields implement Hash. The resulting hash will be the combination of the values from calling hash on each field.

#[derive(Hash)]
struct Rustacean {
    name: String,
    country: String,
}

If you need more control over how a value is hashed, you can of course implement the Hash trait yourself:

use std::hash::{Hash, Hasher};

struct Person {
    id: u32,
    name: String,
    phone: u64,
}

impl Hash for Person {
    fn hash<H: Hasher>(&self, state: &mut H) {
        self.id.hash(state);
        self.phone.hash(state);
    }
}

Hash and Eq

When implementing both Hash and Eq, it is important that the following property holds:

k1 == k2 -> hash(k1) == hash(k2)

In other words, if two keys are equal, their hashes must also be equal. HashMap and HashSet both rely on this behavior.

Thankfully, you won’t need to worry about upholding this property when deriving both Eq and Hash with #[derive(PartialEq, Eq, Hash)].

Violating this property is a logic error. The behavior resulting from a logic error is not specified, but users of the trait must ensure that such logic errors do not result in undefined behavior. This means that unsafe code must not rely on the correctness of these methods.

Prefix collisions

Implementations of hash should ensure that the data they pass to the Hasher are prefix-free. That is, values which are not equal should cause two different sequences of values to be written, and neither of the two sequences should be a prefix of the other.

For example, the standard implementation of Hash for &str passes an extra 0xFF byte to the Hasher so that the values ("ab", "c") and ("a", "bc") hash differently.

Portability

Due to differences in endianness and type sizes, data fed by Hash to a Hasher should not be considered portable across platforms. Additionally the data passed by most standard library types should not be considered stable between compiler versions.

This means tests shouldn’t probe hard-coded hash values or data fed to a Hasher and instead should check consistency with Eq.

Serialization formats intended to be portable between platforms or compiler versions should either avoid encoding hashes or only rely on Hash and Hasher implementations that provide additional guarantees.

Required Methods

1.0.0 · Source

fn hash<H>(&self, state: &mut H)
where H: Hasher,

Feeds this value into the given Hasher.

Examples
use std::hash::{DefaultHasher, Hash, Hasher};

let mut hasher = DefaultHasher::new();
7920.hash(&mut hasher);
println!("Hash is {:x}!", hasher.finish());

Provided Methods

1.3.0 · Source

fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher, Self: Sized,

Feeds a slice of this type into the given Hasher.

This method is meant as a convenience, but its implementation is also explicitly left unspecified. It isn’t guaranteed to be equivalent to repeated calls of hash and implementations of Hash should keep that in mind and call hash themselves if the slice isn’t treated as a whole unit in the PartialEq implementation.

For example, a VecDeque implementation might naïvely call as_slices and then hash_slice on each slice, but this is wrong since the two slices can change with a call to make_contiguous without affecting the PartialEq result. Since these slices aren’t treated as singular units, and instead part of a larger deque, this method cannot be used.

Examples
use std::hash::{DefaultHasher, Hash, Hasher};

let mut hasher = DefaultHasher::new();
let numbers = [6, 28, 496, 8128];
Hash::hash_slice(&numbers, &mut hasher);
println!("Hash is {:x}!", hasher.finish());

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl Hash for TransactionSource

Source

impl Hash for ChildInfo

Source

impl Hash for DeriveJunction

Source

impl Hash for OffchainOverlayedChange

1.0.0 · Source

impl Hash for topsoil_core::runtime::std::cmp::Ordering

1.44.0 · Source

impl Hash for Infallible

1.55.0 · Source

impl Hash for IntErrorKind

1.0.0 · Source

impl Hash for topsoil_core::runtime::std::sync::atomic::Ordering

Source

impl Hash for AsciiChar

Source

impl Hash for Locality

1.7.0 · Source

impl Hash for IpAddr

Source

impl Hash for Ipv6MulticastScope

1.0.0 · Source

impl Hash for SocketAddr

1.0.0 · Source

impl Hash for std::io::error::ErrorKind

Source

impl Hash for Language

Source

impl Hash for byteorder::BigEndian

Source

impl Hash for byteorder::LittleEndian

Source

impl Hash for PollNext

Source

impl Hash for Format

Source

impl Hash for SectionId

Source

impl Hash for RunTimeEndian

Source

impl Hash for Case

Source

impl Hash for log::Level

Source

impl Hash for log::LevelFilter

Source

impl Hash for DataFormat

Source

impl Hash for MZError

Source

impl Hash for MZFlush

Source

impl Hash for MZStatus

Source

impl Hash for TINFLStatus

Source

impl Hash for num_format::error_kind::ErrorKind

Source

impl Hash for Grouping

Source

impl Hash for Locale

Source

impl Hash for AddressSize

Source

impl Hash for Architecture

Source

impl Hash for BinaryFormat

Source

impl Hash for ComdatKind

Source

impl Hash for FileFlags

Source

impl Hash for RelocationEncoding

Source

impl Hash for RelocationFlags

Source

impl Hash for RelocationKind

Source

impl Hash for SectionFlags

Source

impl Hash for SectionKind

Source

impl Hash for SegmentFlags

Source

impl Hash for SubArchitecture

Source

impl Hash for SymbolKind

Source

impl Hash for SymbolScope

Source

impl Hash for Endianness

Source

impl Hash for ArchiveKind

Source

impl Hash for ImportType

Source

impl Hash for CompressionFormat

Source

impl Hash for FileKind

Source

impl Hash for ObjectKind

Source

impl Hash for RelocationTarget

Source

impl Hash for SymbolSection

Source

impl Hash for Instruction

Source

impl Hash for BlockType

Source

impl Hash for Type

Source

impl Hash for ValueType

Source

impl Hash for MultiSignatureStage

Source

impl Hash for SignatureError

Source

impl Hash for All

Source

impl Hash for SignOnly

Source

impl Hash for VerifyOnly

Source

impl Hash for ElligatorSwiftParty

Source

impl Hash for secp256k1::Error

Source

impl Hash for Parity

Source

impl Hash for Value

Source

impl Hash for TokenRegistry

Source

impl Hash for ParseError

Source

impl Hash for subsoil::keyring::ed25519::Keyring

Source

impl Hash for subsoil::keyring::sr25519::Keyring

Source

impl Hash for Month

Source

impl Hash for Weekday

Source

impl Hash for FromStrRadixErrKind

Source

impl Hash for zerocopy::byteorder::BigEndian

Source

impl Hash for zerocopy::byteorder::LittleEndian

1.0.0 · Source

impl Hash for bool

1.0.0 · Source

impl Hash for char

1.0.0 · Source

impl Hash for i8

1.0.0 · Source

impl Hash for i16

1.0.0 · Source

impl Hash for i32

1.0.0 · Source

impl Hash for i64

1.0.0 · Source

impl Hash for i128

1.0.0 · Source

impl Hash for isize

1.29.0 · Source

impl Hash for !

1.0.0 · Source

impl Hash for str

1.0.0 · Source

impl Hash for u8

1.0.0 · Source

impl Hash for u16

1.0.0 · Source

impl Hash for u32

1.0.0 · Source

impl Hash for u64

1.0.0 · Source

impl Hash for u128

1.0.0 · Source

impl Hash for ()

1.0.0 · Source

impl Hash for usize

Source

impl Hash for TrackedStorageKey

Source

impl Hash for WithdrawReasons

Source

impl Hash for ByteStr

Source

impl Hash for ByteString

1.64.0 · Source

impl Hash for CString

Source

impl Hash for ChildTrieParentKeyId

Source

impl Hash for PrefixedStorageKey

Source

impl Hash for StorageData

Source

impl Hash for StorageKey

Source

impl Hash for topsoil_core::runtime::app_crypto::core_::Bytes

Source

impl Hash for H160

Source

impl Hash for H512

Source

impl Hash for U256

Source

impl Hash for U512

Source

impl Hash for topsoil_core::runtime::app_crypto::ecdsa::AppProofOfPossession

Source

impl Hash for topsoil_core::runtime::app_crypto::ecdsa::AppPublic

Source

impl Hash for topsoil_core::runtime::app_crypto::ecdsa::AppSignature

Source

impl Hash for topsoil_core::runtime::app_crypto::ed25519::AppProofOfPossession

Source

impl Hash for topsoil_core::runtime::app_crypto::ed25519::AppPublic

Source

impl Hash for topsoil_core::runtime::app_crypto::ed25519::AppSignature

Source

impl Hash for topsoil_core::runtime::app_crypto::sr25519::AppProofOfPossession

Source

impl Hash for topsoil_core::runtime::app_crypto::sr25519::AppPublic

Source

impl Hash for topsoil_core::runtime::app_crypto::sr25519::AppSignature

Source

impl Hash for Capabilities

Source

impl Hash for HttpRequestId

1.8.0 · Source

impl Hash for Instant

1.8.0 · Source

impl Hash for SystemTime

Source

impl Hash for MetaType

Source

impl Hash for AccountId32

Source

impl Hash for CryptoTypeId

Source

impl Hash for KeyTypeId

Source

impl Hash for H256

Source

impl Hash for TestSignature

Source

impl Hash for UintAuthorityId

1.28.0 · Source

impl Hash for Layout

1.0.0 · Source

impl Hash for TypeId

1.0.0 · Source

impl Hash for topsoil_core::runtime::std::fmt::Error

1.33.0 · Source

impl Hash for PhantomPinned

1.0.0 · Source

impl Hash for RangeFull

Source

impl Hash for Alignment

1.3.0 · Source

impl Hash for topsoil_core::runtime::std::time::Duration

1.0.0 · Source

impl Hash for String

1.64.0 · Source

impl Hash for CStr

1.0.0 · Source

impl Hash for Ipv4Addr

1.0.0 · Source

impl Hash for Ipv6Addr

1.0.0 · Source

impl Hash for SocketAddrV4

1.0.0 · Source

impl Hash for SocketAddrV6

1.10.0 · Source

impl Hash for Location<'_>

1.0.0 · Source

impl Hash for OsStr

1.0.0 · Source

impl Hash for OsString

1.1.0 · Source

impl Hash for FileType

Source

impl Hash for UCred

1.0.0 · Source

impl Hash for Path

1.0.0 · Source

impl Hash for PathBuf

1.0.0 · Source

impl Hash for PrefixComponent<'_>

1.19.0 · Source

impl Hash for ThreadId

Source

impl Hash for aho_corasick::util::primitives::PatternID

Source

impl Hash for aho_corasick::util::primitives::StateID

Source

impl Hash for aho_corasick::util::search::Match

Source

impl Hash for aho_corasick::util::search::Span

Source

impl Hash for Mnemonic

Source

impl Hash for bitcoin_hashes::hash160::Hash

Source

impl Hash for bitcoin_hashes::ripemd160::Hash

Source

impl Hash for bitcoin_hashes::sha1::Hash

Source

impl Hash for bitcoin_hashes::sha256::Hash

Source

impl Hash for Midstate

Source

impl Hash for bitcoin_hashes::sha256d::Hash

Source

impl Hash for bitcoin_hashes::sha384::Hash

Source

impl Hash for bitcoin_hashes::sha512::Hash

Source

impl Hash for bitcoin_hashes::sha512_256::Hash

Source

impl Hash for bitcoin_hashes::siphash24::Hash

Source

impl Hash for bytes::bytes::Bytes

Source

impl Hash for BytesMut

Source

impl Hash for ObjectIdentifier

Source

impl Hash for Limb

Source

impl Hash for CompressedEdwardsY

Source

impl Hash for MontgomeryPoint

Source

impl Hash for CompressedRistretto

Source

impl Hash for curve25519_dalek::scalar::Scalar

Source

impl Hash for VerifyingKey

Source

impl Hash for VerificationKeyBytes

Source

impl Hash for DebugTypeSignature

Source

impl Hash for DwoId

Source

impl Hash for Encoding

Source

impl Hash for LineEncoding

Source

impl Hash for Register

Source

impl Hash for DwAccess

Source

impl Hash for DwAddr

Source

impl Hash for DwAt

Source

impl Hash for DwAte

Source

impl Hash for DwCc

Source

impl Hash for DwCfa

Source

impl Hash for DwChildren

Source

impl Hash for DwDefaulted

Source

impl Hash for DwDs

Source

impl Hash for DwDsc

Source

impl Hash for DwEhPe

Source

impl Hash for DwEnd

Source

impl Hash for DwForm

Source

impl Hash for DwId

Source

impl Hash for DwIdx

Source

impl Hash for DwInl

Source

impl Hash for DwLang

Source

impl Hash for DwLle

Source

impl Hash for DwLnct

Source

impl Hash for DwLne

Source

impl Hash for DwLns

Source

impl Hash for DwMacinfo

Source

impl Hash for DwMacro

Source

impl Hash for DwOp

Source

impl Hash for DwOrd

Source

impl Hash for DwRle

Source

impl Hash for DwSect

Source

impl Hash for DwSectV2

Source

impl Hash for DwTag

Source

impl Hash for DwUt

Source

impl Hash for DwVirtuality

Source

impl Hash for DwVis

Source

impl Hash for gimli::endianity::BigEndian

Source

impl Hash for gimli::endianity::LittleEndian

Source

impl Hash for gimli::read::rnglists::Range

Source

impl Hash for StreamResult

Source

impl Hash for CustomFormat

Source

impl Hash for CustomFormatBuilder

Source

impl Hash for num_format::error::Error

Source

impl Hash for object::endian::BigEndian

Source

impl Hash for object::endian::LittleEndian

Source

impl Hash for CompressedFileRange

Source

impl Hash for SectionIndex

Source

impl Hash for SymbolIndex

Source

impl Hash for BrTableData

Source

impl Hash for FunctionType

Source

impl Hash for H128

Source

impl Hash for H384

Source

impl Hash for H768

Source

impl Hash for primitive_types::U128

Source

impl Hash for LazyStateID

Source

impl Hash for Transition

Source

impl Hash for NonMaxUsize

Source

impl Hash for regex_automata::util::primitives::PatternID

Source

impl Hash for SmallIndex

Source

impl Hash for regex_automata::util::primitives::StateID

Source

impl Hash for HalfMatch

Source

impl Hash for regex_automata::util::search::Match

Source

impl Hash for regex_automata::util::search::Span

Source

impl Hash for AdaptorCertPublic

Source

impl Hash for ChainCode

Source

impl Hash for schnorrkel::keys::PublicKey

Source

impl Hash for RistrettoBoth

Source

impl Hash for VRFInOut

Source

impl Hash for VRFPreOut

Source

impl Hash for secp256k1_sys::recovery::RecoverableSignature

Available on non-secp256k1_fuzz only.
Source

impl Hash for secp256k1_sys::ElligatorSwift

Source

impl Hash for secp256k1_sys::Keypair

Available on non-secp256k1_fuzz only.
Source

impl Hash for secp256k1_sys::PublicKey

Available on non-secp256k1_fuzz only.
Source

impl Hash for secp256k1_sys::Signature

Available on non-secp256k1_fuzz only.
Source

impl Hash for secp256k1_sys::XOnlyPublicKey

Available on non-secp256k1_fuzz only.
Source

impl Hash for SharedSecret

Source

impl Hash for secp256k1::ecdsa::recovery::RecoverableSignature

Source

impl Hash for SerializedSignature

Source

impl Hash for secp256k1::ecdsa::Signature

Source

impl Hash for secp256k1::ellswift::ElligatorSwift

Source

impl Hash for ElligatorSwiftSharedSecret

Source

impl Hash for InvalidParityValue

Source

impl Hash for secp256k1::key::Keypair

Source

impl Hash for secp256k1::key::PublicKey

Source

impl Hash for secp256k1::key::XOnlyPublicKey

Source

impl Hash for OutOfRangeError

Source

impl Hash for secp256k1::scalar::Scalar

Source

impl Hash for secp256k1::schnorr::Signature

Source

impl Hash for Message

Source

impl Hash for Map<String, Value>

Source

impl Hash for Number

Source

impl Hash for Token

Source

impl Hash for TokenAmount

Source

impl Hash for subsoil::consensus::beefy::ecdsa_crypto::ProofOfPossession

Source

impl Hash for subsoil::consensus::beefy::ecdsa_crypto::Public

Source

impl Hash for subsoil::consensus::beefy::ecdsa_crypto::Signature

Source

impl Hash for Payload

Source

impl Hash for Slot

Source

impl Hash for SlotDuration

Source

impl Hash for Date

Source

impl Hash for time::duration::Duration

Source

impl Hash for ComponentRange

Source

impl Hash for OffsetDateTime

Source

impl Hash for PrimitiveDateTime

Source

impl Hash for Time

Source

impl Hash for UtcDateTime

Source

impl Hash for UtcOffset

Source

impl Hash for Identifier

Source

impl Hash for Field

Source

impl Hash for tracing_core::metadata::Level

Source

impl Hash for tracing_core::metadata::LevelFilter

Source

impl Hash for Id

Source

impl Hash for tracing::span::Span

Source

impl Hash for trie_db::Bytes

Source

impl Hash for ATerm

Source

impl Hash for B0

Source

impl Hash for B1

Source

impl Hash for Z0

Source

impl Hash for Equal

Source

impl Hash for Greater

Source

impl Hash for Less

Source

impl Hash for UTerm

1.0.0 · Source

impl<'a> Hash for Component<'a>

1.0.0 · Source

impl<'a> Hash for Prefix<'a>

Source

impl<'a> Hash for PhantomContravariantLifetime<'a>

Source

impl<'a> Hash for PhantomCovariantLifetime<'a>

Source

impl<'a> Hash for PhantomInvariantLifetime<'a>

Source

impl<'a> Hash for Metadata<'a>

Source

impl<'a> Hash for MetadataBuilder<'a>

Source

impl<'a> Hash for DecimalStr<'a>

Source

impl<'a> Hash for InfinityStr<'a>

Source

impl<'a> Hash for MinusSignStr<'a>

Source

impl<'a> Hash for NanStr<'a>

Source

impl<'a> Hash for PlusSignStr<'a>

Source

impl<'a> Hash for SeparatorStr<'a>

Source

impl<'a, T, S> Hash for BoundedSlice<'a, T, S>
where T: Hash,

Available on crate feature std only.
Source

impl<'buf> Hash for AllPreallocated<'buf>

Source

impl<'buf> Hash for SignOnlyPreallocated<'buf>

Source

impl<'buf> Hash for VerifyOnlyPreallocated<'buf>

Source

impl<'data> Hash for CompressedData<'data>

Source

impl<'data> Hash for ObjectMapEntry<'data>

Source

impl<'data> Hash for ObjectMapFile<'data>

Source

impl<'data> Hash for SymbolMapName<'data>

Source

impl<'input, Endian> Hash for EndianSlice<'input, Endian>
where Endian: Hash + Endianity,

Source

impl<'s, T> Hash for SliceVec<'s, T>
where T: Hash,

Source

impl<A> Hash for TinyVec<A>
where A: Array, <A as Array>::Item: Hash,

Source

impl<A> Hash for SmallVec<A>
where A: Array, <A as Array>::Item: Hash,

Source

impl<A> Hash for tinyvec::arrayvec::ArrayVec<A>
where A: Array, <A as Array>::Item: Hash,

Source

impl<A, B> Hash for itertools::either_or_both::EitherOrBoth<A, B>
where A: Hash, B: Hash,

Source

impl<A, B> Hash for itertools::either_or_both::EitherOrBoth<A, B>
where A: Hash, B: Hash,

Source

impl<AccountId, AccountIndex> Hash for MultiAddress<AccountId, AccountIndex>
where AccountId: Hash, AccountIndex: Hash,

Source

impl<AuthorityId> Hash for subsoil::consensus::beefy::test_utils::Keyring<AuthorityId>
where AuthorityId: Hash,

1.0.0 · Source

impl<B> Hash for Cow<'_, B>
where B: Hash + ToOwned + ?Sized,

1.55.0 · Source

impl<B, C> Hash for ControlFlow<B, C>
where B: Hash, C: Hash,

Source

impl<Dyn> Hash for DynMetadata<Dyn>
where Dyn: ?Sized,

Source

impl<E> Hash for I16Bytes<E>
where E: Hash + Endian,

Source

impl<E> Hash for I32Bytes<E>
where E: Hash + Endian,

Source

impl<E> Hash for I64Bytes<E>
where E: Hash + Endian,

Source

impl<E> Hash for U16Bytes<E>
where E: Hash + Endian,

Source

impl<E> Hash for U32Bytes<E>
where E: Hash + Endian,

Source

impl<E> Hash for U64Bytes<E>
where E: Hash + Endian,

1.4.0 · Source

impl<F> Hash for F
where F: FnPtr,

1.0.0 · Source

impl<Idx> Hash for topsoil_core::runtime::std::ops::Range<Idx>
where Idx: Hash,

1.0.0 · Source

impl<Idx> Hash for topsoil_core::runtime::std::ops::RangeFrom<Idx>
where Idx: Hash,

1.26.0 · Source

impl<Idx> Hash for topsoil_core::runtime::std::ops::RangeInclusive<Idx>
where Idx: Hash,

1.0.0 · Source

impl<Idx> Hash for RangeTo<Idx>
where Idx: Hash,

1.26.0 · Source

impl<Idx> Hash for topsoil_core::runtime::std::ops::RangeToInclusive<Idx>
where Idx: Hash,

Source

impl<Idx> Hash for core::range::Range<Idx>
where Idx: Hash,

Source

impl<Idx> Hash for core::range::RangeFrom<Idx>
where Idx: Hash,

1.95.0 · Source

impl<Idx> Hash for core::range::RangeInclusive<Idx>
where Idx: Hash,

1.96.0 · Source

impl<Idx> Hash for core::range::RangeToInclusive<Idx>
where Idx: Hash,

Source

impl<K> Hash for ExtendedKey<K>
where K: Hash,

1.0.0 · Source

impl<K, V, A> Hash for BTreeMap<K, V, A>
where K: Hash, V: Hash, A: Allocator + Clone,

Source

impl<K, V, S> Hash for BoundedBTreeMap<K, V, S>
where K: Hash, V: Hash,

Available on crate feature std only.
Source

impl<L, R> Hash for Either<L, R>
where L: Hash, R: Hash,

Source

impl<O> Hash for F32<O>
where O: Hash,

Source

impl<O> Hash for F64<O>
where O: Hash,

Source

impl<O> Hash for I16<O>
where O: Hash,

Source

impl<O> Hash for I32<O>
where O: Hash,

Source

impl<O> Hash for I64<O>
where O: Hash,

Source

impl<O> Hash for I128<O>
where O: Hash,

Source

impl<O> Hash for Isize<O>
where O: Hash,

Source

impl<O> Hash for U16<O>
where O: Hash,

Source

impl<O> Hash for U32<O>
where O: Hash,

Source

impl<O> Hash for U64<O>
where O: Hash,

Source

impl<O> Hash for zerocopy::byteorder::U128<O>
where O: Hash,

Source

impl<O> Hash for Usize<O>
where O: Hash,

1.41.0 · Source

impl<Ptr> Hash for Pin<Ptr>
where Ptr: Deref, <Ptr as Deref>::Target: Hash,

Source

impl<R> Hash for LocationListEntry<R>
where R: Hash + Reader,

Source

impl<R> Hash for Expression<R>
where R: Hash + Reader,

Source

impl<Section, Symbol> Hash for SymbolFlags<Section, Symbol>
where Section: Hash, Symbol: Hash,

Source

impl<Size> Hash for EncodedPoint<Size>
where Size: ModulusSize,

1.17.0 · Source

impl<T> Hash for Bound<T>
where T: Hash,

1.0.0 · Source

impl<T> Hash for Option<T>
where T: Hash,

1.36.0 · Source

impl<T> Hash for Poll<T>
where T: Hash,

Source

impl<T> Hash for UnitSectionOffset<T>
where T: Hash,

1.0.0 · Source

impl<T> Hash for *const T
where T: ?Sized,

1.0.0 · Source

impl<T> Hash for *mut T
where T: ?Sized,

1.0.0 · Source

impl<T> Hash for &T
where T: Hash + ?Sized,

1.0.0 · Source

impl<T> Hash for &mut T
where T: Hash + ?Sized,

1.0.0 · Source

impl<T> Hash for [T]
where T: Hash,

1.0.0 · Source

impl<T> Hash for (T₁, T₂, …, Tₙ)
where T: Hash,

This trait is implemented for tuples up to twelve items long.

1.0.0 · Source

impl<T> Hash for PhantomData<T>
where T: ?Sized,

Source

impl<T> Hash for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> Hash for PhantomCovariant<T>
where T: ?Sized,

Source

impl<T> Hash for PhantomInvariant<T>
where T: ?Sized,

1.21.0 · Source

impl<T> Hash for Discriminant<T>

1.20.0 · Source

impl<T> Hash for ManuallyDrop<T>
where T: Hash + ?Sized,

1.28.0 · Source

impl<T> Hash for NonZero<T>

1.74.0 · Source

impl<T> Hash for Saturating<T>
where T: Hash,

1.0.0 · Source

impl<T> Hash for Wrapping<T>
where T: Hash,

1.19.0 · Source

impl<T> Hash for Reverse<T>
where T: Hash,

1.25.0 · Source

impl<T> Hash for NonNull<T>
where T: ?Sized,

Source

impl<T> Hash for Exclusive<T>
where T: Sync + Hash + ?Sized,

Source

impl<T> Hash for Hmac<T>
where T: Hash + Hash,

Source

impl<T> Hash for bitcoin_hashes::sha256t::Hash<T>
where T: Tag,

Source

impl<T> Hash for AllowStdIo<T>
where T: Hash,

Source

impl<T> Hash for DebugAbbrevOffset<T>
where T: Hash,

Source

impl<T> Hash for DebugFrameOffset<T>
where T: Hash,

Source

impl<T> Hash for DebugInfoOffset<T>
where T: Hash,

Source

impl<T> Hash for DebugMacinfoOffset<T>
where T: Hash,

Source

impl<T> Hash for DebugMacroOffset<T>
where T: Hash,

Source

impl<T> Hash for DebugTypesOffset<T>
where T: Hash,

Source

impl<T> Hash for EhFrameOffset<T>
where T: Hash,

Source

impl<T> Hash for LocationListsOffset<T>
where T: Hash,

Source

impl<T> Hash for RangeListsOffset<T>
where T: Hash,

Source

impl<T> Hash for RawRangeListsOffset<T>
where T: Hash,

Source

impl<T> Hash for UnitOffset<T>
where T: Hash,

Source

impl<T> Hash for Unalign<T>
where T: Unaligned + Hash,

1.0.0 · Source

impl<T, A> Hash for LinkedList<T, A>
where T: Hash, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for topsoil_core::runtime::Vec<T, A>
where T: Hash, A: Allocator,

The hash of a vector is the same as that of the corresponding slice, as required by the core::borrow::Borrow implementation.

use std::hash::BuildHasher;

let b = std::hash::RandomState::new();
let v: Vec<u8> = vec![0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(v), b.hash_one(s));
1.0.0 · Source

impl<T, A> Hash for BTreeSet<T, A>
where T: Hash, A: Allocator + Clone,

1.0.0 · Source

impl<T, A> Hash for VecDeque<T, A>
where T: Hash, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for topsoil_core::runtime::std::prelude::Box<T, A>
where T: Hash + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for Rc<T, A>
where T: Hash + ?Sized, A: Allocator,

Source

impl<T, A> Hash for UniqueRc<T, A>
where T: Hash + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for Arc<T, A>
where T: Hash + ?Sized, A: Allocator,

Source

impl<T, A> Hash for UniqueArc<T, A>
where T: Hash + ?Sized, A: Allocator,

Source

impl<T, A> Hash for allocator_api2::stable::boxed::Box<T, A>
where T: Hash + ?Sized, A: Allocator,

Source

impl<T, A> Hash for allocator_api2::stable::vec::Vec<T, A>
where T: Hash, A: Allocator,

The hash of a vector is the same as that of the corresponding slice, as required by the core::borrow::Borrow implementation.

#![feature(build_hasher_simple_hash_one)]
use std::hash::BuildHasher;

let b = std::collections::hash_map::RandomState::new();
let v: Vec<u8> = vec![0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(v), b.hash_one(s));
1.0.0 · Source

impl<T, E> Hash for Result<T, E>
where T: Hash, E: Hash,

Source

impl<T, N> Hash for GenericArray<T, N>
where T: Hash, N: ArrayLength<T>,

Source

impl<T, S> Hash for BoundedBTreeSet<T, S>
where T: Hash,

Available on crate feature std only.
Source

impl<T, S> Hash for BoundedVec<T, S>
where T: Hash,

Available on crate feature std only.
Source

impl<T, const CAP: usize> Hash for arrayvec::arrayvec::ArrayVec<T, CAP>
where T: Hash,

1.0.0 · Source

impl<T, const N: usize> Hash for [T; N]
where T: Hash,

The hash of an array is the same as that of the corresponding slice, as required by the Borrow implementation.

use std::hash::BuildHasher;

let b = std::hash::RandomState::new();
let a: [u8; 3] = [0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(a), b.hash_one(s));
Source

impl<T, const N: usize> Hash for Simd<T, N>
where T: SimdElement + Hash,

Source

impl<U> Hash for NInt<U>
where U: Hash + Unsigned + NonZero,

Source

impl<U> Hash for PInt<U>
where U: Hash + Unsigned + NonZero,

Source

impl<U, B> Hash for UInt<U, B>
where U: Hash, B: Hash,

Source

impl<V, A> Hash for TArr<V, A>
where V: Hash, A: Hash,

Source

impl<Y, R> Hash for CoroutineState<Y, R>
where Y: Hash, R: Hash,

Source

impl<const CAP: usize> Hash for ArrayString<CAP>

Source

impl<const LIMBS: usize> Hash for Uint<LIMBS>

Source

impl<const MIN: i8, const MAX: i8> Hash for OptionRangedI8<MIN, MAX>

Source

impl<const MIN: i8, const MAX: i8> Hash for RangedI8<MIN, MAX>

Source

impl<const MIN: i16, const MAX: i16> Hash for OptionRangedI16<MIN, MAX>

Source

impl<const MIN: i16, const MAX: i16> Hash for RangedI16<MIN, MAX>

Source

impl<const MIN: i32, const MAX: i32> Hash for OptionRangedI32<MIN, MAX>

Source

impl<const MIN: i32, const MAX: i32> Hash for RangedI32<MIN, MAX>

Source

impl<const MIN: i64, const MAX: i64> Hash for OptionRangedI64<MIN, MAX>

Source

impl<const MIN: i64, const MAX: i64> Hash for RangedI64<MIN, MAX>

Source

impl<const MIN: i128, const MAX: i128> Hash for OptionRangedI128<MIN, MAX>

Source

impl<const MIN: i128, const MAX: i128> Hash for RangedI128<MIN, MAX>

Source

impl<const MIN: isize, const MAX: isize> Hash for OptionRangedIsize<MIN, MAX>

Source

impl<const MIN: isize, const MAX: isize> Hash for RangedIsize<MIN, MAX>

Source

impl<const MIN: u8, const MAX: u8> Hash for OptionRangedU8<MIN, MAX>

Source

impl<const MIN: u8, const MAX: u8> Hash for RangedU8<MIN, MAX>

Source

impl<const MIN: u16, const MAX: u16> Hash for OptionRangedU16<MIN, MAX>

Source

impl<const MIN: u16, const MAX: u16> Hash for RangedU16<MIN, MAX>

Source

impl<const MIN: u32, const MAX: u32> Hash for OptionRangedU32<MIN, MAX>

Source

impl<const MIN: u32, const MAX: u32> Hash for RangedU32<MIN, MAX>

Source

impl<const MIN: u64, const MAX: u64> Hash for OptionRangedU64<MIN, MAX>

Source

impl<const MIN: u64, const MAX: u64> Hash for RangedU64<MIN, MAX>

Source

impl<const MIN: u128, const MAX: u128> Hash for OptionRangedU128<MIN, MAX>

Source

impl<const MIN: u128, const MAX: u128> Hash for RangedU128<MIN, MAX>

Source

impl<const MIN: usize, const MAX: usize> Hash for OptionRangedUsize<MIN, MAX>

Source

impl<const MIN: usize, const MAX: usize> Hash for RangedUsize<MIN, MAX>

Source

impl<const N: usize, T> Hash for CryptoBytes<N, T>

Source

impl<const N: usize, const UPPERCASE: bool> Hash for serdect::array::HexOrBin<N, UPPERCASE>

Source

impl<const SIZE: usize> Hash for WriteBuffer<SIZE>

Source

impl<const UPPERCASE: bool> Hash for serdect::slice::HexOrBin<UPPERCASE>