pub trait Copy: Clone { }Expand description
Types whose values can be duplicated simply by copying bits.
By default, variable bindings have ‘move semantics.’ In other words:
#[derive(Debug)]
struct Foo;
let x = Foo;
let y = x;
// `x` has moved into `y`, and so cannot be used
// println!("{x:?}"); // error: use of moved valueHowever, if a type implements Copy, it instead has ‘copy semantics’:
// We can derive a `Copy` implementation. `Clone` is also required, as it's
// a supertrait of `Copy`.
#[derive(Debug, Copy, Clone)]
struct Foo;
let x = Foo;
let y = x;
// `y` is a copy of `x`
println!("{x:?}"); // A-OK!It’s important to note that in these two examples, the only difference is whether you
are allowed to access x after the assignment. Under the hood, both a copy and a move
can result in bits being copied in memory, although this is sometimes optimized away.
How can I implement Copy?
There are two ways to implement Copy on your type. The simplest is to use derive:
#[derive(Copy, Clone)]
struct MyStruct;You can also implement Copy and Clone manually:
struct MyStruct;
impl Copy for MyStruct { }
impl Clone for MyStruct {
fn clone(&self) -> MyStruct {
*self
}
}There is a small difference between the two. The derive strategy will also place a Copy
bound on type parameters:
#[derive(Clone)]
struct MyStruct<T>(T);
impl<T: Copy> Copy for MyStruct<T> { }This isn’t always desired. For example, shared references (&T) can be copied regardless of
whether T is Copy. Likewise, a generic struct containing markers such as PhantomData
could potentially be duplicated with a bit-wise copy.
What’s the difference between Copy and Clone?
Copies happen implicitly, for example as part of an assignment y = x. The behavior of
Copy is not overloadable; it is always a simple bit-wise copy.
Cloning is an explicit action, x.clone(). The implementation of Clone can
provide any type-specific behavior necessary to duplicate values safely. For example,
the implementation of Clone for String needs to copy the pointed-to string
buffer in the heap. A simple bitwise copy of String values would merely copy the
pointer, leading to a double free down the line. For this reason, String is Clone
but not Copy.
Clone is a supertrait of Copy, so everything which is Copy must also implement
Clone. If a type is Copy then its Clone implementation only needs to return *self
(see the example above).
When can my type be Copy?
A type can implement Copy if all of its components implement Copy. For example, this
struct can be Copy:
#[derive(Copy, Clone)]
struct Point {
x: i32,
y: i32,
}A struct can be Copy, and i32 is Copy, therefore Point is eligible to be Copy.
By contrast, consider
struct PointList {
points: Vec<Point>,
}The struct PointList cannot implement Copy, because Vec<T> is not Copy. If we
attempt to derive a Copy implementation, we’ll get an error:
the trait `Copy` cannot be implemented for this type; field `points` does not implement `Copy`Shared references (&T) are also Copy, so a type can be Copy, even when it holds
shared references of types T that are not Copy. Consider the following struct,
which can implement Copy, because it only holds a shared reference to our non-Copy
type PointList from above:
#[derive(Copy, Clone)]
struct PointListWrapper<'a> {
point_list_ref: &'a PointList,
}When can’t my type be Copy?
Some types can’t be copied safely. For example, copying &mut T would create an aliased
mutable reference. Copying String would duplicate responsibility for managing the
String’s buffer, leading to a double free.
Generalizing the latter case, any type implementing Drop can’t be Copy, because it’s
managing some resource besides its own size_of::<T> bytes.
If you try to implement Copy on a struct or enum containing non-Copy data, you will get
the error E0204.
When should my type be Copy?
Generally speaking, if your type can implement Copy, it should. Keep in mind, though,
that implementing Copy is part of the public API of your type. If the type might become
non-Copy in the future, it could be prudent to omit the Copy implementation now, to
avoid a breaking API change.
Additional implementors
In addition to the implementors listed below,
the following types also implement Copy:
- Function item types (i.e., the distinct types defined for each function)
- Function pointer types (e.g.,
fn() -> i32) - Closure types, if they capture no value from the environment
or if all such captured values implement
Copythemselves. Note that variables captured by shared reference always implementCopy(even if the referent doesn’t), while variables captured by mutable reference never implementCopy.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
impl Copy for DispatchClass
impl Copy for Pays
impl Copy for FailedMigrationHandling
impl Copy for topsoil_core::pallet_prelude::DispatchError
impl Copy for InvalidTransaction
impl Copy for TransactionSource
impl Copy for TransactionValidityError
impl Copy for UnknownTransaction
impl Copy for ChildType
impl Copy for ProcessMessageError
impl Copy for TrieError
impl Copy for Judgement
impl Copy for Truth
impl Copy for BalanceStatus
impl Copy for DepositConsequence
impl Copy for ExistenceRequirement
impl Copy for Fortitude
impl Copy for Precision
impl Copy for Preservation
impl Copy for Provenance
impl Copy for Restriction
impl Copy for Ss58AddressFormatRegistry
impl Copy for LogLevelFilter
impl Copy for RuntimeInterfaceLogLevel
impl Copy for CallContext
impl Copy for DeriveJunction
impl Copy for ArithmeticError
impl Copy for ExtrinsicInclusionMode
impl Copy for Rounding
impl Copy for StateVersion
impl Copy for TokenError
impl Copy for TransactionalError
impl Copy for Era
impl Copy for topsoil_core::runtime::legacy::byte_sized_error::DispatchError
impl Copy for HttpError
impl Copy for HttpRequestStatus
impl Copy for StorageKind
impl Copy for MetaForm
impl Copy for PortableForm
impl Copy for topsoil_core::runtime::std::cmp::Ordering
impl Copy for Infallible
impl Copy for topsoil_core::runtime::std::fmt::Alignment
impl Copy for DebugAsHex
impl Copy for Sign
impl Copy for FpCategory
impl Copy for IntErrorKind
impl Copy for SearchStep
impl Copy for topsoil_core::runtime::std::sync::atomic::Ordering
impl Copy for RecvTimeoutError
impl Copy for topsoil_core::runtime::std::sync::mpmc::TryRecvError
impl Copy for AsciiChar
impl Copy for FromBytesWithNulError
impl Copy for Locality
impl Copy for IpAddr
impl Copy for Ipv6MulticastScope
impl Copy for SocketAddr
impl Copy for SeekFrom
impl Copy for std::io::error::ErrorKind
impl Copy for Shutdown
impl Copy for BacktraceStyle
impl Copy for AhoCorasickKind
impl Copy for aho_corasick::packed::api::MatchKind
impl Copy for aho_corasick::util::search::Anchored
impl Copy for aho_corasick::util::search::MatchKind
impl Copy for StartKind
impl Copy for PrintFmt
impl Copy for DecodePaddingMode
impl Copy for bip39::Error
impl Copy for Language
impl Copy for bs58::alphabet::Error
impl Copy for bs58::decode::Error
impl Copy for bs58::encode::Error
impl Copy for byteorder::BigEndian
impl Copy for byteorder::LittleEndian
impl Copy for const_oid::error::Error
impl Copy for const_format::__ascii_case_conv::Case
impl Copy for der::error::ErrorKind
impl Copy for Class
impl Copy for der::tag::Tag
impl Copy for TagMode
impl Copy for TruncSide
impl Copy for ed25519_zebra::error::Error
impl Copy for Phase
impl Copy for futures_channel::mpsc::TryRecvError
impl Copy for PollNext
impl Copy for DwarfFileType
impl Copy for Format
impl Copy for SectionId
impl Copy for Vendor
impl Copy for RunTimeEndian
impl Copy for AbbreviationsCacheStrategy
impl Copy for gimli::read::cfi::Pointer
impl Copy for gimli::read::Error
impl Copy for IndexSectionId
impl Copy for ColumnType
impl Copy for gimli::read::value::Value
impl Copy for gimli::read::value::ValueType
impl Copy for hex_conservative::Case
impl Copy for hex::error::FromHexError
impl Copy for itertools::with_position::Position
impl Copy for DIR
impl Copy for FILE
impl Copy for timezone
impl Copy for tpacket_versions
impl Copy for libsecp256k1_core::error::Error
impl Copy for log::Level
impl Copy for log::LevelFilter
impl Copy for PrefilterConfig
impl Copy for DataFormat
impl Copy for MZError
impl Copy for MZFlush
impl Copy for MZStatus
impl Copy for TINFLStatus
impl Copy for TargetGround
impl Copy for Color
impl Copy for Grouping
impl Copy for Locale
impl Copy for AddressSize
impl Copy for Architecture
impl Copy for BinaryFormat
impl Copy for ComdatKind
impl Copy for FileFlags
impl Copy for RelocationEncoding
impl Copy for RelocationFlags
impl Copy for RelocationKind
impl Copy for SectionFlags
impl Copy for SectionKind
impl Copy for SegmentFlags
impl Copy for SubArchitecture
impl Copy for SymbolKind
impl Copy for SymbolScope
impl Copy for Endianness
impl Copy for PtrauthKey
impl Copy for ArchiveKind
impl Copy for ImportType
impl Copy for CompressionFormat
impl Copy for FileKind
impl Copy for ObjectKind
impl Copy for RelocationTarget
impl Copy for SymbolSection
impl Copy for Internal
impl Copy for External
impl Copy for ImportCountType
impl Copy for RelocationEntry
impl Copy for BlockType
impl Copy for TableElementType
impl Copy for parity_wasm::elements::types::ValueType
impl Copy for OnceState
impl Copy for FilterOp
impl Copy for ParkResult
impl Copy for RequeueOp
impl Copy for pkcs8::error::Error
impl Copy for pkcs8::version::Version
impl Copy for BernoulliError
impl Copy for WeightedError
impl Copy for WhichCaptures
impl Copy for regex_automata::util::look::Look
impl Copy for regex_automata::util::search::Anchored
impl Copy for regex_automata::util::search::MatchKind
impl Copy for regex_syntax::ast::ClassSetBinaryOpKind
impl Copy for regex_syntax::ast::ClassSetBinaryOpKind
impl Copy for regex_syntax::ast::Flag
impl Copy for regex_syntax::ast::Flag
impl Copy for Dot
impl Copy for regex_syntax::hir::Look
impl Copy for regex_syntax::utf8::Utf8Sequence
impl Copy for regex_syntax::utf8::Utf8Sequence
impl Copy for rustc_hex::FromHexError
impl Copy for MultiSignatureStage
impl Copy for SignatureError
impl Copy for sec1::error::Error
impl Copy for EcParameters
impl Copy for sec1::point::Tag
impl Copy for All
impl Copy for SignOnly
impl Copy for VerifyOnly
impl Copy for ElligatorSwiftParty
impl Copy for secp256k1::Error
impl Copy for Parity
impl Copy for Category
impl Copy for spki::error::Error
impl Copy for TokenRegistry
impl Copy for strum::ParseError
impl Copy for SignedRounding
impl Copy for AllowedSlots
impl Copy for TransactionType
impl Copy for subsoil::keyring::ed25519::Keyring
impl Copy for subsoil::keyring::sr25519::Keyring
impl Copy for subsoil::version::embed::Error
impl Copy for ReturnValue
impl Copy for subsoil::wasm_interface::Value
impl Copy for subsoil::wasm_interface::ValueType
impl Copy for time::format_description::component::Component
impl Copy for MonthRepr
impl Copy for Padding
impl Copy for SubsecondDigits
impl Copy for TrailingInput
impl Copy for UnixTimestampPrecision
impl Copy for WeekNumberRepr
impl Copy for WeekdayRepr
impl Copy for YearRange
impl Copy for YearRepr
impl Copy for DateKind
impl Copy for FormattedComponents
impl Copy for OffsetPrecision
impl Copy for TimePrecision
impl Copy for time::month::Month
impl Copy for time::weekday::Weekday
impl Copy for RecordedForKey
impl Copy for FromStrRadixErrKind
impl Copy for zerocopy::byteorder::BigEndian
impl Copy for zerocopy::byteorder::LittleEndian
impl Copy for bool
impl Copy for char
impl Copy for f16
impl Copy for f32
impl Copy for f64
impl Copy for f128
impl Copy for i8
impl Copy for i16
impl Copy for i32
impl Copy for i64
impl Copy for i128
impl Copy for isize
impl Copy for !
impl Copy for u8
impl Copy for u16
impl Copy for u32
impl Copy for u64
impl Copy for u128
impl Copy for usize
impl Copy for DispatchInfo
impl Copy for PostDispatchInfo
impl Copy for Instance1
impl Copy for PalletId
impl Copy for DispatchEventInfo
impl Copy for BatchFootprint
impl Copy for CrateVersion
impl Copy for Footprint
impl Copy for PalletInfoData
impl Copy for QueueFootprint
impl Copy for StorageVersion
impl Copy for WithdrawReasons
impl Copy for RuntimeDbWeight
impl Copy for Weight
impl Copy for Ss58AddressFormat
impl Copy for H160
impl Copy for H512
impl Copy for U256
impl Copy for U512
impl Copy for topsoil_core::runtime::app_crypto::ed25519::Pair
impl Copy for topsoil_core::runtime::codec::OptionBool
impl Copy for topsoil_core::runtime::legacy::byte_sized_error::ModuleError
impl Copy for Capabilities
impl Copy for topsoil_core::runtime::offchain::Duration
impl Copy for HttpRequestId
impl Copy for topsoil_core::runtime::offchain::Timestamp
impl Copy for Instant
impl Copy for topsoil_core::runtime::scale_info::prelude::time::SystemTime
impl Copy for MetaType
impl Copy for IgnoredAny
impl Copy for CryptoTypeId
impl Copy for FixedI64
impl Copy for FixedI128
impl Copy for FixedU64
impl Copy for FixedU128
impl Copy for KeyTypeId
impl Copy for topsoil_core::runtime::ModuleError
impl Copy for PerU16
impl Copy for Perbill
impl Copy for Percent
impl Copy for Permill
impl Copy for Perquintill
impl Copy for Rational128
impl Copy for H256
impl Copy for topsoil_core::runtime::std::alloc::AllocError
impl Copy for topsoil_core::runtime::std::alloc::Global
impl Copy for Layout
impl Copy for System
impl Copy for TypeId
impl Copy for topsoil_core::runtime::std::fmt::Error
impl Copy for FormattingOptions
impl Copy for Assume
impl Copy for topsoil_core::runtime::std::num::TryFromIntError
impl Copy for RangeFull
impl Copy for topsoil_core::runtime::std::ptr::Alignment
impl Copy for Utf8Error
impl Copy for topsoil_core::runtime::std::sync::mpmc::RecvError
impl Copy for topsoil_core::runtime::std::sync::WaitTimeoutResult
impl Copy for topsoil_core::runtime::std::time::Duration
impl Copy for core::array::TryFromSliceError
impl Copy for CharTryFromError
impl Copy for TryFromCharError
impl Copy for CpuidResult
impl Copy for __m128
impl Copy for __m128bh
impl Copy for __m128d
impl Copy for __m128h
impl Copy for __m128i
impl Copy for __m256
impl Copy for __m256bh
impl Copy for __m256d
impl Copy for __m256h
impl Copy for __m256i
impl Copy for __m512
impl Copy for __m512bh
impl Copy for __m512d
impl Copy for __m512h
impl Copy for __m512i
impl Copy for bf16
impl Copy for Ipv4Addr
impl Copy for Ipv6Addr
impl Copy for SocketAddrV4
impl Copy for SocketAddrV6
impl Copy for RawWakerVTable
impl Copy for FileTimes
impl Copy for FileType
impl Copy for Empty
impl Copy for Sink
impl Copy for UCred
impl Copy for ExitCode
impl Copy for ExitStatus
impl Copy for ExitStatusError
impl Copy for DefaultRandomSource
impl Copy for ThreadId
impl Copy for AccessError
impl Copy for Adler32
impl Copy for aho_corasick::util::primitives::PatternID
impl Copy for aho_corasick::util::primitives::StateID
impl Copy for aho_corasick::util::search::Match
impl Copy for aho_corasick::util::search::Span
impl Copy for allocator_api2::stable::alloc::global::Global
impl Copy for allocator_api2::stable::alloc::AllocError
impl Copy for GeneralPurposeConfig
impl Copy for AmbiguousLanguages
impl Copy for bitcoin_hashes::hash160::Hash
impl Copy for bitcoin_hashes::ripemd160::Hash
impl Copy for bitcoin_hashes::sha1::Hash
impl Copy for bitcoin_hashes::sha256::Hash
impl Copy for Midstate
impl Copy for bitcoin_hashes::sha256d::Hash
impl Copy for bitcoin_hashes::sha384::Hash
impl Copy for bitcoin_hashes::sha512::Hash
impl Copy for bitcoin_hashes::sha512_256::Hash
impl Copy for bitcoin_hashes::siphash24::Hash
impl Copy for blake2b_simd::Hash
impl Copy for Eager
impl Copy for block_buffer::Error
impl Copy for Lazy
impl Copy for Alphabet
impl Copy for ObjectIdentifier
impl Copy for SplicedStr
impl Copy for CtChoice
impl Copy for Limb
impl Copy for Reciprocal
impl Copy for InvalidLength
impl Copy for CompressedEdwardsY
impl Copy for EdwardsPoint
impl Copy for MontgomeryPoint
impl Copy for CompressedRistretto
impl Copy for RistrettoPoint
impl Copy for curve25519_dalek::scalar::Scalar
impl Copy for GeneralizedTime
impl Copy for Null
impl Copy for UtcTime
impl Copy for DateTime
impl Copy for der::error::Error
impl Copy for der::header::Header
impl Copy for IndefiniteLength
impl Copy for Length
impl Copy for TagNumber
impl Copy for deranged::TryFromIntError
impl Copy for digest::errors::InvalidOutputSize
impl Copy for MacError
impl Copy for InvalidBufferSize
impl Copy for digest::InvalidOutputSize
impl Copy for ecdsa::recovery::RecoveryId
impl Copy for ed25519_dalek::verifying::VerifyingKey
impl Copy for SigningKey
impl Copy for VerificationKey
impl Copy for VerificationKeyBytes
impl Copy for ed25519::Signature
impl Copy for elliptic_curve::error::Error
impl Copy for foldhash::fast::FixedState
impl Copy for foldhash::fast::RandomState
impl Copy for foldhash::fast::SeedableRandomState
impl Copy for foldhash::quality::FixedState
impl Copy for foldhash::quality::RandomState
impl Copy for foldhash::quality::SeedableRandomState
impl Copy for futures_channel::mpsc::RecvError
impl Copy for Canceled
impl Copy for Aborted
impl Copy for getrandom::error::Error
impl Copy for getrandom::error::Error
impl Copy for AArch64
impl Copy for Arm
impl Copy for LoongArch
impl Copy for MIPS
impl Copy for PowerPc64
impl Copy for RiscV
impl Copy for X86
impl Copy for X86_64
impl Copy for DebugTypeSignature
impl Copy for DwoId
impl Copy for Encoding
impl Copy for LineEncoding
impl Copy for Register
impl Copy for DwAccess
impl Copy for DwAddr
impl Copy for DwAt
impl Copy for DwAte
impl Copy for DwCc
impl Copy for DwCfa
impl Copy for DwChildren
impl Copy for DwDefaulted
impl Copy for DwDs
impl Copy for DwDsc
impl Copy for DwEhPe
impl Copy for DwEnd
impl Copy for DwForm
impl Copy for DwId
impl Copy for DwIdx
impl Copy for DwInl
impl Copy for DwLang
impl Copy for DwLle
impl Copy for DwLnct
impl Copy for DwLne
impl Copy for DwLns
impl Copy for DwMacinfo
impl Copy for DwMacro
impl Copy for DwOp
impl Copy for DwOrd
impl Copy for DwRle
impl Copy for DwSect
impl Copy for DwSectV2
impl Copy for DwTag
impl Copy for DwUt
impl Copy for DwVirtuality
impl Copy for DwVis
impl Copy for gimli::endianity::BigEndian
impl Copy for gimli::endianity::LittleEndian
impl Copy for AttributeSpecification
impl Copy for Augmentation
impl Copy for UnitIndexSection
impl Copy for FileEntryFormat
impl Copy for LineRow
impl Copy for ReaderOffsetId
impl Copy for gimli::read::rnglists::Range
impl Copy for StoreOnHeap
impl Copy for itoa::Buffer
impl Copy for jam_codec::codec::OptionBool
impl Copy for AffinePoint
impl Copy for ProjectivePoint
impl Copy for k256::arithmetic::scalar::Scalar
impl Copy for Secp256k1
impl Copy for rtentry
impl Copy for bcm_msg_head
impl Copy for bcm_timeval
impl Copy for j1939_filter
impl Copy for __c_anonymous_sockaddr_can_j1939
impl Copy for __c_anonymous_sockaddr_can_tp
impl Copy for can_filter
impl Copy for can_frame
impl Copy for canfd_frame
impl Copy for canxl_frame
impl Copy for sockaddr_can
impl Copy for nl_mmap_hdr
impl Copy for nl_mmap_req
impl Copy for nl_pktinfo
impl Copy for nlattr
impl Copy for nlmsgerr
impl Copy for nlmsghdr
impl Copy for sockaddr_nl
impl Copy for termios2
impl Copy for msqid_ds
impl Copy for semid_ds
impl Copy for sigset_t
impl Copy for sysinfo
impl Copy for timex
impl Copy for statvfs
impl Copy for _libc_fpstate
impl Copy for _libc_fpxreg
impl Copy for _libc_xmmreg
impl Copy for clone_args
impl Copy for flock64
impl Copy for flock
impl Copy for ipc_perm
impl Copy for max_align_t
impl Copy for mcontext_t
impl Copy for pthread_attr_t
impl Copy for ptrace_rseq_configuration
impl Copy for shmid_ds
impl Copy for sigaction
impl Copy for siginfo_t
impl Copy for stack_t
impl Copy for stat64
impl Copy for stat
impl Copy for statfs64
impl Copy for statfs
impl Copy for statvfs64
impl Copy for ucontext_t
impl Copy for user
impl Copy for user_fpregs_struct
impl Copy for user_regs_struct
impl Copy for Elf32_Chdr
impl Copy for Elf64_Chdr
impl Copy for __c_anonymous_ptrace_syscall_info_entry
impl Copy for __c_anonymous_ptrace_syscall_info_exit
impl Copy for __c_anonymous_ptrace_syscall_info_seccomp
impl Copy for __exit_status
impl Copy for __timeval
impl Copy for aiocb
impl Copy for cmsghdr
impl Copy for fanotify_event_info_error
impl Copy for fanotify_event_info_pidfd
impl Copy for fpos64_t
impl Copy for fpos_t
impl Copy for glob64_t
impl Copy for iocb
impl Copy for mallinfo2
impl Copy for mallinfo
impl Copy for mbstate_t
impl Copy for msghdr
impl Copy for ntptimeval
impl Copy for ptrace_peeksiginfo_args
impl Copy for ptrace_sud_config
impl Copy for ptrace_syscall_info
impl Copy for regex_t
impl Copy for sem_t
impl Copy for seminfo
impl Copy for tcp_info
impl Copy for termios
impl Copy for timespec
impl Copy for utmpx
impl Copy for __c_anonymous__kernel_fsid_t
impl Copy for af_alg_iv
impl Copy for dmabuf_cmsg
impl Copy for dmabuf_token
impl Copy for dqblk
impl Copy for epoll_params
impl Copy for fanotify_event_info_fid
impl Copy for fanotify_event_info_header
impl Copy for fanotify_event_metadata
impl Copy for fanotify_response
impl Copy for fanout_args
impl Copy for ff_condition_effect
impl Copy for ff_constant_effect
impl Copy for ff_effect
impl Copy for ff_envelope
impl Copy for ff_periodic_effect
impl Copy for ff_ramp_effect
impl Copy for ff_replay
impl Copy for ff_rumble_effect
impl Copy for ff_trigger
impl Copy for genlmsghdr
impl Copy for hwtstamp_config
impl Copy for in6_ifreq
impl Copy for inotify_event
impl Copy for input_absinfo
impl Copy for input_event
impl Copy for input_id
impl Copy for input_keymap_entry
impl Copy for input_mask
impl Copy for iw_discarded
impl Copy for iw_encode_ext
impl Copy for iw_event
impl Copy for iw_freq
impl Copy for iw_michaelmicfailure
impl Copy for iw_missed
impl Copy for iw_mlme
impl Copy for iw_param
impl Copy for iw_pmkid_cand
impl Copy for iw_pmksa
impl Copy for iw_point
impl Copy for iw_priv_args
impl Copy for iw_quality
impl Copy for iw_range
impl Copy for iw_scan_req
impl Copy for iw_statistics
impl Copy for iw_thrspy
impl Copy for iwreq
impl Copy for mnt_ns_info
impl Copy for mount_attr
impl Copy for mq_attr
impl Copy for msginfo
impl Copy for open_how
impl Copy for pidfd_info
impl Copy for posix_spawn_file_actions_t
impl Copy for posix_spawnattr_t
impl Copy for pthread_barrier_t
impl Copy for pthread_barrierattr_t
impl Copy for pthread_cond_t
impl Copy for pthread_condattr_t
impl Copy for pthread_mutex_t
impl Copy for pthread_mutexattr_t
impl Copy for pthread_rwlock_t
impl Copy for pthread_rwlockattr_t
impl Copy for ptp_clock_caps
impl Copy for ptp_clock_time
impl Copy for ptp_extts_event
impl Copy for ptp_extts_request
impl Copy for ptp_perout_request
impl Copy for ptp_pin_desc
impl Copy for ptp_sys_offset
impl Copy for ptp_sys_offset_extended
impl Copy for ptp_sys_offset_precise
impl Copy for sched_attr
impl Copy for sctp_authinfo
impl Copy for sctp_initmsg
impl Copy for sctp_nxtinfo
impl Copy for sctp_prinfo
impl Copy for sctp_rcvinfo
impl Copy for sctp_sndinfo
impl Copy for sctp_sndrcvinfo
impl Copy for seccomp_data
impl Copy for seccomp_notif
impl Copy for seccomp_notif_addfd
impl Copy for seccomp_notif_resp
impl Copy for seccomp_notif_sizes
impl Copy for signalfd_siginfo
impl Copy for sock_extended_err
impl Copy for sock_txtime
impl Copy for sockaddr_alg
impl Copy for sockaddr_pkt
impl Copy for sockaddr_vm
impl Copy for sockaddr_xdp
impl Copy for tls12_crypto_info_aes_ccm_128
impl Copy for tls12_crypto_info_aes_gcm_128
impl Copy for tls12_crypto_info_aes_gcm_256
impl Copy for tls12_crypto_info_aria_gcm_128
impl Copy for tls12_crypto_info_aria_gcm_256
impl Copy for tls12_crypto_info_chacha20_poly1305
impl Copy for tls12_crypto_info_sm4_ccm
impl Copy for tls12_crypto_info_sm4_gcm
impl Copy for tls_crypto_info
impl Copy for tpacket2_hdr
impl Copy for tpacket3_hdr
impl Copy for tpacket_auxdata
impl Copy for tpacket_bd_ts
impl Copy for tpacket_block_desc
impl Copy for tpacket_hdr
impl Copy for tpacket_hdr_v1
impl Copy for tpacket_hdr_variant1
impl Copy for tpacket_req3
impl Copy for tpacket_req
impl Copy for tpacket_rollover_stats
impl Copy for tpacket_stats
impl Copy for tpacket_stats_v3
impl Copy for uinput_abs_setup
impl Copy for uinput_ff_erase
impl Copy for uinput_ff_upload
impl Copy for uinput_setup
impl Copy for uinput_user_dev
impl Copy for xdp_desc
impl Copy for xdp_mmap_offsets
impl Copy for xdp_mmap_offsets_v1
impl Copy for xdp_options
impl Copy for xdp_ring_offset
impl Copy for xdp_ring_offset_v1
impl Copy for xdp_statistics
impl Copy for xdp_statistics_v1
impl Copy for xdp_umem_reg
impl Copy for xdp_umem_reg_v1
impl Copy for xsk_tx_metadata
impl Copy for xsk_tx_metadata_completion
impl Copy for xsk_tx_metadata_request
impl Copy for Elf32_Ehdr
impl Copy for Elf32_Phdr
impl Copy for Elf32_Shdr
impl Copy for Elf32_Sym
impl Copy for Elf64_Ehdr
impl Copy for Elf64_Phdr
impl Copy for Elf64_Shdr
impl Copy for Elf64_Sym
impl Copy for __c_anonymous_elf32_rel
impl Copy for __c_anonymous_elf32_rela
impl Copy for __c_anonymous_elf64_rel
impl Copy for __c_anonymous_elf64_rela
impl Copy for __c_anonymous_ifru_map
impl Copy for arpd_request
impl Copy for cpu_set_t
impl Copy for dirent64
impl Copy for dirent
impl Copy for dl_phdr_info
impl Copy for fsid_t
impl Copy for glob_t
impl Copy for ifconf
impl Copy for ifreq
impl Copy for in6_pktinfo
impl Copy for itimerspec
impl Copy for mntent
impl Copy for option
impl Copy for packet_mreq
impl Copy for passwd
impl Copy for regmatch_t
impl Copy for rlimit64
impl Copy for sembuf
impl Copy for spwd
impl Copy for ucred
impl Copy for Dl_info
impl Copy for addrinfo
impl Copy for arphdr
impl Copy for arpreq
impl Copy for arpreq_old
impl Copy for epoll_event
impl Copy for fd_set
impl Copy for file_clone_range
impl Copy for if_nameindex
impl Copy for ifaddrs
impl Copy for in6_rtmsg
impl Copy for in_addr
impl Copy for in_pktinfo
impl Copy for ip_mreq
impl Copy for ip_mreq_source
impl Copy for ip_mreqn
impl Copy for lconv
impl Copy for mmsghdr
impl Copy for sched_param
impl Copy for sigevent
impl Copy for sock_filter
impl Copy for sock_fprog
impl Copy for sockaddr
impl Copy for sockaddr_in6
impl Copy for sockaddr_in
impl Copy for sockaddr_ll
impl Copy for sockaddr_storage
impl Copy for sockaddr_un
impl Copy for statx
impl Copy for statx_timestamp
impl Copy for tm
impl Copy for utsname
impl Copy for group
impl Copy for hostent
impl Copy for in6_addr
impl Copy for iovec
impl Copy for ipv6_mreq
impl Copy for itimerval
impl Copy for linger
impl Copy for pollfd
impl Copy for protoent
impl Copy for rlimit
impl Copy for rusage
impl Copy for servent
impl Copy for sigval
impl Copy for timeval
impl Copy for tms
impl Copy for utimbuf
impl Copy for winsize
impl Copy for Field
impl Copy for FieldStorage
impl Copy for Affine
impl Copy for AffineStorage
impl Copy for Jacobian
impl Copy for libsecp256k1_core::scalar::Scalar
impl Copy for libsecp256k1::Message
impl Copy for libsecp256k1::PublicKey
impl Copy for libsecp256k1::RecoveryId
impl Copy for libsecp256k1::SecretKey
impl Copy for libsecp256k1::Signature
impl Copy for memchr::arch::all::memchr::One
impl Copy for memchr::arch::all::memchr::Three
impl Copy for memchr::arch::all::memchr::Two
impl Copy for memchr::arch::all::packedpair::Finder
impl Copy for memchr::arch::all::packedpair::Pair
impl Copy for memchr::arch::all::twoway::Finder
impl Copy for FinderRev
impl Copy for memchr::arch::x86_64::avx2::memchr::One
impl Copy for memchr::arch::x86_64::avx2::memchr::Three
impl Copy for memchr::arch::x86_64::avx2::memchr::Two
impl Copy for memchr::arch::x86_64::avx2::packedpair::Finder
impl Copy for memchr::arch::x86_64::sse2::memchr::One
impl Copy for memchr::arch::x86_64::sse2::memchr::Three
impl Copy for memchr::arch::x86_64::sse2::memchr::Two
impl Copy for memchr::arch::x86_64::sse2::packedpair::Finder
impl Copy for StreamResult
impl Copy for Infix
impl Copy for nu_ansi_term::ansi::Prefix
impl Copy for Suffix
impl Copy for Gradient
impl Copy for Rgb
impl Copy for Style
impl Copy for num_format::buffer::Buffer
impl Copy for AixFileHeader
impl Copy for AixHeader
impl Copy for AixMemberOffset
impl Copy for object::archive::Header
impl Copy for Ident
impl Copy for object::endian::BigEndian
impl Copy for object::endian::LittleEndian
impl Copy for DyldCacheSlidePointer3
impl Copy for DyldCacheSlidePointer5
impl Copy for FatArch32
impl Copy for FatArch64
impl Copy for FatHeader
impl Copy for RelocationInfo
impl Copy for ScatteredRelocationInfo
impl Copy for AnonObjectHeader
impl Copy for AnonObjectHeaderBigobj
impl Copy for AnonObjectHeaderV2
impl Copy for Guid
impl Copy for ImageAlpha64RuntimeFunctionEntry
impl Copy for ImageAlphaRuntimeFunctionEntry
impl Copy for ImageArchitectureEntry
impl Copy for ImageArchiveMemberHeader
impl Copy for ImageArm64RuntimeFunctionEntry
impl Copy for ImageArmRuntimeFunctionEntry
impl Copy for ImageAuxSymbolCrc
impl Copy for ImageAuxSymbolFunction
impl Copy for ImageAuxSymbolFunctionBeginEnd
impl Copy for ImageAuxSymbolSection
impl Copy for ImageAuxSymbolTokenDef
impl Copy for ImageAuxSymbolWeak
impl Copy for ImageBaseRelocation
impl Copy for ImageBoundForwarderRef
impl Copy for ImageBoundImportDescriptor
impl Copy for ImageCoffSymbolsHeader
impl Copy for ImageCor20Header
impl Copy for ImageDataDirectory
impl Copy for ImageDebugDirectory
impl Copy for ImageDebugMisc
impl Copy for ImageDelayloadDescriptor
impl Copy for ImageDosHeader
impl Copy for ImageDynamicRelocation32
impl Copy for ImageDynamicRelocation32V2
impl Copy for ImageDynamicRelocation64
impl Copy for ImageDynamicRelocation64V2
impl Copy for ImageDynamicRelocationTable
impl Copy for ImageEnclaveConfig32
impl Copy for ImageEnclaveConfig64
impl Copy for ImageEnclaveImport
impl Copy for ImageEpilogueDynamicRelocationHeader
impl Copy for ImageExportDirectory
impl Copy for ImageFileHeader
impl Copy for ImageFunctionEntry64
impl Copy for ImageFunctionEntry
impl Copy for ImageHotPatchBase
impl Copy for ImageHotPatchHashes
impl Copy for ImageHotPatchInfo
impl Copy for ImageImportByName
impl Copy for ImageImportDescriptor
impl Copy for ImageLinenumber
impl Copy for ImageLoadConfigCodeIntegrity
impl Copy for ImageLoadConfigDirectory32
impl Copy for ImageLoadConfigDirectory64
impl Copy for ImageNtHeaders32
impl Copy for ImageNtHeaders64
impl Copy for ImageOptionalHeader32
impl Copy for ImageOptionalHeader64
impl Copy for ImageOs2Header
impl Copy for ImagePrologueDynamicRelocationHeader
impl Copy for ImageRelocation
impl Copy for ImageResourceDataEntry
impl Copy for ImageResourceDirStringU
impl Copy for ImageResourceDirectory
impl Copy for ImageResourceDirectoryEntry
impl Copy for ImageResourceDirectoryString
impl Copy for ImageRomHeaders
impl Copy for ImageRomOptionalHeader
impl Copy for ImageRuntimeFunctionEntry
impl Copy for ImageSectionHeader
impl Copy for ImageSeparateDebugHeader
impl Copy for ImageSymbol
impl Copy for ImageSymbolBytes
impl Copy for ImageSymbolEx
impl Copy for ImageSymbolExBytes
impl Copy for ImageThunkData32
impl Copy for ImageThunkData64
impl Copy for ImageTlsDirectory32
impl Copy for ImageTlsDirectory64
impl Copy for ImageVxdHeader
impl Copy for ImportObjectHeader
impl Copy for MaskedRichHeaderEntry
impl Copy for NonPagedDebugInfo
impl Copy for ArchiveOffset
impl Copy for Crel
impl Copy for VersionIndex
impl Copy for object::read::pe::relocation::Relocation
impl Copy for ResourceName
impl Copy for RichHeaderEntry
impl Copy for CompressedFileRange
impl Copy for object::read::Error
impl Copy for SectionIndex
impl Copy for SymbolIndex
impl Copy for AuxHeader32
impl Copy for AuxHeader64
impl Copy for BlockAux32
impl Copy for BlockAux64
impl Copy for CsectAux32
impl Copy for CsectAux64
impl Copy for DwarfAux32
impl Copy for DwarfAux64
impl Copy for ExpAux
impl Copy for FileAux32
impl Copy for FileAux64
impl Copy for object::xcoff::FileHeader32
impl Copy for object::xcoff::FileHeader64
impl Copy for FunAux32
impl Copy for FunAux64
impl Copy for object::xcoff::Rel32
impl Copy for object::xcoff::Rel64
impl Copy for object::xcoff::SectionHeader32
impl Copy for object::xcoff::SectionHeader64
impl Copy for StatAux
impl Copy for Symbol32
impl Copy for Symbol64
impl Copy for SymbolBytes
impl Copy for Func
impl Copy for Local
impl Copy for GlobalType
impl Copy for MemoryType
impl Copy for ResizableLimits
impl Copy for TableType
impl Copy for Uint8
impl Copy for Uint32
impl Copy for Uint64
impl Copy for VarInt7
impl Copy for VarInt32
impl Copy for VarInt64
impl Copy for VarUint1
impl Copy for VarUint7
impl Copy for VarUint32
impl Copy for VarUint64
impl Copy for parking_lot::condvar::WaitTimeoutResult
impl Copy for ParkToken
impl Copy for UnparkResult
impl Copy for UnparkToken
impl Copy for FormatterOptions
impl Copy for NoA1
impl Copy for NoA2
impl Copy for NoNI
impl Copy for NoS3
impl Copy for NoS4
impl Copy for YesA1
impl Copy for YesA2
impl Copy for YesNI
impl Copy for YesS3
impl Copy for YesS4
impl Copy for H128
impl Copy for H384
impl Copy for H768
impl Copy for primitive_types::U128
impl Copy for Bernoulli
impl Copy for Open01
impl Copy for OpenClosed01
impl Copy for Alphanumeric
impl Copy for Standard
impl Copy for UniformChar
impl Copy for UniformDuration
impl Copy for OsRng
impl Copy for LazyStateID
impl Copy for Transition
impl Copy for ByteClasses
impl Copy for Unit
impl Copy for DebugByte
impl Copy for regex_automata::util::look::LookSet
impl Copy for NonMaxUsize
impl Copy for regex_automata::util::primitives::PatternID
impl Copy for SmallIndex
impl Copy for regex_automata::util::primitives::StateID
impl Copy for HalfMatch
impl Copy for regex_automata::util::search::Match
impl Copy for regex_automata::util::search::Span
impl Copy for Config
impl Copy for regex_syntax::ast::Position
impl Copy for regex_syntax::ast::Position
impl Copy for regex_syntax::ast::Span
impl Copy for regex_syntax::ast::Span
impl Copy for regex_syntax::hir::ClassBytesRange
impl Copy for regex_syntax::hir::ClassBytesRange
impl Copy for regex_syntax::hir::ClassUnicodeRange
impl Copy for regex_syntax::hir::ClassUnicodeRange
impl Copy for regex_syntax::hir::LookSet
impl Copy for regex_syntax::utf8::Utf8Range
impl Copy for regex_syntax::utf8::Utf8Range
impl Copy for ByLength
impl Copy for ByMemoryUsage
impl Copy for Unlimited
impl Copy for UnlimitedCompact
impl Copy for AdaptorCertPublic
impl Copy for AdaptorCertSecret
impl Copy for ChainCode
impl Copy for schnorrkel::keys::PublicKey
impl Copy for Commitment
impl Copy for Cosignature
impl Copy for RistrettoBoth
impl Copy for schnorrkel::sign::Signature
impl Copy for VRFPreOut
impl Copy for secp256k1_sys::recovery::RecoverableSignature
impl Copy for secp256k1_sys::ElligatorSwift
impl Copy for secp256k1_sys::Keypair
impl Copy for secp256k1_sys::PublicKey
impl Copy for secp256k1_sys::Signature
impl Copy for secp256k1_sys::XOnlyPublicKey
impl Copy for AlignedType
impl Copy for GlobalContext
impl Copy for secp256k1::ecdsa::recovery::RecoverableSignature
impl Copy for secp256k1::ecdsa::recovery::RecoveryId
impl Copy for SerializedSignature
impl Copy for secp256k1::ecdsa::Signature
impl Copy for secp256k1::ellswift::ElligatorSwift
impl Copy for InvalidParityValue
impl Copy for secp256k1::key::Keypair
impl Copy for secp256k1::key::PublicKey
impl Copy for secp256k1::key::SecretKey
impl Copy for secp256k1::key::XOnlyPublicKey
impl Copy for secp256k1::scalar::Scalar
impl Copy for secp256k1::schnorr::Signature
impl Copy for secp256k1::Message
impl Copy for DefaultConfig
impl Copy for ss58_registry::error::ParseError
impl Copy for Slot
impl Copy for SlotDuration
impl Copy for BalancingConfig
impl Copy for ElectionScore
impl Copy for OffenceSeverity
impl Copy for subsoil::timestamp::Timestamp
impl Copy for HitStatsSnapshot
impl Copy for TrieHitStatsSnapshot
impl Copy for CacheSize
impl Copy for LocalNodeCacheConfig
impl Copy for LocalValueCacheConfig
impl Copy for Choice
impl Copy for time_core::convert::Day
impl Copy for time_core::convert::Hour
impl Copy for Microsecond
impl Copy for Millisecond
impl Copy for time_core::convert::Minute
impl Copy for Nanosecond
impl Copy for time_core::convert::Second
impl Copy for Week
impl Copy for Date
impl Copy for time::duration::Duration
impl Copy for ComponentRange
impl Copy for ConversionRange
impl Copy for DifferentVariant
impl Copy for InvalidVariant
impl Copy for time::format_description::modifier::Day
impl Copy for End
impl Copy for time::format_description::modifier::Hour
impl Copy for Ignore
impl Copy for time::format_description::modifier::Minute
impl Copy for time::format_description::modifier::Month
impl Copy for OffsetHour
impl Copy for OffsetMinute
impl Copy for OffsetSecond
impl Copy for Ordinal
impl Copy for Period
impl Copy for time::format_description::modifier::Second
impl Copy for Subsecond
impl Copy for UnixTimestamp
impl Copy for WeekNumber
impl Copy for time::format_description::modifier::Weekday
impl Copy for Year
impl Copy for Rfc2822
impl Copy for Rfc3339
impl Copy for OffsetDateTime
impl Copy for PrimitiveDateTime
impl Copy for Time
impl Copy for UtcDateTime
impl Copy for UtcOffset
impl Copy for tinyvec::arrayvec::TryFromSliceError
impl Copy for tracing_core::metadata::Level
impl Copy for tracing_core::metadata::LevelFilter
impl Copy for NoSubscriber
impl Copy for FilterId
impl Copy for tracing_subscriber::fmt::format::Compact
impl Copy for Full
impl Copy for tracing_subscriber::fmt::time::SystemTime
impl Copy for Uptime
impl Copy for XxHash64
impl Copy for XxHash32
impl Copy for ATerm
impl Copy for B0
impl Copy for B1
impl Copy for Z0
impl Copy for Equal
impl Copy for Greater
impl Copy for Less
impl Copy for UTerm
impl Copy for zerocopy::error::AllocError
impl Copy for PhantomPinned
impl Copy for __c_anonymous_sockaddr_can_can_addr
impl Copy for __c_anonymous_ptrace_syscall_info_data
impl Copy for __c_anonymous_iwreq
impl Copy for __c_anonymous_ptp_perout_request_1
impl Copy for __c_anonymous_ptp_perout_request_2
impl Copy for __c_anonymous_xsk_tx_metadata_union
impl Copy for iwreq_data
impl Copy for tpacket_bd_header_u
impl Copy for tpacket_req_u
impl Copy for __c_anonymous_ifc_ifcu
impl Copy for __c_anonymous_ifr_ifru
impl Copy for vec128_storage
impl Copy for vec256_storage
impl Copy for vec512_storage
impl<'a> Copy for OpaqueDigestItemId<'a>
impl<'a> Copy for Unexpected<'a>
impl<'a> Copy for Utf8Pattern<'a>
impl<'a> Copy for std::path::Component<'a>
impl<'a> Copy for std::path::Prefix<'a>
impl<'a> Copy for NodeHandle<'a>
impl<'a> Copy for Arguments<'a>
impl<'a> Copy for core::panic::location::Location<'a>
impl<'a> Copy for IoSlice<'a>
impl<'a> Copy for Ancestors<'a>
impl<'a> Copy for PrefixComponent<'a>
impl<'a> Copy for HexDisplay<'a>
impl<'a> Copy for AnyRef<'a>
impl<'a> Copy for BitStringRef<'a>
impl<'a> Copy for Ia5StringRef<'a>
impl<'a> Copy for IntRef<'a>
impl<'a> Copy for UintRef<'a>
impl<'a> Copy for OctetStringRef<'a>
impl<'a> Copy for PrintableStringRef<'a>
impl<'a> Copy for TeletexStringRef<'a>
impl<'a> Copy for Utf8StringRef<'a>
impl<'a> Copy for VideotexStringRef<'a>
impl<'a> Copy for NibbleSlice<'a>
impl<'a> Copy for PhantomContravariantLifetime<'a>
impl<'a> Copy for PhantomCovariantLifetime<'a>
impl<'a> Copy for PhantomInvariantLifetime<'a>
impl<'a, E> Copy for BytesDeserializer<'a, E>
impl<'a, R> Copy for UnitRef<'a, R>where
R: Reader,
impl<'a, R> Copy for ReadCacheRange<'a, R>where
R: ReadCacheOps,
impl<'a, Size> Copy for Coordinates<'a, Size>where
Size: Copy + ModulusSize,
impl<'a, T> Copy for topsoil_core::runtime::codec::CompactRef<'a, T>where
T: Copy,
impl<'a, T> Copy for Symbol<'a, T>where
T: Copy + 'a,
impl<'a, T> Copy for ContextSpecificRef<'a, T>where
T: Copy,
impl<'a, T> Copy for jam_codec::compact::CompactRef<'a, T>where
T: Copy,
impl<'a, T> Copy for Slice<'a, T>where
T: Copy,
impl<'a, T> Copy for PtrInner<'a, T>where
T: 'a + ?Sized,
impl<'a, T, I> Copy for Ptr<'a, T, I>where
T: 'a + ?Sized,
I: Invariants<Aliasing = Shared>,
SAFETY: Shared pointers are safely Copy. Ptr’s other invariants
(besides aliasing) are unaffected by the number of references that exist
to Ptr’s referent. The notable cases are:
-
Alignment is a property of the referent type (
T) and the address, both of which are unchanged -
Let
S(T, V)be the set of bit values permitted to appear in the referent of aPtr<T, I: Invariants<Validity = V>>. Since this copy does not changeI::ValidityorT,S(T, I::Validity)is also unchanged.We are required to guarantee that the referents of the original
Ptrand of the copy (which, of course, are actually the same since they live in the same byte address range) both remain in the setS(T, I::Validity). Since this invariant holds on the originalPtr, it cannot be violated by the originalPtr, and thus the originalPtrcannot be used to violate this invariant on the copy. The inverse holds as well.
impl<'a, T, S> Copy for BoundedSlice<'a, T, S>
impl<'abbrev, 'entry, 'unit, R> Copy for AttrsIter<'abbrev, 'entry, 'unit, R>
impl<'buf> Copy for AllPreallocated<'buf>
impl<'buf> Copy for SignOnlyPreallocated<'buf>
impl<'buf> Copy for VerifyOnlyPreallocated<'buf>
impl<'data> Copy for ImportName<'data>
impl<'data> Copy for ExportTarget<'data>
impl<'data> Copy for object::read::pe::import::Import<'data>
impl<'data> Copy for ArchiveSymbol<'data>
impl<'data> Copy for object::read::coff::section::SectionTable<'data>
impl<'data> Copy for object::read::elf::version::Version<'data>
impl<'data> Copy for DataDirectories<'data>
impl<'data> Copy for object::read::pe::export::Export<'data>
impl<'data> Copy for RelocationBlockIterator<'data>
impl<'data> Copy for ResourceDirectory<'data>
impl<'data> Copy for RichHeaderInfo<'data>
impl<'data> Copy for CodeView<'data>
impl<'data> Copy for CompressedData<'data>
impl<'data> Copy for object::read::Export<'data>
impl<'data> Copy for object::read::Import<'data>
impl<'data> Copy for ObjectMapEntry<'data>
impl<'data> Copy for ObjectMapFile<'data>
impl<'data> Copy for SymbolMapName<'data>
impl<'data> Copy for Bytes<'data>
impl<'data, 'file, Elf, R> Copy for ElfSymbol<'data, 'file, Elf, R>where
Elf: Copy + FileHeader,
R: Copy + ReadRef<'data>,
<Elf as FileHeader>::Endian: Copy,
<Elf as FileHeader>::Sym: Copy,
impl<'data, 'file, Elf, R> Copy for ElfSymbolTable<'data, 'file, Elf, R>
impl<'data, 'file, Mach, R> Copy for MachOSymbol<'data, 'file, Mach, R>
impl<'data, 'file, Mach, R> Copy for MachOSymbolTable<'data, 'file, Mach, R>
impl<'data, 'file, R, Coff> Copy for CoffSymbol<'data, 'file, R, Coff>
impl<'data, 'file, R, Coff> Copy for CoffSymbolTable<'data, 'file, R, Coff>
impl<'data, 'file, Xcoff, R> Copy for XcoffSymbol<'data, 'file, Xcoff, R>
impl<'data, 'file, Xcoff, R> Copy for XcoffSymbolTable<'data, 'file, Xcoff, R>
impl<'data, E> Copy for DyldCacheMappingSlice<'data, E>
impl<'data, E> Copy for DyldCacheSlideInfo<'data, E>
impl<'data, E> Copy for DyldSubCacheSlice<'data, E>
impl<'data, E> Copy for LoadCommandVariant<'data, E>
impl<'data, E> Copy for LoadCommandData<'data, E>
impl<'data, E> Copy for LoadCommandIterator<'data, E>
impl<'data, E, R> Copy for DyldCacheMapping<'data, E, R>
impl<'data, Elf, R> Copy for object::read::elf::section::SectionTable<'data, Elf, R>
impl<'data, Elf, R> Copy for object::read::elf::symbol::SymbolTable<'data, Elf, R>where
Elf: Copy + FileHeader,
R: Copy + ReadRef<'data>,
<Elf as FileHeader>::Sym: Copy,
<Elf as FileHeader>::Endian: Copy,
impl<'data, Mach, R> Copy for object::read::macho::symbol::SymbolTable<'data, Mach, R>
impl<'data, R> Copy for ArchiveFile<'data, R>
impl<'data, R> Copy for StringTable<'data, R>
impl<'data, Xcoff> Copy for object::read::xcoff::section::SectionTable<'data, Xcoff>
impl<'de, E> Copy for BorrowedBytesDeserializer<'de, E>
impl<'de, E> Copy for BorrowedStrDeserializer<'de, E>
impl<'de, E> Copy for StrDeserializer<'de, E>
impl<'fd> Copy for BorrowedFd<'fd>
impl<'h> Copy for regex::regex::bytes::Match<'h>
impl<'h> Copy for regex::regex::string::Match<'h>
impl<'input, Endian> Copy for EndianSlice<'input, Endian>
impl<A> Copy for ArrayVec<A>
impl<A, B> Copy for EitherWriter<A, B>
impl<A, B> Copy for OrElse<A, B>
impl<A, B> Copy for Tee<A, B>
impl<AccountId, Balance> Copy for IndividualExposure<AccountId, Balance>
impl<AuthorityId> Copy for subsoil::consensus::beefy::test_utils::Keyring<AuthorityId>where
AuthorityId: Copy,
impl<B, C> Copy for ControlFlow<B, C>
impl<B, T> Copy for Ref<B, T>
impl<Balance> Copy for PagedExposureMetadata<Balance>
impl<Balance> Copy for Stake<Balance>where
Balance: Copy,
impl<Balance: Copy> Copy for WithdrawConsequence<Balance>
impl<Block> Copy for BlockId<Block>where
Block: Block,
impl<BlockNumber: Copy> Copy for DispatchTime<BlockNumber>
impl<C> Copy for ecdsa::Signature<C>where
C: PrimeCurve,
<<C as Curve>::FieldBytesSize as Add>::Output: ArrayLength<u8>,
<<<C as Curve>::FieldBytesSize as Add>::Output as ArrayLength<u8>>::ArrayType: Copy,
impl<C> Copy for SignatureWithOid<C>where
C: PrimeCurve,
<<C as Curve>::FieldBytesSize as Add>::Output: ArrayLength<u8>,
<<<C as Curve>::FieldBytesSize as Add>::Output as ArrayLength<u8>>::ArrayType: Copy,
digest only.impl<C> Copy for ecdsa::verifying::VerifyingKey<C>where
C: PrimeCurve + CurveArithmetic,
impl<C> Copy for elliptic_curve::public_key::PublicKey<C>where
C: CurveArithmetic,
impl<C> Copy for NonZeroScalar<C>where
C: CurveArithmetic,
impl<C> Copy for ScalarPrimitive<C>
impl<Dyn> Copy for DynMetadata<Dyn>where
Dyn: ?Sized,
impl<E> Copy for BoolDeserializer<E>
impl<E> Copy for CharDeserializer<E>
impl<E> Copy for F32Deserializer<E>
impl<E> Copy for F64Deserializer<E>
impl<E> Copy for I8Deserializer<E>
impl<E> Copy for I16Deserializer<E>
impl<E> Copy for I32Deserializer<E>
impl<E> Copy for I64Deserializer<E>
impl<E> Copy for I128Deserializer<E>
impl<E> Copy for IsizeDeserializer<E>
impl<E> Copy for U8Deserializer<E>
impl<E> Copy for U16Deserializer<E>
impl<E> Copy for U32Deserializer<E>
impl<E> Copy for U64Deserializer<E>
impl<E> Copy for U128Deserializer<E>
impl<E> Copy for UnitDeserializer<E>
impl<E> Copy for UsizeDeserializer<E>
impl<E> Copy for CompressionHeader32<E>
impl<E> Copy for CompressionHeader64<E>
impl<E> Copy for Dyn32<E>
impl<E> Copy for Dyn64<E>
impl<E> Copy for object::elf::FileHeader32<E>
impl<E> Copy for object::elf::FileHeader64<E>
impl<E> Copy for GnuHashHeader<E>
impl<E> Copy for HashHeader<E>
impl<E> Copy for NoteHeader32<E>
impl<E> Copy for NoteHeader64<E>
impl<E> Copy for ProgramHeader32<E>
impl<E> Copy for ProgramHeader64<E>
impl<E> Copy for object::elf::Rel32<E>
impl<E> Copy for object::elf::Rel64<E>
impl<E> Copy for Rela32<E>
impl<E> Copy for Rela64<E>
impl<E> Copy for Relr32<E>
impl<E> Copy for Relr64<E>
impl<E> Copy for object::elf::SectionHeader32<E>
impl<E> Copy for object::elf::SectionHeader64<E>
impl<E> Copy for Sym32<E>
impl<E> Copy for Sym64<E>
impl<E> Copy for Syminfo32<E>
impl<E> Copy for Syminfo64<E>
impl<E> Copy for Verdaux<E>
impl<E> Copy for Verdef<E>
impl<E> Copy for Vernaux<E>
impl<E> Copy for Verneed<E>
impl<E> Copy for Versym<E>
impl<E> Copy for I16Bytes<E>
impl<E> Copy for I32Bytes<E>
impl<E> Copy for I64Bytes<E>
impl<E> Copy for U16Bytes<E>
impl<E> Copy for U32Bytes<E>
impl<E> Copy for U64Bytes<E>
impl<E> Copy for BuildToolVersion<E>
impl<E> Copy for BuildVersionCommand<E>
impl<E> Copy for DataInCodeEntry<E>
impl<E> Copy for DyldCacheHeader<E>
impl<E> Copy for DyldCacheImageInfo<E>
impl<E> Copy for DyldCacheMappingAndSlideInfo<E>
impl<E> Copy for DyldCacheMappingInfo<E>
impl<E> Copy for DyldCacheSlideInfo2<E>
impl<E> Copy for DyldCacheSlideInfo3<E>
impl<E> Copy for DyldCacheSlideInfo5<E>
impl<E> Copy for DyldInfoCommand<E>
impl<E> Copy for DyldSubCacheEntryV1<E>
impl<E> Copy for DyldSubCacheEntryV2<E>
impl<E> Copy for Dylib<E>
impl<E> Copy for DylibCommand<E>
impl<E> Copy for DylibModule32<E>
impl<E> Copy for DylibModule64<E>
impl<E> Copy for DylibReference<E>
impl<E> Copy for DylibTableOfContents<E>
impl<E> Copy for DylinkerCommand<E>
impl<E> Copy for DysymtabCommand<E>
impl<E> Copy for EncryptionInfoCommand32<E>
impl<E> Copy for EncryptionInfoCommand64<E>
impl<E> Copy for EntryPointCommand<E>
impl<E> Copy for FilesetEntryCommand<E>
impl<E> Copy for FvmfileCommand<E>
impl<E> Copy for Fvmlib<E>
impl<E> Copy for FvmlibCommand<E>
impl<E> Copy for IdentCommand<E>
impl<E> Copy for LcStr<E>
impl<E> Copy for LinkeditDataCommand<E>
impl<E> Copy for LinkerOptionCommand<E>
impl<E> Copy for LoadCommand<E>
impl<E> Copy for MachHeader32<E>
impl<E> Copy for MachHeader64<E>
impl<E> Copy for Nlist32<E>
impl<E> Copy for Nlist64<E>
impl<E> Copy for NoteCommand<E>
impl<E> Copy for PrebindCksumCommand<E>
impl<E> Copy for PreboundDylibCommand<E>
impl<E> Copy for object::macho::Relocation<E>
impl<E> Copy for RoutinesCommand32<E>
impl<E> Copy for RoutinesCommand64<E>
impl<E> Copy for RpathCommand<E>
impl<E> Copy for Section32<E>
impl<E> Copy for Section64<E>
impl<E> Copy for SegmentCommand32<E>
impl<E> Copy for SegmentCommand64<E>
impl<E> Copy for SourceVersionCommand<E>
impl<E> Copy for SubClientCommand<E>
impl<E> Copy for SubFrameworkCommand<E>
impl<E> Copy for SubLibraryCommand<E>
impl<E> Copy for SubUmbrellaCommand<E>
impl<E> Copy for SymsegCommand<E>
impl<E> Copy for SymtabCommand<E>
impl<E> Copy for ThreadCommand<E>
impl<E> Copy for TwolevelHint<E>
impl<E> Copy for TwolevelHintsCommand<E>
impl<E> Copy for UuidCommand<E>
impl<E> Copy for VersionMinCommand<E>
impl<F> Copy for RepeatWith<F>where
F: Copy,
impl<HO> Copy for ChildReference<HO>where
HO: Copy,
impl<Idx> Copy for RangeTo<Idx>where
Idx: Copy,
impl<Idx> Copy for topsoil_core::runtime::std::ops::RangeToInclusive<Idx>where
Idx: Copy,
impl<Idx> Copy for core::range::Range<Idx>where
Idx: Copy,
impl<Idx> Copy for RangeFrom<Idx>where
Idx: Copy,
impl<Idx> Copy for RangeInclusive<Idx>where
Idx: Copy,
impl<Idx> Copy for core::range::RangeToInclusive<Idx>where
Idx: Copy,
impl<Info> Copy for DispatchErrorWithPostInfo<Info>
impl<K> Copy for ExtendedKey<K>where
K: Copy,
impl<L, R> Copy for Either<L, R>
impl<M> Copy for WithMaxLevel<M>where
M: Copy,
impl<M> Copy for WithMinLevel<M>where
M: Copy,
impl<M, F> Copy for WithFilter<M, F>
impl<MOD, const LIMBS: usize> Copy for Residue<MOD, LIMBS>where
MOD: Copy + ResidueParams<LIMBS>,
impl<NI> Copy for Avx2Machine<NI>where
NI: Copy,
impl<O> Copy for F32<O>where
O: Copy,
impl<O> Copy for F64<O>where
O: Copy,
impl<O> Copy for I16<O>where
O: Copy,
impl<O> Copy for I32<O>where
O: Copy,
impl<O> Copy for I64<O>where
O: Copy,
impl<O> Copy for I128<O>where
O: Copy,
impl<O> Copy for Isize<O>where
O: Copy,
impl<O> Copy for U16<O>where
O: Copy,
impl<O> Copy for U32<O>where
O: Copy,
impl<O> Copy for U64<O>where
O: Copy,
impl<O> Copy for zerocopy::byteorder::U128<O>where
O: Copy,
impl<O> Copy for Usize<O>where
O: Copy,
impl<Offset> Copy for UnitType<Offset>where
Offset: Copy + ReaderOffset,
impl<P> Copy for MaybeDangling<P>
impl<P> Copy for NonIdentity<P>where
P: Copy,
impl<Params> Copy for AlgorithmIdentifier<Params>where
Params: Copy,
impl<Ptr> Copy for Pin<Ptr>where
Ptr: Copy,
impl<R> Copy for DebugAbbrev<R>where
R: Copy,
impl<R> Copy for DebugAddr<R>where
R: Copy,
impl<R> Copy for DebugAranges<R>where
R: Copy,
impl<R> Copy for DebugFrame<R>
impl<R> Copy for EhFrame<R>
impl<R> Copy for EhFrameHdr<R>
impl<R> Copy for DebugCuIndex<R>where
R: Copy,
impl<R> Copy for DebugTuIndex<R>where
R: Copy,
impl<R> Copy for DebugLine<R>where
R: Copy,
impl<R> Copy for DebugLoc<R>where
R: Copy,
impl<R> Copy for DebugLocLists<R>where
R: Copy,
impl<R> Copy for LocationListEntry<R>
impl<R> Copy for LocationLists<R>where
R: Copy,
impl<R> Copy for DebugMacinfo<R>where
R: Copy,
impl<R> Copy for DebugMacro<R>where
R: Copy,
impl<R> Copy for Expression<R>
impl<R> Copy for OperationIter<R>
impl<R> Copy for DebugRanges<R>where
R: Copy,
impl<R> Copy for DebugRngLists<R>where
R: Copy,
impl<R> Copy for RangeLists<R>where
R: Copy,
impl<R> Copy for DebugLineStr<R>where
R: Copy,
impl<R> Copy for DebugStr<R>where
R: Copy,
impl<R> Copy for DebugStrOffsets<R>where
R: Copy,
impl<R> Copy for Attribute<R>
impl<R> Copy for DebugInfo<R>where
R: Copy,
impl<R> Copy for DebugTypes<R>where
R: Copy,
impl<R, Offset> Copy for LineInstruction<R, Offset>
impl<R, Offset> Copy for gimli::read::op::Location<R, Offset>
impl<R, Offset> Copy for Operation<R, Offset>
impl<R, Offset> Copy for AttributeValue<R, Offset>
impl<R, Offset> Copy for FileEntry<R, Offset>
impl<R, Offset> Copy for Piece<R, Offset>
impl<R, Offset> Copy for UnitHeader<R, Offset>
impl<S3, S4, NI> Copy for SseMachine<S3, S4, NI>
impl<Section, Symbol> Copy for SymbolFlags<Section, Symbol>
impl<Size> Copy for EncodedPoint<Size>where
Size: ModulusSize,
<<Size as ModulusSize>::UncompressedPointSize as ArrayLength<u8>>::ArrayType: Copy,
impl<T> Copy for Bound<T>where
T: Copy,
impl<T> Copy for SendTimeoutError<T>where
T: Copy,
impl<T> Copy for TrySendError<T>where
T: Copy,
impl<T> Copy for Option<T>where
T: Copy,
impl<T> Copy for Poll<T>where
T: Copy,
impl<T> Copy for UnitSectionOffset<T>where
T: Copy,
impl<T> Copy for DieReference<T>where
T: Copy,
impl<T> Copy for itertools::FoldWhile<T>where
T: Copy,
impl<T> Copy for itertools::FoldWhile<T>where
T: Copy,
impl<T> Copy for itertools::minmax::MinMaxResult<T>where
T: Copy,
impl<T> Copy for itertools::minmax::MinMaxResult<T>where
T: Copy,
impl<T> Copy for itertools::with_position::Position<T>where
T: Copy,
impl<T> Copy for *const Twhere
T: ?Sized,
impl<T> Copy for *mut Twhere
T: ?Sized,
impl<T> Copy for &Twhere
T: ?Sized,
Shared references can be copied, but mutable references cannot!