FromStr

Trait FromStr 

1.0.0 (const: unstable) · Source
pub trait FromStr: Sized {
    type Err;

    // Required method
    fn from_str(s: &str) -> Result<Self, Self::Err>;
}
Parse a value from a string

FromStr’s from_str method is often used implicitly, through str’s parse method. See parse’s documentation for examples.

FromStr does not have a lifetime parameter, and so you can only parse types that do not contain a lifetime parameter themselves. In other words, you can parse an i32 with FromStr, but not a &i32. You can parse a struct that contains an i32, but not one that contains an &i32.

Input format and round-tripping

The input format expected by a type’s FromStr implementation depends on the type. Check the type’s documentation for the input formats it knows how to parse. Note that the input format of a type’s FromStr implementation might not necessarily accept the output format of its Display implementation, and even if it does, the Display implementation may not be lossless so the round-trip may lose information.

However, if a type has a lossless Display implementation whose output is meant to be conveniently machine-parseable and not just meant for human consumption, then the type may wish to accept the same format in FromStr, and document that usage. Having both Display and FromStr implementations where the result of Display cannot be parsed with FromStr may surprise users.

Examples

Basic implementation of FromStr on an example Point type:

use std::str::FromStr;

#[derive(Debug, PartialEq)]
struct Point {
    x: i32,
    y: i32
}

#[derive(Debug, PartialEq, Eq)]
struct ParsePointError;

impl FromStr for Point {
    type Err = ParsePointError;

    fn from_str(s: &str) -> Result<Self, Self::Err> {
        let (x, y) = s
            .strip_prefix('(')
            .and_then(|s| s.strip_suffix(')'))
            .and_then(|s| s.split_once(','))
            .ok_or(ParsePointError)?;

        let x_fromstr = x.parse::<i32>().map_err(|_| ParsePointError)?;
        let y_fromstr = y.parse::<i32>().map_err(|_| ParsePointError)?;

        Ok(Point { x: x_fromstr, y: y_fromstr })
    }
}

let expected = Ok(Point { x: 1, y: 2 });
// Explicit call
assert_eq!(Point::from_str("(1,2)"), expected);
// Implicit calls, through parse
assert_eq!("(1,2)".parse(), expected);
assert_eq!("(1,2)".parse::<Point>(), expected);
// Invalid input string
assert!(Point::from_str("(1 2)").is_err());

Required Associated Types

1.0.0 · Source

type Err

The associated error which can be returned from parsing.

Required Methods

1.0.0 · Source

fn from_str(s: &str) -> Result<Self, Self::Err>

Parses a string s to return a value of this type.

If parsing succeeds, return the value inside Ok, otherwise when the string is ill-formatted return an error specific to the inside Err. The error type is specific to the implementation of the trait.

Examples

Basic usage with i32, a type that implements FromStr:

use std::str::FromStr;

let s = "5";
let x = i32::from_str(s).unwrap();

assert_eq!(5, x);

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl FromStr for Ss58AddressFormatRegistry

Available on crate feature std only.
1.7.0 · Source

impl FromStr for IpAddr

1.0.0 · Source

impl FromStr for SocketAddr

Source

impl FromStr for TagMode

Source

impl FromStr for log::Level

Source

impl FromStr for log::LevelFilter

Source

impl FromStr for Locale

Source

impl FromStr for Value

Source

impl FromStr for subsoil::keyring::ed25519::Keyring

Source

impl FromStr for subsoil::keyring::sr25519::Keyring

Source

impl FromStr for Month

Source

impl FromStr for Weekday

1.0.0 · Source

impl FromStr for bool

1.20.0 · Source

impl FromStr for char

1.0.0 · Source

impl FromStr for f16

1.0.0 · Source

impl FromStr for f32

1.0.0 · Source

impl FromStr for f64

1.0.0 (const: unstable) · Source

impl FromStr for i8

1.0.0 (const: unstable) · Source

impl FromStr for i16

1.0.0 (const: unstable) · Source

impl FromStr for i32

1.0.0 (const: unstable) · Source

impl FromStr for i64

1.0.0 (const: unstable) · Source

impl FromStr for i128

1.0.0 (const: unstable) · Source

impl FromStr for isize

1.0.0 (const: unstable) · Source

impl FromStr for u8

1.0.0 (const: unstable) · Source

impl FromStr for u16

1.0.0 (const: unstable) · Source

impl FromStr for u32

1.0.0 (const: unstable) · Source

impl FromStr for u64

1.0.0 (const: unstable) · Source

impl FromStr for u128

1.0.0 (const: unstable) · Source

impl FromStr for usize

Source

impl FromStr for ByteString

1.85.0 · Source

impl FromStr for CString

Source

impl FromStr for SecretUri

Source

impl FromStr for Bytes

Available on crate feature std only.
Source

type Err = FromHexError

Source

impl FromStr for H160

Source

impl FromStr for H512

Source

impl FromStr for U256

Source

impl FromStr for U512

Source

impl FromStr for AccountId32

Available on crate feature std only.
Source

type Err = &'static str

Source

impl FromStr for FixedI64

Source

type Err = &'static str

Source

impl FromStr for FixedI128

Source

type Err = &'static str

Source

impl FromStr for FixedU64

Source

type Err = &'static str

Source

impl FromStr for FixedU128

Source

type Err = &'static str

Source

impl FromStr for H256

1.35.0 · Source

impl FromStr for NonZero<i8>

1.35.0 · Source

impl FromStr for NonZero<i16>

1.35.0 · Source

impl FromStr for NonZero<i32>

1.35.0 · Source

impl FromStr for NonZero<i64>

1.35.0 · Source

impl FromStr for NonZero<i128>

1.35.0 · Source

impl FromStr for NonZero<isize>

1.35.0 · Source

impl FromStr for NonZero<u8>

1.35.0 · Source

impl FromStr for NonZero<u16>

1.35.0 · Source

impl FromStr for NonZero<u32>

1.35.0 · Source

impl FromStr for NonZero<u64>

1.35.0 · Source

impl FromStr for NonZero<u128>

1.35.0 · Source

impl FromStr for NonZero<usize>

1.0.0 · Source

impl FromStr for String

Available on non-no_global_oom_handling only.
1.0.0 · Source

impl FromStr for Ipv4Addr

1.0.0 · Source

impl FromStr for Ipv6Addr

1.5.0 · Source

impl FromStr for SocketAddrV4

1.5.0 · Source

impl FromStr for SocketAddrV6

1.45.0 · Source

impl FromStr for OsString

1.32.0 · Source

impl FromStr for PathBuf

Source

impl FromStr for Mnemonic

Source

impl FromStr for bitcoin_hashes::hash160::Hash

Source

impl FromStr for bitcoin_hashes::ripemd160::Hash

Source

impl FromStr for bitcoin_hashes::sha1::Hash

Source

impl FromStr for bitcoin_hashes::sha256::Hash

Source

impl FromStr for Midstate

Source

impl FromStr for bitcoin_hashes::sha256d::Hash

Source

impl FromStr for bitcoin_hashes::sha384::Hash

Source

impl FromStr for bitcoin_hashes::sha512::Hash

Source

impl FromStr for bitcoin_hashes::sha512_256::Hash

Source

impl FromStr for bitcoin_hashes::siphash24::Hash

Source

impl FromStr for ObjectIdentifier

Source

impl FromStr for BmpString

Source

impl FromStr for DateTime

Source

impl FromStr for ed25519::Signature

Decode a signature from hexadecimal.

Upper and lower case hexadecimal are both accepted, however mixed case is rejected.

Source

impl FromStr for Pattern

Source

impl FromStr for H128

Source

impl FromStr for H384

Source

impl FromStr for H768

Source

impl FromStr for U128

Source

impl FromStr for regex::regex::bytes::Regex

Source

impl FromStr for regex::regex::string::Regex

Source

impl FromStr for SharedSecret

Source

impl FromStr for secp256k1::ecdsa::Signature

Source

impl FromStr for ElligatorSwift

Source

impl FromStr for Keypair

Source

impl FromStr for PublicKey

Source

impl FromStr for SecretKey

Source

impl FromStr for XOnlyPublicKey

Source

impl FromStr for secp256k1::schnorr::Signature

Source

impl FromStr for Secret<String>

Source

impl FromStr for Map<String, Value>

Source

impl FromStr for Number

Source

impl FromStr for tracing_core::metadata::Level

Source

impl FromStr for tracing_core::metadata::LevelFilter

Source

impl FromStr for Directive

Source

impl FromStr for EnvFilter

Source

impl FromStr for Targets

Source

impl<C> FromStr for ecdsa::Signature<C>

Available on crate feature arithmetic only.
Source

impl<C> FromStr for NonZeroScalar<C>
where C: CurveArithmetic,

Source

impl<C> FromStr for ScalarPrimitive<C>
where C: Curve,

Source

impl<Size> FromStr for EncodedPoint<Size>
where Size: ModulusSize,

Decode a SEC1-encoded point from hexadecimal.

Upper and lower case hexadecimal are both accepted, however mixed case is rejected.

Source

impl<T> FromStr for Hmac<T>
where T: Hash + FromStr,

Source

type Err = <T as FromStr>::Err

Source

impl<T> FromStr for bitcoin_hashes::sha256t::Hash<T>
where T: Tag,

Source

impl<const CAP: usize> FromStr for ArrayString<CAP>

Source

impl<const MIN: i8, const MAX: i8> FromStr for RangedI8<MIN, MAX>

Source

impl<const MIN: i16, const MAX: i16> FromStr for RangedI16<MIN, MAX>

Source

impl<const MIN: i32, const MAX: i32> FromStr for RangedI32<MIN, MAX>

Source

impl<const MIN: i64, const MAX: i64> FromStr for RangedI64<MIN, MAX>

Source

impl<const MIN: i128, const MAX: i128> FromStr for RangedI128<MIN, MAX>

Source

impl<const MIN: isize, const MAX: isize> FromStr for RangedIsize<MIN, MAX>

Source

impl<const MIN: u8, const MAX: u8> FromStr for RangedU8<MIN, MAX>

Source

impl<const MIN: u16, const MAX: u16> FromStr for RangedU16<MIN, MAX>

Source

impl<const MIN: u32, const MAX: u32> FromStr for RangedU32<MIN, MAX>

Source

impl<const MIN: u64, const MAX: u64> FromStr for RangedU64<MIN, MAX>

Source

impl<const MIN: u128, const MAX: u128> FromStr for RangedU128<MIN, MAX>

Source

impl<const MIN: usize, const MAX: usize> FromStr for RangedUsize<MIN, MAX>

Source

impl<const N: usize, SubTag> FromStr for CryptoBytes<N, (PublicTag, SubTag)>
where CryptoBytes<N, (PublicTag, SubTag)>: CryptoType,

Available on crate feature std only.