pub enum RecvTimeoutError<T> {
Timeout(Receiver<T>),
Disconnected,
}🔬This is a nightly-only experimental API. (
oneshot_channel)Expand description
An error returned from the recv_timeout or
recv_deadline methods.
Examples
Usage of this error is similar to TryRecvError.
#![feature(oneshot_channel)]
use std::sync::oneshot::{self, RecvTimeoutError};
use std::thread;
use std::time::Duration;
let (sender, receiver) = oneshot::channel();
let send_failure = thread::spawn(move || {
// Simulate a long computation that takes longer than our timeout.
thread::sleep(Duration::from_millis(250));
// This will likely fail to send because we drop the receiver in the main thread.
sender.send("Goodbye!".to_string()).unwrap();
});
// Try to receive the message with a short timeout.
match receiver.recv_timeout(Duration::from_millis(10)) {
Ok(msg) => println!("Received: {}", msg),
Err(RecvTimeoutError::Timeout(rx)) => {
println!("Timed out waiting for message!");
// Note that you can reuse the receiver without dropping it.
drop(rx);
},
Err(RecvTimeoutError::Disconnected) => println!("Sender dropped!"),
}
send_failure.join().unwrap_err();Variants
Timeout(Receiver<T>)
🔬This is a nightly-only experimental API. (
oneshot_channel)The Sender has not sent a message yet, but it might in the future (as it has not yet
disconnected). This variant contains the Receiver that either
recv_timeout or recv_deadline took
ownership over.
Disconnected
🔬This is a nightly-only experimental API. (
oneshot_channel)The corresponding Sender half of this channel has become disconnected, and there will
never be any more data sent over the channel.