pub enum TryRecvError<T> {
Empty(Receiver<T>),
Disconnected,
}🔬This is a nightly-only experimental API. (
oneshot_channel)Expand description
Variants
Empty(Receiver<T>)
🔬This is a nightly-only experimental API. (
oneshot_channel)The Sender has not sent a message yet, but it might in the future (as it has not yet
disconnected). This variant contains the Receiver that try_recv
took ownership over.
Disconnected
🔬This is a nightly-only experimental API. (
oneshot_channel)The corresponding Sender half of this channel has become disconnected, and there will
never be any more data sent over the channel.