pub trait Ord: Eq + PartialOrd {
// Required method
fn cmp(&self, other: &Self) -> Ordering;
// Provided methods
fn max(self, other: Self) -> Self
where Self: Sized { ... }
fn min(self, other: Self) -> Self
where Self: Sized { ... }
fn clamp(self, min: Self, max: Self) -> Self
where Self: Sized { ... }
}Expand description
Trait for types that form a total order.
Implementations must be consistent with the PartialOrd implementation, and ensure max,
min, and clamp are consistent with cmp:
partial_cmp(a, b) == Some(cmp(a, b)).max(a, b) == max_by(a, b, cmp)(ensured by the default implementation).min(a, b) == min_by(a, b, cmp)(ensured by the default implementation).- For
a.clamp(min, max), see the method docs (ensured by the default implementation).
Violating these requirements is a logic error. The behavior resulting from a logic error is not
specified, but users of the trait must ensure that such logic errors do not result in
undefined behavior. This means that unsafe code must not rely on the correctness of these
methods.
Corollaries
From the above and the requirements of PartialOrd, it follows that for all a, b and c:
- exactly one of
a < b,a == bora > bis true; and <is transitive:a < bandb < cimpliesa < c. The same must hold for both==and>.
Mathematically speaking, the < operator defines a strict weak order. In cases where ==
conforms to mathematical equality, it also defines a strict total order.
Derivable
This trait can be used with #[derive].
When derived on structs, it will produce a
lexicographic ordering based on the
top-to-bottom declaration order of the struct’s members.
When derived on enums, variants are ordered primarily by their discriminants. Secondarily,
they are ordered by their fields. By default, the discriminant is smallest for variants at the
top, and largest for variants at the bottom. Here’s an example:
#[derive(PartialEq, Eq, PartialOrd, Ord)]
enum E {
Top,
Bottom,
}
assert!(E::Top < E::Bottom);However, manually setting the discriminants can override this default behavior:
#[derive(PartialEq, Eq, PartialOrd, Ord)]
enum E {
Top = 2,
Bottom = 1,
}
assert!(E::Bottom < E::Top);Lexicographical comparison
Lexicographical comparison is an operation with the following properties:
- Two sequences are compared element by element.
- The first mismatching element defines which sequence is lexicographically less or greater than the other.
- If one sequence is a prefix of another, the shorter sequence is lexicographically less than the other.
- If two sequences have equivalent elements and are of the same length, then the sequences are lexicographically equal.
- An empty sequence is lexicographically less than any non-empty sequence.
- Two empty sequences are lexicographically equal.
How can I implement Ord?
Ord requires that the type also be PartialOrd, PartialEq, and Eq.
Because Ord implies a stronger ordering relationship than PartialOrd, and both Ord and
PartialOrd must agree, you must choose how to implement Ord first. You can choose to
derive it, or implement it manually. If you derive it, you should derive all four traits. If you
implement it manually, you should manually implement all four traits, based on the
implementation of Ord.
Here’s an example where you want to define the Character comparison by health and
experience only, disregarding the field mana:
use std::cmp::Ordering;
struct Character {
health: u32,
experience: u32,
mana: f32,
}
impl Ord for Character {
fn cmp(&self, other: &Self) -> Ordering {
self.experience
.cmp(&other.experience)
.then(self.health.cmp(&other.health))
}
}
impl PartialOrd for Character {
fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
Some(self.cmp(other))
}
}
impl PartialEq for Character {
fn eq(&self, other: &Self) -> bool {
self.health == other.health && self.experience == other.experience
}
}
impl Eq for Character {}If all you need is to slice::sort a type by a field value, it can be simpler to use
slice::sort_by_key.
Examples of incorrect Ord implementations
use std::cmp::Ordering;
#[derive(Debug)]
struct Character {
health: f32,
}
impl Ord for Character {
fn cmp(&self, other: &Self) -> std::cmp::Ordering {
if self.health < other.health {
Ordering::Less
} else if self.health > other.health {
Ordering::Greater
} else {
Ordering::Equal
}
}
}
impl PartialOrd for Character {
fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
Some(self.cmp(other))
}
}
impl PartialEq for Character {
fn eq(&self, other: &Self) -> bool {
self.health == other.health
}
}
impl Eq for Character {}
let a = Character { health: 4.5 };
let b = Character { health: f32::NAN };
// Mistake: floating-point values do not form a total order and using the built-in comparison
// operands to implement `Ord` irregardless of that reality does not change it. Use
// `f32::total_cmp` if you need a total order for floating-point values.
// Reflexivity requirement of `Ord` is not given.
assert!(a == a);
assert!(b != b);
// Antisymmetry requirement of `Ord` is not given. Only one of a < c and c < a is allowed to be
// true, not both or neither.
assert_eq!((a < b) as u8 + (b < a) as u8, 0);use std::cmp::Ordering;
#[derive(Debug)]
struct Character {
health: u32,
experience: u32,
}
impl PartialOrd for Character {
fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
Some(self.cmp(other))
}
}
impl Ord for Character {
fn cmp(&self, other: &Self) -> std::cmp::Ordering {
if self.health < 50 {
self.health.cmp(&other.health)
} else {
self.experience.cmp(&other.experience)
}
}
}
// For performance reasons implementing `PartialEq` this way is not the idiomatic way, but it
// ensures consistent behavior between `PartialEq`, `PartialOrd` and `Ord` in this example.
impl PartialEq for Character {
fn eq(&self, other: &Self) -> bool {
self.cmp(other) == Ordering::Equal
}
}
impl Eq for Character {}
let a = Character {
health: 3,
experience: 5,
};
let b = Character {
health: 10,
experience: 77,
};
let c = Character {
health: 143,
experience: 2,
};
// Mistake: The implementation of `Ord` compares different fields depending on the value of
// `self.health`, the resulting order is not total.
// Transitivity requirement of `Ord` is not given. If a is smaller than b and b is smaller than
// c, by transitive property a must also be smaller than c.
assert!(a < b && b < c && c < a);
// Antisymmetry requirement of `Ord` is not given. Only one of a < c and c < a is allowed to be
// true, not both or neither.
assert_eq!((a < c) as u8 + (c < a) as u8, 2);The documentation of PartialOrd contains further examples, for example it’s wrong for
PartialOrd and PartialEq to disagree.
Required Methods
1.0.0 · Sourcefn cmp(&self, other: &Self) -> Ordering
fn cmp(&self, other: &Self) -> Ordering
This method returns an Ordering between self and other.
By convention, self.cmp(&other) returns the ordering matching the expression
self <operator> other if true.
Examples
use std::cmp::Ordering;
assert_eq!(5.cmp(&10), Ordering::Less);
assert_eq!(10.cmp(&5), Ordering::Greater);
assert_eq!(5.cmp(&5), Ordering::Equal);Provided Methods
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values.
Returns the second argument if the comparison determines them to be equal.
Examples
assert_eq!(1.max(2), 2);
assert_eq!(2.max(2), 2);use std::cmp::Ordering;
#[derive(Eq)]
struct Equal(&'static str);
impl PartialEq for Equal {
fn eq(&self, other: &Self) -> bool { true }
}
impl PartialOrd for Equal {
fn partial_cmp(&self, other: &Self) -> Option<Ordering> { Some(Ordering::Equal) }
}
impl Ord for Equal {
fn cmp(&self, other: &Self) -> Ordering { Ordering::Equal }
}
assert_eq!(Equal("self").max(Equal("other")).0, "other");1.21.0 · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values.
Returns the first argument if the comparison determines them to be equal.
Examples
assert_eq!(1.min(2), 1);
assert_eq!(2.min(2), 2);use std::cmp::Ordering;
#[derive(Eq)]
struct Equal(&'static str);
impl PartialEq for Equal {
fn eq(&self, other: &Self) -> bool { true }
}
impl PartialOrd for Equal {
fn partial_cmp(&self, other: &Self) -> Option<Ordering> { Some(Ordering::Equal) }
}
impl Ord for Equal {
fn cmp(&self, other: &Self) -> Ordering { Ordering::Equal }
}
assert_eq!(Equal("self").min(Equal("other")).0, "self");Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
impl Ord for ChildInfo
impl Ord for CallContext
impl Ord for MultiSigner
impl Ord for TypeDefPrimitive
impl Ord for MetaForm
impl Ord for PortableForm
impl Ord for Infallible
impl Ord for Ordering
impl Ord for AsciiChar
impl Ord for IpAddr
impl Ord for SocketAddr
impl Ord for ErrorKind
impl Ord for Language
impl Ord for byteorder::BigEndian
impl Ord for byteorder::LittleEndian
impl Ord for const_oid::error::Error
impl Ord for Class
impl Ord for Tag
impl Ord for TagMode
impl Ord for SectionId
impl Ord for ColumnType
impl Ord for log::Level
impl Ord for log::LevelFilter
impl Ord for Locale
impl Ord for regex_syntax::utf8::Utf8Sequence
impl Ord for regex_syntax::utf8::Utf8Sequence
impl Ord for All
impl Ord for SignOnly
impl Ord for VerifyOnly
impl Ord for ElligatorSwiftParty
impl Ord for secp256k1::Error
impl Ord for Parity
impl Ord for TokenRegistry
impl Ord for subsoil::keyring::ed25519::Keyring
impl Ord for subsoil::keyring::sr25519::Keyring
impl Ord for Month
impl Ord for zerocopy::byteorder::BigEndian
impl Ord for zerocopy::byteorder::LittleEndian
impl Ord for bool
impl Ord for char
impl Ord for i8
impl Ord for i16
impl Ord for i32
impl Ord for i64
impl Ord for i128
impl Ord for isize
impl Ord for !
impl Ord for str
Implements ordering of strings.
Strings are ordered lexicographically by their byte values. This orders Unicode code
points based on their positions in the code charts. This is not necessarily the same as
“alphabetical” order, which varies by language and locale. Sorting strings according to
culturally-accepted standards requires locale-specific data that is outside the scope of
the str type.
impl Ord for u8
impl Ord for u16
impl Ord for u32
impl Ord for u64
impl Ord for u128
impl Ord for ()
impl Ord for usize
impl Ord for CrateVersion
impl Ord for PalletInfoData
impl Ord for StorageVersion
impl Ord for TrackedStorageKey
impl Ord for WithdrawReasons
impl Ord for ByteStr
impl Ord for ByteString
impl Ord for CString
impl Ord for ChildTrieParentKeyId
impl Ord for PrefixedStorageKey
impl Ord for StorageData
impl Ord for StorageKey
impl Ord for topsoil_core::runtime::app_crypto::core_::Bytes
impl Ord for H160
impl Ord for H512
impl Ord for OpaquePeerId
impl Ord for U256
impl Ord for U512
impl Ord for topsoil_core::runtime::app_crypto::ecdsa::AppPublic
impl Ord for topsoil_core::runtime::app_crypto::ed25519::AppPublic
impl Ord for topsoil_core::runtime::app_crypto::sr25519::AppPublic
impl Ord for BigUint
impl Ord for Capabilities
impl Ord for topsoil_core::runtime::offchain::Duration
impl Ord for HttpRequestId
impl Ord for topsoil_core::runtime::offchain::Timestamp
impl Ord for Instant
impl Ord for SystemTime
impl Ord for MetaType
impl Ord for AccountId32
impl Ord for CryptoTypeId
impl Ord for FixedI64
impl Ord for FixedI128
impl Ord for FixedU64
impl Ord for FixedU128
impl Ord for KeyTypeId
impl Ord for PerU16
impl Ord for Perbill
impl Ord for Percent
impl Ord for Permill
impl Ord for Perquintill
impl Ord for Rational128
impl Ord for H256
impl Ord for UintAuthorityId
impl Ord for TypeId
impl Ord for topsoil_core::runtime::std::fmt::Error
impl Ord for PhantomPinned
impl Ord for Alignment
impl Ord for topsoil_core::runtime::std::time::Duration
impl Ord for String
impl Ord for CpuidResult
impl Ord for CStr
impl Ord for Ipv4Addr
impl Ord for Ipv6Addr
impl Ord for SocketAddrV4
impl Ord for SocketAddrV6
impl Ord for Location<'_>
impl Ord for OsStr
impl Ord for OsString
impl Ord for Components<'_>
impl Ord for std::path::Path
impl Ord for PathBuf
impl Ord for PrefixComponent<'_>
impl Ord for aho_corasick::util::primitives::PatternID
impl Ord for aho_corasick::util::primitives::StateID
impl Ord for Mnemonic
impl Ord for bitcoin_hashes::hash160::Hash
impl Ord for bitcoin_hashes::ripemd160::Hash
impl Ord for bitcoin_hashes::sha1::Hash
impl Ord for bitcoin_hashes::sha256::Hash
impl Ord for Midstate
impl Ord for bitcoin_hashes::sha256d::Hash
impl Ord for bitcoin_hashes::sha384::Hash
impl Ord for bitcoin_hashes::sha512::Hash
impl Ord for bitcoin_hashes::sha512_256::Hash
impl Ord for bitcoin_hashes::siphash24::Hash
impl Ord for bytes::bytes::Bytes
impl Ord for BytesMut
impl Ord for ObjectIdentifier
impl Ord for Limb
impl Ord for Any
impl Ord for BitString
impl Ord for BmpString
impl Ord for GeneralizedTime
impl Ord for Ia5String
impl Ord for Int
impl Ord for der::asn1::integer::uint::allocating::Uint
impl Ord for Null
impl Ord for OctetString
impl Ord for PrintableString
impl Ord for TeletexString
impl Ord for UtcTime
impl Ord for DateTime
impl Ord for IndefiniteLength
impl Ord for Length
impl Ord for TagNumber
impl Ord for ecdsa::recovery::RecoveryId
impl Ord for VerificationKeyBytes
impl Ord for Register
impl Ord for DwAccess
impl Ord for DwAddr
impl Ord for DwAt
impl Ord for DwAte
impl Ord for DwCc
impl Ord for DwCfa
impl Ord for DwChildren
impl Ord for DwDefaulted
impl Ord for DwDs
impl Ord for DwDsc
impl Ord for DwEhPe
impl Ord for DwEnd
impl Ord for DwForm
impl Ord for DwId
impl Ord for DwIdx
impl Ord for DwInl
impl Ord for DwLang
impl Ord for DwLle
impl Ord for DwLnct
impl Ord for DwLne
impl Ord for DwLns
impl Ord for DwMacinfo
impl Ord for DwMacro
impl Ord for DwOp
impl Ord for DwOrd
impl Ord for DwRle
impl Ord for DwSect
impl Ord for DwSectV2
impl Ord for DwTag
impl Ord for DwUt
impl Ord for DwVirtuality
impl Ord for DwVis
impl Ord for ArangeEntry
impl Ord for Range
impl Ord for k256::arithmetic::scalar::Scalar
impl Ord for Secp256k1
impl Ord for libsecp256k1_core::field::Field
impl Ord for H128
impl Ord for H384
impl Ord for H768
impl Ord for primitive_types::U128
impl Ord for LazyStateID
impl Ord for Unit
impl Ord for NonMaxUsize
impl Ord for regex_automata::util::primitives::PatternID
impl Ord for SmallIndex
impl Ord for regex_automata::util::primitives::StateID
impl Ord for regex_syntax::ast::Position
impl Ord for regex_syntax::ast::Position
impl Ord for regex_syntax::ast::Span
impl Ord for regex_syntax::ast::Span
impl Ord for regex_syntax::hir::literal::Literal
impl Ord for regex_syntax::hir::literal::Literal
impl Ord for regex_syntax::hir::ClassBytesRange
impl Ord for regex_syntax::hir::ClassBytesRange
impl Ord for regex_syntax::hir::ClassUnicodeRange
impl Ord for regex_syntax::hir::ClassUnicodeRange
impl Ord for regex_syntax::utf8::Utf8Range
impl Ord for regex_syntax::utf8::Utf8Range
impl Ord for schnorrkel::keys::PublicKey
impl Ord for RistrettoBoth
impl Ord for VRFInOut
impl Ord for VRFPreOut
impl Ord for secp256k1_sys::recovery::RecoverableSignature
secp256k1_fuzz only.impl Ord for secp256k1_sys::ElligatorSwift
impl Ord for secp256k1_sys::Keypair
secp256k1_fuzz only.impl Ord for secp256k1_sys::PublicKey
secp256k1_fuzz only.impl Ord for secp256k1_sys::Signature
secp256k1_fuzz only.impl Ord for secp256k1_sys::XOnlyPublicKey
secp256k1_fuzz only.impl Ord for secp256k1::ecdsa::recovery::RecoverableSignature
impl Ord for secp256k1::ecdsa::recovery::RecoveryId
impl Ord for SerializedSignature
impl Ord for secp256k1::ecdsa::Signature
impl Ord for secp256k1::ellswift::ElligatorSwift
impl Ord for InvalidParityValue
impl Ord for secp256k1::key::Keypair
impl Ord for secp256k1::key::PublicKey
impl Ord for secp256k1::key::XOnlyPublicKey
impl Ord for secp256k1::scalar::Scalar
impl Ord for secp256k1::schnorr::Signature
impl Ord for Message
impl Ord for Token
impl Ord for TokenAmount
impl Ord for RationalInfinite
impl Ord for subsoil::consensus::beefy::ecdsa_crypto::Public
impl Ord for Payload
impl Ord for Slot
impl Ord for SlotDuration
impl Ord for ElectionScore
impl Ord for OffenceSeverity
impl Ord for subsoil::timestamp::Timestamp
impl Ord for Date
impl Ord for time::duration::Duration
impl Ord for OffsetDateTime
impl Ord for PrimitiveDateTime
impl Ord for Time
impl Ord for UtcDateTime
impl Ord for UtcOffset
impl Ord for tracing_core::metadata::Level
impl Ord for tracing_core::metadata::LevelFilter
impl Ord for Directive
impl Ord for FmtSpan
impl Ord for trie_db::Bytes
impl Ord for ATerm
impl Ord for B0
impl Ord for B1
impl Ord for Z0
impl Ord for Equal
impl Ord for Greater
impl Ord for Less
impl Ord for UTerm
impl<'a> Ord for OpaqueDigestItemId<'a>
impl<'a> Ord for Component<'a>
impl<'a> Ord for Prefix<'a>
impl<'a> Ord for PhantomContravariantLifetime<'a>
impl<'a> Ord for PhantomCovariantLifetime<'a>
impl<'a> Ord for PhantomInvariantLifetime<'a>
impl<'a> Ord for AnyRef<'a>
impl<'a> Ord for BitStringRef<'a>
impl<'a> Ord for Ia5StringRef<'a>
impl<'a> Ord for IntRef<'a>
impl<'a> Ord for UintRef<'a>
impl<'a> Ord for OctetStringRef<'a>
impl<'a> Ord for PrintableStringRef<'a>
impl<'a> Ord for TeletexStringRef<'a>
impl<'a> Ord for Utf8StringRef<'a>
impl<'a> Ord for VideotexStringRef<'a>
impl<'a> Ord for Metadata<'a>
impl<'a> Ord for MetadataBuilder<'a>
impl<'a> Ord for DecimalStr<'a>
impl<'a> Ord for InfinityStr<'a>
impl<'a> Ord for MinusSignStr<'a>
impl<'a> Ord for NanStr<'a>
impl<'a> Ord for PlusSignStr<'a>
impl<'a> Ord for SeparatorStr<'a>
impl<'a> Ord for NibbleSlice<'a>
impl<'a, T> Ord for Symbol<'a, T>where
T: Ord + 'a,
impl<'a, T> Ord for ContextSpecificRef<'a, T>where
T: Ord,
impl<'a, T, Bound> Ord for BoundedSlice<'a, T, Bound>
impl<'buf> Ord for AllPreallocated<'buf>
impl<'buf> Ord for SignOnlyPreallocated<'buf>
impl<'buf> Ord for VerifyOnlyPreallocated<'buf>
impl<'s, T> Ord for SliceVec<'s, T>where
T: Ord,
impl<A> Ord for TinyVec<A>
impl<A> Ord for &A
impl<A> Ord for &mut A
impl<A> Ord for SmallVec<A>
impl<A> Ord for tinyvec::arrayvec::ArrayVec<A>
impl<AccountId, Balance> Ord for Exposure<AccountId, Balance>
impl<AccountId, Balance> Ord for ExposurePage<AccountId, Balance>
impl<AccountId, Balance> Ord for IndividualExposure<AccountId, Balance>
impl<AssetId: Ord> Ord for NativeOrWithId<AssetId>
impl<B> Ord for Cow<'_, B>
impl<Balance> Ord for PagedExposureMetadata<Balance>
impl<C> Ord for VerifyingKey<C>where
C: PrimeCurve + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
impl<C> Ord for elliptic_curve::public_key::PublicKey<C>where
C: CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
sec1 only.impl<C> Ord for ScalarPrimitive<C>where
C: Curve,
impl<Dyn> Ord for DynMetadata<Dyn>where
Dyn: ?Sized,
impl<E> Ord for I16Bytes<E>
impl<E> Ord for I32Bytes<E>
impl<E> Ord for I64Bytes<E>
impl<E> Ord for U16Bytes<E>
impl<E> Ord for U32Bytes<E>
impl<E> Ord for U64Bytes<E>
impl<F> Ord for Fwhere
F: FnPtr,
impl<K, V, A> Ord for BTreeMap<K, V, A>
impl<K, V, S> Ord for BoundedBTreeMap<K, V, S>
impl<L, R> Ord for Either<L, R>
impl<O> Ord for I16<O>where
O: ByteOrder,
impl<O> Ord for I32<O>where
O: ByteOrder,
impl<O> Ord for I64<O>where
O: ByteOrder,
impl<O> Ord for I128<O>where
O: ByteOrder,
impl<O> Ord for Isize<O>where
O: ByteOrder,
impl<O> Ord for U16<O>where
O: ByteOrder,
impl<O> Ord for U32<O>where
O: ByteOrder,
impl<O> Ord for U64<O>where
O: ByteOrder,
impl<O> Ord for zerocopy::byteorder::U128<O>where
O: ByteOrder,
impl<O> Ord for Usize<O>where
O: ByteOrder,
impl<Params> Ord for AlgorithmIdentifier<Params>where
Params: Ord,
impl<Ptr> Ord for Pin<Ptr>
impl<Size> Ord for EncodedPoint<Size>where
Size: ModulusSize,
impl<T> Ord for TypeDef<T>
impl<T> Ord for Option<T>where
T: Ord,
impl<T> Ord for Poll<T>where
T: Ord,
impl<T> Ord for UnitSectionOffset<T>where
T: Ord,
impl<T> Ord for *const Twhere
T: ?Sized,
Pointer comparison is by address, as produced by the [<*const T>::addr](pointer::addr) method.
impl<T> Ord for *mut Twhere
T: ?Sized,
Pointer comparison is by address, as produced by the <*mut T>::addr method.
impl<T> Ord for [T]where
T: Ord,
Implements comparison of slices lexicographically.
impl<T> Ord for (T₁, T₂, …, Tₙ)where
T: Ord,
This trait is implemented for tuples up to twelve items long.
impl<T> Ord for PhantomData<T>where
T: ?Sized,
impl<T> Ord for topsoil_core::runtime::codec::Compact<T>where
T: Ord,
impl<T> Ord for UntrackedSymbol<T>where
T: Ord,
impl<T> Ord for topsoil_core::runtime::scale_info::Field<T>
impl<T> Ord for topsoil_core::runtime::scale_info::Path<T>
impl<T> Ord for Type<T>
impl<T> Ord for TypeDefArray<T>
impl<T> Ord for TypeDefBitSequence<T>
impl<T> Ord for TypeDefCompact<T>
impl<T> Ord for TypeDefComposite<T>
impl<T> Ord for TypeDefSequence<T>
impl<T> Ord for TypeDefTuple<T>
impl<T> Ord for TypeDefVariant<T>
impl<T> Ord for TypeParameter<T>
impl<T> Ord for Variant<T>
impl<T> Ord for Cell<T>
impl<T> Ord for RefCell<T>
impl<T> Ord for PhantomContravariant<T>where
T: ?Sized,
impl<T> Ord for PhantomCovariant<T>where
T: ?Sized,
impl<T> Ord for PhantomInvariant<T>where
T: ?Sized,
impl<T> Ord for ManuallyDrop<T>
impl<T> Ord for topsoil_core::runtime::std::num::NonZero<T>where
T: ZeroablePrimitive + Ord,
impl<T> Ord for Saturating<T>where
T: Ord,
impl<T> Ord for topsoil_core::runtime::std::num::Wrapping<T>where
T: Ord,
impl<T> Ord for Reverse<T>where
T: Ord,
impl<T> Ord for NonNull<T>where
T: ?Sized,
impl<T> Ord for Exclusive<T>
impl<T> Ord for CapacityError<T>where
T: Ord,
impl<T> Ord for Hmac<T>
impl<T> Ord for bitcoin_hashes::sha256t::Hash<T>where
T: Tag,
impl<T> Ord for crypto_bigint::non_zero::NonZero<T>
impl<T> Ord for crypto_bigint::wrapping::Wrapping<T>where
T: Ord,
impl<T> Ord for ContextSpecific<T>where
T: Ord,
impl<T> Ord for SetOfVec<T>
impl<T> Ord for AllowStdIo<T>where
T: Ord,
impl<T> Ord for DebugInfoOffset<T>where
T: Ord,
impl<T> Ord for DebugTypesOffset<T>where
T: Ord,
impl<T> Ord for UnitOffset<T>where
T: Ord,
impl<T> Ord for jam_codec::compact::Compact<T>where
T: Ord,
impl<T> Ord for Unalign<T>
impl<T, A> Ord for LinkedList<T, A>
impl<T, A> Ord for topsoil_core::runtime::Vec<T, A>
Implements ordering of vectors, lexicographically.
impl<T, A> Ord for BTreeSet<T, A>
impl<T, A> Ord for VecDeque<T, A>
impl<T, A> Ord for topsoil_core::runtime::std::prelude::Box<T, A>
impl<T, A> Ord for Rc<T, A>
impl<T, A> Ord for UniqueRc<T, A>
impl<T, A> Ord for Arc<T, A>
impl<T, A> Ord for UniqueArc<T, A>
impl<T, A> Ord for allocator_api2::stable::boxed::Box<T, A>
impl<T, A> Ord for allocator_api2::stable::vec::Vec<T, A>
Implements ordering of vectors, lexicographically.
impl<T, B> Ord for Ref<B, T>
impl<T, Bound> Ord for BoundedVec<T, Bound>
impl<T, D> Ord for TypeWithDefault<T, D>
impl<T, E> Ord for Result<T, E>
impl<T, N> Ord for GenericArray<T, N>where
T: Ord,
N: ArrayLength<T>,
impl<T, S> Ord for BoundedBTreeSet<T, S>
impl<T, S> Ord for WeakBoundedVec<T, S>
impl<T, const CAP: usize> Ord for arrayvec::arrayvec::ArrayVec<T, CAP>where
T: Ord,
impl<T, const N: usize> Ord for [T; N]where
T: Ord,
Implements comparison of arrays lexicographically.
impl<T, const N: usize> Ord for Simd<T, N>where
T: SimdElement + Ord,
Lexicographic order. For the SIMD elementwise minimum and maximum, use simd_min and simd_max instead.