pub trait TryFrom<T>: Sized {
type Error;
// Required method
fn try_from(value: T) -> Result<Self, Self::Error>;
}Expand description
Simple and safe type conversions that may fail in a controlled
way under some circumstances. It is the reciprocal of TryInto.
This is useful when you are doing a type conversion that may
trivially succeed but may also need special handling.
For example, there is no way to convert an i64 into an i32
using the From trait, because an i64 may contain a value
that an i32 cannot represent and so the conversion would lose data.
This might be handled by truncating the i64 to an i32 or by
simply returning i32::MAX, or by some other method. The From
trait is intended for perfect conversions, so the TryFrom trait
informs the programmer when a type conversion could go bad and lets
them decide how to handle it.
Generic Implementations
TryFrom<T> for UimpliesTryInto<U> for Ttry_fromis reflexive, which means thatTryFrom<T> for Tis implemented and cannot fail – the associatedErrortype for callingT::try_from()on a value of typeTisInfallible. When the!type is stabilizedInfallibleand!will be equivalent.
Prefer using TryInto over TryFrom when specifying trait bounds on a generic function
to ensure that types that only implement TryInto can be used as well.
TryFrom<T> can be implemented as follows:
struct GreaterThanZero(i32);
impl TryFrom<i32> for GreaterThanZero {
type Error = &'static str;
fn try_from(value: i32) -> Result<Self, Self::Error> {
if value <= 0 {
Err("GreaterThanZero only accepts values greater than zero!")
} else {
Ok(GreaterThanZero(value))
}
}
}Examples
As described, i32 implements TryFrom<i64>:
let big_number = 1_000_000_000_000i64;
// Silently truncates `big_number`, requires detecting
// and handling the truncation after the fact.
let smaller_number = big_number as i32;
assert_eq!(smaller_number, -727379968);
// Returns an error because `big_number` is too big to
// fit in an `i32`.
let try_smaller_number = i32::try_from(big_number);
assert!(try_smaller_number.is_err());
// Returns `Ok(3)`.
let try_successful_smaller_number = i32::try_from(3);
assert!(try_successful_smaller_number.is_ok());Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
Sourceimpl TryFrom<&SystemTime> for GeneralizedTime
Available on crate feature std only.
impl TryFrom<&SystemTime> for GeneralizedTime
std only.Sourceimpl TryFrom<&SystemTime> for DateTime
Available on crate feature std only.
impl TryFrom<&SystemTime> for DateTime
std only.Sourceimpl TryFrom<&PrivateKeyInfo<'_>> for SecretDocument
Available on crate feature alloc only.
impl TryFrom<&PrivateKeyInfo<'_>> for SecretDocument
alloc only.Sourceimpl TryFrom<&EncodedPoint<<Secp256k1 as Curve>::FieldBytesSize>> for AffinePoint
impl TryFrom<&EncodedPoint<<Secp256k1 as Curve>::FieldBytesSize>> for AffinePoint
Sourceimpl TryFrom<&EcPrivateKey<'_>> for SecretDocument
Available on crate feature alloc only.
impl TryFrom<&EcPrivateKey<'_>> for SecretDocument
alloc only.Sourceimpl TryFrom<&[u8]> for CompressedEdwardsY
impl TryFrom<&[u8]> for CompressedEdwardsY
type Error = TryFromSliceError
Sourceimpl TryFrom<&[u8]> for CompressedRistretto
impl TryFrom<&[u8]> for CompressedRistretto
type Error = TryFromSliceError
Sourceimpl TryFrom<&[u8]> for SecretDocument
Available on crate feature zeroize only.
impl TryFrom<&[u8]> for SecretDocument
zeroize only.Sourceimpl TryFrom<MultiSignature> for CryptoBytes<subsoil::::core::ecdsa::GenericSignature::{constant#0}, (SignatureTag, CryptoBytes<subsoil::::core::ecdsa::GenericPublic::{constant#0}, (PublicTag, EcdsaTag)>)>
impl TryFrom<MultiSignature> for CryptoBytes<subsoil::::core::ecdsa::GenericSignature::{constant#0}, (SignatureTag, CryptoBytes<subsoil::::core::ecdsa::GenericPublic::{constant#0}, (PublicTag, EcdsaTag)>)>
Sourceimpl TryFrom<MultiSignature> for CryptoBytes<subsoil::::core::ed25519::Signature::{constant#0}, (SignatureTag, Ed25519Tag)>
impl TryFrom<MultiSignature> for CryptoBytes<subsoil::::core::ed25519::Signature::{constant#0}, (SignatureTag, Ed25519Tag)>
Sourceimpl TryFrom<MultiSignature> for CryptoBytes<subsoil::::core::sr25519::Signature::{constant#0}, (SignatureTag, Sr25519Tag)>
impl TryFrom<MultiSignature> for CryptoBytes<subsoil::::core::sr25519::Signature::{constant#0}, (SignatureTag, Sr25519Tag)>
Sourceimpl TryFrom<MultiSigner> for CryptoBytes<subsoil::::core::ecdsa::GenericPublic::{constant#0}, (PublicTag, EcdsaTag)>
impl TryFrom<MultiSigner> for CryptoBytes<subsoil::::core::ecdsa::GenericPublic::{constant#0}, (PublicTag, EcdsaTag)>
Sourceimpl TryFrom<MultiSigner> for CryptoBytes<subsoil::::core::ed25519::Public::{constant#0}, (PublicTag, Ed25519Tag)>
impl TryFrom<MultiSigner> for CryptoBytes<subsoil::::core::ed25519::Public::{constant#0}, (PublicTag, Ed25519Tag)>
Sourceimpl TryFrom<Error> for InvalidFormatDescription
impl TryFrom<Error> for InvalidFormatDescription
type Error = DifferentVariant
Sourceimpl TryFrom<Error> for ComponentRange
impl TryFrom<Error> for ComponentRange
type Error = DifferentVariant
Sourceimpl TryFrom<Error> for ConversionRange
impl TryFrom<Error> for ConversionRange
type Error = DifferentVariant
Sourceimpl TryFrom<Error> for DifferentVariant
impl TryFrom<Error> for DifferentVariant
type Error = DifferentVariant
Sourceimpl TryFrom<Error> for InvalidVariant
impl TryFrom<Error> for InvalidVariant
type Error = DifferentVariant
Sourceimpl TryFrom<Format> for ComponentRange
impl TryFrom<Format> for ComponentRange
type Error = DifferentVariant
Sourceimpl TryFrom<BorrowedFormatItem<'_>> for Component
impl TryFrom<BorrowedFormatItem<'_>> for Component
type Error = DifferentVariant
Sourceimpl TryFrom<OwnedFormatItem> for Component
impl TryFrom<OwnedFormatItem> for Component
type Error = DifferentVariant
Sourceimpl TryFrom<OwnedFormatItem> for Vec<OwnedFormatItem>
impl TryFrom<OwnedFormatItem> for Vec<OwnedFormatItem>
type Error = DifferentVariant
1.59.0 (const: unstable) · Sourceimpl TryFrom<char> for u8
Maps a char with a code point from U+0000 to U+00FF (inclusive) to a byte in 0x00..=0xFF with
the same value, failing if the code point is greater than U+00FF.
impl TryFrom<char> for u8
Maps a char with a code point from U+0000 to U+00FF (inclusive) to a byte in 0x00..=0xFF with
the same value, failing if the code point is greater than U+00FF.
See impl From<u8> for char for details on the encoding.
type Error = TryFromCharError
1.74.0 (const: unstable) · Sourceimpl TryFrom<char> for u16
Maps a char with a code point from U+0000 to U+FFFF (inclusive) to a u16 in 0x0000..=0xFFFF
with the same value, failing if the code point is greater than U+FFFF.
impl TryFrom<char> for u16
Maps a char with a code point from U+0000 to U+FFFF (inclusive) to a u16 in 0x0000..=0xFFFF
with the same value, failing if the code point is greater than U+FFFF.
This corresponds to the UCS-2 encoding, as specified in ISO/IEC 10646:2003.
type Error = TryFromCharError
1.94.0 (const: unstable) · Sourceimpl TryFrom<char> for usize
Maps a char with a code point from U+0000 to U+10FFFF (inclusive) to a usize in
0x0000..=0x10FFFF with the same value, failing if the final value is unrepresentable by
usize.
impl TryFrom<char> for usize
Maps a char with a code point from U+0000 to U+10FFFF (inclusive) to a usize in
0x0000..=0x10FFFF with the same value, failing if the final value is unrepresentable by
usize.
Generally speaking, this conversion can be seen as obtaining the character’s corresponding UTF-32 code point to the extent representable by pointer addresses.
type Error = TryFromCharError
1.46.0 (const: unstable) · Sourceimpl TryFrom<i8> for NonZero<i8>
impl TryFrom<i8> for NonZero<i8>
type Error = TryFromIntError
1.46.0 (const: unstable) · Sourceimpl TryFrom<i16> for NonZero<i16>
impl TryFrom<i16> for NonZero<i16>
type Error = TryFromIntError
Sourceimpl TryFrom<i32> for Parity
Even for 0, Odd for 1, error for anything else
impl TryFrom<i32> for Parity
Even for 0, Odd for 1, error for anything else
type Error = InvalidParityValue
1.46.0 (const: unstable) · Sourceimpl TryFrom<i32> for NonZero<i32>
impl TryFrom<i32> for NonZero<i32>
type Error = TryFromIntError
1.46.0 (const: unstable) · Sourceimpl TryFrom<i64> for NonZero<i64>
impl TryFrom<i64> for NonZero<i64>
type Error = TryFromIntError
1.46.0 (const: unstable) · Sourceimpl TryFrom<i128> for NonZero<i128>
impl TryFrom<i128> for NonZero<i128>
type Error = TryFromIntError
1.46.0 (const: unstable) · Sourceimpl TryFrom<isize> for NonZero<isize>
impl TryFrom<isize> for NonZero<isize>
type Error = TryFromIntError
Sourceimpl TryFrom<u8> for Parity
Even for 0, Odd for 1, error for anything else
impl TryFrom<u8> for Parity
Even for 0, Odd for 1, error for anything else
type Error = InvalidParityValue
1.46.0 (const: unstable) · Sourceimpl TryFrom<u8> for NonZero<u8>
impl TryFrom<u8> for NonZero<u8>
type Error = TryFromIntError
1.46.0 (const: unstable) · Sourceimpl TryFrom<u16> for NonZero<u16>
impl TryFrom<u16> for NonZero<u16>
type Error = TryFromIntError
Sourceimpl TryFrom<u16> for aho_corasick::util::primitives::PatternID
impl TryFrom<u16> for aho_corasick::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<u16> for aho_corasick::util::primitives::StateID
impl TryFrom<u16> for aho_corasick::util::primitives::StateID
type Error = StateIDError
Sourceimpl TryFrom<u16> for regex_automata::util::primitives::PatternID
impl TryFrom<u16> for regex_automata::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<u16> for SmallIndex
impl TryFrom<u16> for SmallIndex
type Error = SmallIndexError
Sourceimpl TryFrom<u16> for regex_automata::util::primitives::StateID
impl TryFrom<u16> for regex_automata::util::primitives::StateID
type Error = StateIDError
1.46.0 (const: unstable) · Sourceimpl TryFrom<u32> for NonZero<u32>
impl TryFrom<u32> for NonZero<u32>
type Error = TryFromIntError
Sourceimpl TryFrom<u32> for aho_corasick::util::primitives::PatternID
impl TryFrom<u32> for aho_corasick::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<u32> for aho_corasick::util::primitives::StateID
impl TryFrom<u32> for aho_corasick::util::primitives::StateID
type Error = StateIDError
Sourceimpl TryFrom<u32> for regex_automata::util::primitives::PatternID
impl TryFrom<u32> for regex_automata::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<u32> for SmallIndex
impl TryFrom<u32> for SmallIndex
type Error = SmallIndexError
Sourceimpl TryFrom<u32> for regex_automata::util::primitives::StateID
impl TryFrom<u32> for regex_automata::util::primitives::StateID
type Error = StateIDError
1.46.0 (const: unstable) · Sourceimpl TryFrom<u64> for NonZero<u64>
impl TryFrom<u64> for NonZero<u64>
type Error = TryFromIntError
Sourceimpl TryFrom<u64> for aho_corasick::util::primitives::PatternID
impl TryFrom<u64> for aho_corasick::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<u64> for aho_corasick::util::primitives::StateID
impl TryFrom<u64> for aho_corasick::util::primitives::StateID
type Error = StateIDError
Sourceimpl TryFrom<u64> for regex_automata::util::primitives::PatternID
impl TryFrom<u64> for regex_automata::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<u64> for SmallIndex
impl TryFrom<u64> for SmallIndex
type Error = SmallIndexError
Sourceimpl TryFrom<u64> for regex_automata::util::primitives::StateID
impl TryFrom<u64> for regex_automata::util::primitives::StateID
type Error = StateIDError
1.46.0 (const: unstable) · Sourceimpl TryFrom<u128> for NonZero<u128>
impl TryFrom<u128> for NonZero<u128>
type Error = TryFromIntError
1.46.0 (const: unstable) · Sourceimpl TryFrom<usize> for NonZero<usize>
impl TryFrom<usize> for NonZero<usize>
type Error = TryFromIntError
Sourceimpl TryFrom<usize> for aho_corasick::util::primitives::PatternID
impl TryFrom<usize> for aho_corasick::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<usize> for aho_corasick::util::primitives::StateID
impl TryFrom<usize> for aho_corasick::util::primitives::StateID
type Error = StateIDError
Sourceimpl TryFrom<usize> for regex_automata::util::primitives::PatternID
impl TryFrom<usize> for regex_automata::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<usize> for SmallIndex
impl TryFrom<usize> for SmallIndex
type Error = SmallIndexError
Sourceimpl TryFrom<usize> for regex_automata::util::primitives::StateID
impl TryFrom<usize> for regex_automata::util::primitives::StateID
type Error = StateIDError
Sourceimpl TryFrom<ByteString> for String
impl TryFrom<ByteString> for String
type Error = FromUtf8Error
Sourceimpl TryFrom<Ss58AddressFormat> for Ss58AddressFormatRegistry
impl TryFrom<Ss58AddressFormat> for Ss58AddressFormatRegistry
type Error = ParseError
Sourceimpl TryFrom<SystemTime> for GeneralizedTime
Available on crate feature std only.
impl TryFrom<SystemTime> for GeneralizedTime
std only.Sourceimpl TryFrom<SystemTime> for DateTime
Available on crate feature std only.
impl TryFrom<SystemTime> for DateTime
std only.1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i8>> for NonZero<u8>
impl TryFrom<NonZero<i8>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i8>> for NonZero<u16>
impl TryFrom<NonZero<i8>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i8>> for NonZero<u32>
impl TryFrom<NonZero<i8>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i8>> for NonZero<u64>
impl TryFrom<NonZero<i8>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i8>> for NonZero<u128>
impl TryFrom<NonZero<i8>> for NonZero<u128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i8>> for NonZero<usize>
impl TryFrom<NonZero<i8>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i16>> for NonZero<i8>
impl TryFrom<NonZero<i16>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i16>> for NonZero<u8>
impl TryFrom<NonZero<i16>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i16>> for NonZero<u16>
impl TryFrom<NonZero<i16>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i16>> for NonZero<u32>
impl TryFrom<NonZero<i16>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i16>> for NonZero<u64>
impl TryFrom<NonZero<i16>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i16>> for NonZero<u128>
impl TryFrom<NonZero<i16>> for NonZero<u128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i16>> for NonZero<usize>
impl TryFrom<NonZero<i16>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<i8>
impl TryFrom<NonZero<i32>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<i16>
impl TryFrom<NonZero<i32>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<isize>
impl TryFrom<NonZero<i32>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<u8>
impl TryFrom<NonZero<i32>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<u16>
impl TryFrom<NonZero<i32>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<u32>
impl TryFrom<NonZero<i32>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<u64>
impl TryFrom<NonZero<i32>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<u128>
impl TryFrom<NonZero<i32>> for NonZero<u128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<usize>
impl TryFrom<NonZero<i32>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<i8>
impl TryFrom<NonZero<i64>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<i16>
impl TryFrom<NonZero<i64>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<i32>
impl TryFrom<NonZero<i64>> for NonZero<i32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<isize>
impl TryFrom<NonZero<i64>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<u8>
impl TryFrom<NonZero<i64>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<u16>
impl TryFrom<NonZero<i64>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<u32>
impl TryFrom<NonZero<i64>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<u64>
impl TryFrom<NonZero<i64>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<u128>
impl TryFrom<NonZero<i64>> for NonZero<u128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<usize>
impl TryFrom<NonZero<i64>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<i8>
impl TryFrom<NonZero<i128>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<i16>
impl TryFrom<NonZero<i128>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<i32>
impl TryFrom<NonZero<i128>> for NonZero<i32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<i64>
impl TryFrom<NonZero<i128>> for NonZero<i64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<isize>
impl TryFrom<NonZero<i128>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<u8>
impl TryFrom<NonZero<i128>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<u16>
impl TryFrom<NonZero<i128>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<u32>
impl TryFrom<NonZero<i128>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<u64>
impl TryFrom<NonZero<i128>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<u128>
impl TryFrom<NonZero<i128>> for NonZero<u128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<usize>
impl TryFrom<NonZero<i128>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<i8>
impl TryFrom<NonZero<isize>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<i16>
impl TryFrom<NonZero<isize>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<i32>
impl TryFrom<NonZero<isize>> for NonZero<i32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<i64>
impl TryFrom<NonZero<isize>> for NonZero<i64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<i128>
impl TryFrom<NonZero<isize>> for NonZero<i128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<u8>
impl TryFrom<NonZero<isize>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<u16>
impl TryFrom<NonZero<isize>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<u32>
impl TryFrom<NonZero<isize>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<u64>
impl TryFrom<NonZero<isize>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<u128>
impl TryFrom<NonZero<isize>> for NonZero<u128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<usize>
impl TryFrom<NonZero<isize>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u8>> for NonZero<i8>
impl TryFrom<NonZero<u8>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u16>> for NonZero<i8>
impl TryFrom<NonZero<u16>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u16>> for NonZero<i16>
impl TryFrom<NonZero<u16>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u16>> for NonZero<isize>
impl TryFrom<NonZero<u16>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u16>> for NonZero<u8>
impl TryFrom<NonZero<u16>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u32>> for NonZero<i8>
impl TryFrom<NonZero<u32>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u32>> for NonZero<i16>
impl TryFrom<NonZero<u32>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u32>> for NonZero<i32>
impl TryFrom<NonZero<u32>> for NonZero<i32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u32>> for NonZero<isize>
impl TryFrom<NonZero<u32>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u32>> for NonZero<u8>
impl TryFrom<NonZero<u32>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u32>> for NonZero<u16>
impl TryFrom<NonZero<u32>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u32>> for NonZero<usize>
impl TryFrom<NonZero<u32>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<i8>
impl TryFrom<NonZero<u64>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<i16>
impl TryFrom<NonZero<u64>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<i32>
impl TryFrom<NonZero<u64>> for NonZero<i32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<i64>
impl TryFrom<NonZero<u64>> for NonZero<i64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<isize>
impl TryFrom<NonZero<u64>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<u8>
impl TryFrom<NonZero<u64>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<u16>
impl TryFrom<NonZero<u64>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<u32>
impl TryFrom<NonZero<u64>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<usize>
impl TryFrom<NonZero<u64>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<i8>
impl TryFrom<NonZero<u128>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<i16>
impl TryFrom<NonZero<u128>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<i32>
impl TryFrom<NonZero<u128>> for NonZero<i32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<i64>
impl TryFrom<NonZero<u128>> for NonZero<i64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<i128>
impl TryFrom<NonZero<u128>> for NonZero<i128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<isize>
impl TryFrom<NonZero<u128>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<u8>
impl TryFrom<NonZero<u128>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<u16>
impl TryFrom<NonZero<u128>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<u32>
impl TryFrom<NonZero<u128>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<u64>
impl TryFrom<NonZero<u128>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<usize>
impl TryFrom<NonZero<u128>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<i8>
impl TryFrom<NonZero<usize>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<i16>
impl TryFrom<NonZero<usize>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<i32>
impl TryFrom<NonZero<usize>> for NonZero<i32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<i64>
impl TryFrom<NonZero<usize>> for NonZero<i64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<i128>
impl TryFrom<NonZero<usize>> for NonZero<i128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<isize>
impl TryFrom<NonZero<usize>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<u8>
impl TryFrom<NonZero<usize>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<u16>
impl TryFrom<NonZero<usize>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<u32>
impl TryFrom<NonZero<usize>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<u64>
impl TryFrom<NonZero<usize>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<u128>
impl TryFrom<NonZero<usize>> for NonZero<u128>
type Error = TryFromIntError
Sourceimpl TryFrom<PrivateKeyInfo<'_>> for SecretDocument
Available on crate feature alloc only.
impl TryFrom<PrivateKeyInfo<'_>> for SecretDocument
alloc only.Sourceimpl TryFrom<EncodedPoint<<Secp256k1 as Curve>::FieldBytesSize>> for AffinePoint
impl TryFrom<EncodedPoint<<Secp256k1 as Curve>::FieldBytesSize>> for AffinePoint
Sourceimpl TryFrom<EcPrivateKey<'_>> for SecretDocument
Available on crate feature alloc only.
impl TryFrom<EcPrivateKey<'_>> for SecretDocument
alloc only.Sourceimpl TryFrom<Duration> for topsoil_core::runtime::std::time::Duration
impl TryFrom<Duration> for topsoil_core::runtime::std::time::Duration
type Error = ConversionRange
Sourceimpl<'__der> TryFrom<&'__der Any> for GeneralizedTime
Available on crate feature alloc only.
impl<'__der> TryFrom<&'__der Any> for GeneralizedTime
alloc only.Sourceimpl<'__der> TryFrom<&'__der Any> for OctetString
Available on crate feature alloc only.
impl<'__der> TryFrom<&'__der Any> for OctetString
alloc only.Sourceimpl<'__der> TryFrom<&'__der Any> for PrintableString
Available on crate feature alloc only.
impl<'__der> TryFrom<&'__der Any> for PrintableString
alloc only.Sourceimpl<'__der> TryFrom<&'__der Any> for TeletexString
Available on crate feature alloc only.
impl<'__der> TryFrom<&'__der Any> for TeletexString
alloc only.Sourceimpl<'__der, 'a> TryFrom<&'__der Any> for BitStringRef<'a>where
'__der: 'a,
Available on crate feature alloc only.
impl<'__der, 'a> TryFrom<&'__der Any> for BitStringRef<'a>where
'__der: 'a,
alloc only.Sourceimpl<'__der, 'a> TryFrom<&'__der Any> for Ia5StringRef<'a>where
'__der: 'a,
Available on crate feature alloc only.
impl<'__der, 'a> TryFrom<&'__der Any> for Ia5StringRef<'a>where
'__der: 'a,
alloc only.Sourceimpl<'__der, 'a> TryFrom<&'__der Any> for IntRef<'a>where
'__der: 'a,
Available on crate feature alloc only.
impl<'__der, 'a> TryFrom<&'__der Any> for IntRef<'a>where
'__der: 'a,
alloc only.Sourceimpl<'__der, 'a> TryFrom<&'__der Any> for UintRef<'a>where
'__der: 'a,
Available on crate feature alloc only.
impl<'__der, 'a> TryFrom<&'__der Any> for UintRef<'a>where
'__der: 'a,
alloc only.Sourceimpl<'__der, 'a> TryFrom<&'__der Any> for OctetStringRef<'a>where
'__der: 'a,
Available on crate feature alloc only.
impl<'__der, 'a> TryFrom<&'__der Any> for OctetStringRef<'a>where
'__der: 'a,
alloc only.Sourceimpl<'__der, 'a> TryFrom<&'__der Any> for PrintableStringRef<'a>where
'__der: 'a,
Available on crate feature alloc only.
impl<'__der, 'a> TryFrom<&'__der Any> for PrintableStringRef<'a>where
'__der: 'a,
alloc only.Sourceimpl<'__der, 'a> TryFrom<&'__der Any> for TeletexStringRef<'a>where
'__der: 'a,
Available on crate feature alloc only.
impl<'__der, 'a> TryFrom<&'__der Any> for TeletexStringRef<'a>where
'__der: 'a,
alloc only.Sourceimpl<'__der, 'a> TryFrom<&'__der Any> for Utf8StringRef<'a>where
'__der: 'a,
Available on crate feature alloc only.
impl<'__der, 'a> TryFrom<&'__der Any> for Utf8StringRef<'a>where
'__der: 'a,
alloc only.Sourceimpl<'__der, 'a> TryFrom<&'__der Any> for VideotexStringRef<'a>where
'__der: 'a,
Available on crate feature alloc only.
impl<'__der, 'a> TryFrom<&'__der Any> for VideotexStringRef<'a>where
'__der: 'a,
alloc only.Sourceimpl<'__der, 'a> TryFrom<AnyRef<'__der>> for BitStringRef<'a>where
'__der: 'a,
impl<'__der, 'a> TryFrom<AnyRef<'__der>> for BitStringRef<'a>where
'__der: 'a,
Sourceimpl<'__der, 'a> TryFrom<AnyRef<'__der>> for Ia5StringRef<'a>where
'__der: 'a,
impl<'__der, 'a> TryFrom<AnyRef<'__der>> for Ia5StringRef<'a>where
'__der: 'a,
Sourceimpl<'__der, 'a> TryFrom<AnyRef<'__der>> for OctetStringRef<'a>where
'__der: 'a,
impl<'__der, 'a> TryFrom<AnyRef<'__der>> for OctetStringRef<'a>where
'__der: 'a,
Sourceimpl<'__der, 'a> TryFrom<AnyRef<'__der>> for PrintableStringRef<'a>where
'__der: 'a,
impl<'__der, 'a> TryFrom<AnyRef<'__der>> for PrintableStringRef<'a>where
'__der: 'a,
Sourceimpl<'__der, 'a> TryFrom<AnyRef<'__der>> for TeletexStringRef<'a>where
'__der: 'a,
impl<'__der, 'a> TryFrom<AnyRef<'__der>> for TeletexStringRef<'a>where
'__der: 'a,
Sourceimpl<'__der, 'a> TryFrom<AnyRef<'__der>> for Utf8StringRef<'a>where
'__der: 'a,
impl<'__der, 'a> TryFrom<AnyRef<'__der>> for Utf8StringRef<'a>where
'__der: 'a,
Sourceimpl<'__der, 'a> TryFrom<AnyRef<'__der>> for VideotexStringRef<'a>where
'__der: 'a,
impl<'__der, 'a> TryFrom<AnyRef<'__der>> for VideotexStringRef<'a>where
'__der: 'a,
Sourceimpl<'a> TryFrom<&&'a [u8]> for BitStringRef<'a>
Hack for simplifying the custom derive use case.
impl<'a> TryFrom<&&'a [u8]> for BitStringRef<'a>
Hack for simplifying the custom derive use case.
Sourceimpl<'a> TryFrom<&'a str> for Ss58AddressFormatRegistry
impl<'a> TryFrom<&'a str> for Ss58AddressFormatRegistry
type Error = ParseError
Sourceimpl<'a> TryFrom<&'a str> for Ss58AddressFormat
impl<'a> TryFrom<&'a str> for Ss58AddressFormat
type Error = ParseError
Sourceimpl<'a> TryFrom<&'a SerializedSignature> for secp256k1::ecdsa::Signature
impl<'a> TryFrom<&'a SerializedSignature> for secp256k1::ecdsa::Signature
Sourceimpl<'a> TryFrom<&'a [u8]> for topsoil_core::runtime::app_crypto::ecdsa::AppProofOfPossession
impl<'a> TryFrom<&'a [u8]> for topsoil_core::runtime::app_crypto::ecdsa::AppProofOfPossession
Sourceimpl<'a> TryFrom<&'a [u8]> for topsoil_core::runtime::app_crypto::ecdsa::AppSignature
impl<'a> TryFrom<&'a [u8]> for topsoil_core::runtime::app_crypto::ecdsa::AppSignature
Sourceimpl<'a> TryFrom<&'a [u8]> for topsoil_core::runtime::app_crypto::ed25519::AppProofOfPossession
impl<'a> TryFrom<&'a [u8]> for topsoil_core::runtime::app_crypto::ed25519::AppProofOfPossession
Sourceimpl<'a> TryFrom<&'a [u8]> for topsoil_core::runtime::app_crypto::ed25519::AppSignature
impl<'a> TryFrom<&'a [u8]> for topsoil_core::runtime::app_crypto::ed25519::AppSignature
Sourceimpl<'a> TryFrom<&'a [u8]> for topsoil_core::runtime::app_crypto::sr25519::AppProofOfPossession
impl<'a> TryFrom<&'a [u8]> for topsoil_core::runtime::app_crypto::sr25519::AppProofOfPossession
Sourceimpl<'a> TryFrom<&'a [u8]> for topsoil_core::runtime::app_crypto::sr25519::AppSignature
impl<'a> TryFrom<&'a [u8]> for topsoil_core::runtime::app_crypto::sr25519::AppSignature
Sourceimpl<'a> TryFrom<&'a [u8]> for subsoil::consensus::beefy::ecdsa_crypto::ProofOfPossession
impl<'a> TryFrom<&'a [u8]> for subsoil::consensus::beefy::ecdsa_crypto::ProofOfPossession
Sourceimpl<'a> TryFrom<BorrowedFormatItem<'a>> for &[BorrowedFormatItem<'a>]
impl<'a> TryFrom<BorrowedFormatItem<'a>> for &[BorrowedFormatItem<'a>]
type Error = DifferentVariant
Sourceimpl<'a> TryFrom<AnyRef<'a>> for SystemTime
Available on crate feature std only.
impl<'a> TryFrom<AnyRef<'a>> for SystemTime
std only.Sourceimpl<'a, 'k, Params, Key> TryFrom<&SubjectPublicKeyInfo<Params, Key>> for Document
Available on crate feature alloc only.
impl<'a, 'k, Params, Key> TryFrom<&SubjectPublicKeyInfo<Params, Key>> for Document
alloc only.Sourceimpl<'a, 'k, Params, Key> TryFrom<SubjectPublicKeyInfo<Params, Key>> for Document
Available on crate feature alloc only.
impl<'a, 'k, Params, Key> TryFrom<SubjectPublicKeyInfo<Params, Key>> for Document
alloc only.Sourceimpl<'a, HO> TryFrom<NodeHandle<'a>> for ChildReference<HO>
impl<'a, HO> TryFrom<NodeHandle<'a>> for ChildReference<HO>
Sourceimpl<'a, Params> TryFrom<&'a [u8]> for AlgorithmIdentifier<Params>
impl<'a, Params> TryFrom<&'a [u8]> for AlgorithmIdentifier<Params>
Sourceimpl<'a, Params, Key> TryFrom<&'a [u8]> for SubjectPublicKeyInfo<Params, Key>
impl<'a, Params, Key> TryFrom<&'a [u8]> for SubjectPublicKeyInfo<Params, Key>
Sourceimpl<'a, T, S> TryFrom<&'a [T]> for BoundedSlice<'a, T, S>
impl<'a, T, S> TryFrom<&'a [T]> for BoundedSlice<'a, T, S>
1.34.0 (const: unstable) · Sourceimpl<'a, T, const N: usize> TryFrom<&'a [T]> for &'a [T; N]
Tries to create an array ref &[T; N] from a slice ref &[T]. Succeeds if
slice.len() == N.
impl<'a, T, const N: usize> TryFrom<&'a [T]> for &'a [T; N]
Tries to create an array ref &[T; N] from a slice ref &[T]. Succeeds if
slice.len() == N.
let bytes: [u8; 3] = [1, 0, 2];
let bytes_head: &[u8; 2] = <&[u8; 2]>::try_from(&bytes[0..2]).unwrap();
assert_eq!(1, u16::from_le_bytes(*bytes_head));
let bytes_tail: &[u8; 2] = bytes[1..3].try_into().unwrap();
assert_eq!(512, u16::from_le_bytes(*bytes_tail));type Error = TryFromSliceError
1.34.0 (const: unstable) · Sourceimpl<'a, T, const N: usize> TryFrom<&'a mut [T]> for &'a mut [T; N]
Tries to create a mutable array ref &mut [T; N] from a mutable slice ref
&mut [T]. Succeeds if slice.len() == N.
impl<'a, T, const N: usize> TryFrom<&'a mut [T]> for &'a mut [T; N]
Tries to create a mutable array ref &mut [T; N] from a mutable slice ref
&mut [T]. Succeeds if slice.len() == N.
let mut bytes: [u8; 3] = [1, 0, 2];
let bytes_head: &mut [u8; 2] = <&mut [u8; 2]>::try_from(&mut bytes[0..2]).unwrap();
assert_eq!(1, u16::from_le_bytes(*bytes_head));
let bytes_tail: &mut [u8; 2] = (&mut bytes[1..3]).try_into().unwrap();
assert_eq!(512, u16::from_le_bytes(*bytes_tail));type Error = TryFromSliceError
Sourceimpl<'a, const CAP: usize> TryFrom<&'a str> for ArrayString<CAP>
impl<'a, const CAP: usize> TryFrom<&'a str> for ArrayString<CAP>
type Error = CapacityError<&'a str>
Sourceimpl<'a, const CAP: usize> TryFrom<Arguments<'a>> for ArrayString<CAP>
impl<'a, const CAP: usize> TryFrom<Arguments<'a>> for ArrayString<CAP>
type Error = CapacityError<Error>
Sourceimpl<C> TryFrom<&GenericArray<u8, <<C as Curve>::FieldBytesSize as ModulusSize>::CompressedPointSize>> for elliptic_curve::public_key::PublicKey<C>where
C: CurveArithmetic,
<C as Curve>::FieldBytesSize: ModulusSize,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
Available on crate feature sec1 only.
impl<C> TryFrom<&GenericArray<u8, <<C as Curve>::FieldBytesSize as ModulusSize>::CompressedPointSize>> for elliptic_curve::public_key::PublicKey<C>where
C: CurveArithmetic,
<C as Curve>::FieldBytesSize: ModulusSize,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
sec1 only.Sourceimpl<C> TryFrom<&EncodedPoint<<C as Curve>::FieldBytesSize>> for elliptic_curve::public_key::PublicKey<C>where
C: CurveArithmetic,
<C as Curve>::FieldBytesSize: ModulusSize,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
Available on crate feature sec1 only.
impl<C> TryFrom<&EncodedPoint<<C as Curve>::FieldBytesSize>> for elliptic_curve::public_key::PublicKey<C>where
C: CurveArithmetic,
<C as Curve>::FieldBytesSize: ModulusSize,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
sec1 only.Sourceimpl<C> TryFrom<&SubjectPublicKeyInfo<AnyRef<'_>, BitStringRef<'_>>> for elliptic_curve::public_key::PublicKey<C>where
C: AssociatedOid + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
Available on crate feature pkcs8 only.
impl<C> TryFrom<&SubjectPublicKeyInfo<AnyRef<'_>, BitStringRef<'_>>> for elliptic_curve::public_key::PublicKey<C>where
C: AssociatedOid + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
pkcs8 only.Sourceimpl<C> TryFrom<&[u8]> for ecdsa::signing::SigningKey<C>where
C: PrimeCurve + CurveArithmetic,
<C as CurveArithmetic>::Scalar: Invert<Output = CtOption<<C as CurveArithmetic>::Scalar>> + SignPrimitive<C>,
<<C as Curve>::FieldBytesSize as Add>::Output: ArrayLength<u8>,
impl<C> TryFrom<&[u8]> for ecdsa::signing::SigningKey<C>where
C: PrimeCurve + CurveArithmetic,
<C as CurveArithmetic>::Scalar: Invert<Output = CtOption<<C as CurveArithmetic>::Scalar>> + SignPrimitive<C>,
<<C as Curve>::FieldBytesSize as Add>::Output: ArrayLength<u8>,
Sourceimpl<C> TryFrom<&[u8]> for SignatureWithOid<C>where
C: DigestPrimitive,
<C as DigestPrimitive>::Digest: AssociatedOid,
<<C as Curve>::FieldBytesSize as Add>::Output: ArrayLength<u8>,
Available on crate features digest and hazmat only.NOTE: this implementation assumes the default digest for the given elliptic
curve as defined by hazmat::DigestPrimitive.
impl<C> TryFrom<&[u8]> for SignatureWithOid<C>where
C: DigestPrimitive,
<C as DigestPrimitive>::Digest: AssociatedOid,
<<C as Curve>::FieldBytesSize as Add>::Output: ArrayLength<u8>,
digest and hazmat only.NOTE: this implementation assumes the default digest for the given elliptic
curve as defined by hazmat::DigestPrimitive.
When working with alternative digests, you will need to use e.g.
SignatureWithOid::new_with_digest.
Sourceimpl<C> TryFrom<&[u8]> for ecdsa::verifying::VerifyingKey<C>where
C: PrimeCurve + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
impl<C> TryFrom<&[u8]> for ecdsa::verifying::VerifyingKey<C>where
C: PrimeCurve + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
Sourceimpl<C> TryFrom<&[u8]> for NonZeroScalar<C>where
C: CurveArithmetic,
impl<C> TryFrom<&[u8]> for NonZeroScalar<C>where
C: CurveArithmetic,
Sourceimpl<C> TryFrom<GenericArray<u8, <<C as Curve>::FieldBytesSize as ModulusSize>::CompressedPointSize>> for elliptic_curve::public_key::PublicKey<C>where
C: CurveArithmetic,
<C as Curve>::FieldBytesSize: ModulusSize,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
Available on crate feature sec1 only.
impl<C> TryFrom<GenericArray<u8, <<C as Curve>::FieldBytesSize as ModulusSize>::CompressedPointSize>> for elliptic_curve::public_key::PublicKey<C>where
C: CurveArithmetic,
<C as Curve>::FieldBytesSize: ModulusSize,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
sec1 only.Sourceimpl<C> TryFrom<PrivateKeyInfo<'_>> for elliptic_curve::secret_key::SecretKey<C>
impl<C> TryFrom<PrivateKeyInfo<'_>> for elliptic_curve::secret_key::SecretKey<C>
Sourceimpl<C> TryFrom<EncodedPoint<<C as Curve>::FieldBytesSize>> for elliptic_curve::public_key::PublicKey<C>where
C: CurveArithmetic,
<C as Curve>::FieldBytesSize: ModulusSize,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
Available on crate feature sec1 only.
impl<C> TryFrom<EncodedPoint<<C as Curve>::FieldBytesSize>> for elliptic_curve::public_key::PublicKey<C>where
C: CurveArithmetic,
<C as Curve>::FieldBytesSize: ModulusSize,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
sec1 only.Sourceimpl<C> TryFrom<EcPrivateKey<'_>> for elliptic_curve::secret_key::SecretKey<C>
Available on crate feature sec1 only.
impl<C> TryFrom<EcPrivateKey<'_>> for elliptic_curve::secret_key::SecretKey<C>
sec1 only.Sourceimpl<C> TryFrom<SubjectPublicKeyInfo<AnyRef<'_>, BitStringRef<'_>>> for elliptic_curve::public_key::PublicKey<C>where
C: AssociatedOid + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
Available on crate feature pkcs8 only.
impl<C> TryFrom<SubjectPublicKeyInfo<AnyRef<'_>, BitStringRef<'_>>> for elliptic_curve::public_key::PublicKey<C>where
C: AssociatedOid + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
pkcs8 only.Sourceimpl<K, V, S> TryFrom<BTreeMap<K, V>> for BoundedBTreeMap<K, V, S>
impl<K, V, S> TryFrom<BTreeMap<K, V>> for BoundedBTreeMap<K, V, S>
Sourceimpl<Size> TryFrom<&[u8]> for EncodedPoint<Size>where
Size: ModulusSize,
impl<Size> TryFrom<&[u8]> for EncodedPoint<Size>where
Size: ModulusSize,
Sourceimpl<T> TryFrom<Vec<T>> for SetOfVec<T>where
T: DerOrd,
Available on crate feature alloc only.
impl<T> TryFrom<Vec<T>> for SetOfVec<T>where
T: DerOrd,
alloc only.Sourceimpl<T, A> TryFrom<&[T]> for tinyvec::arrayvec::ArrayVec<A>
impl<T, A> TryFrom<&[T]> for tinyvec::arrayvec::ArrayVec<A>
type Error = TryFromSliceError
1.43.0 · Sourceimpl<T, A, const N: usize> TryFrom<Arc<[T], A>> for Arc<[T; N], A>where
A: Allocator,
impl<T, A, const N: usize> TryFrom<Arc<[T], A>> for Arc<[T; N], A>where
A: Allocator,
Sourceimpl<T, A, const N: usize> TryFrom<Box<[T], A>> for allocator_api2::stable::boxed::Box<[T; N], A>where
A: Allocator,
impl<T, A, const N: usize> TryFrom<Box<[T], A>> for allocator_api2::stable::boxed::Box<[T; N], A>where
A: Allocator,
Sourceimpl<T, D> TryFrom<usize> for TypeWithDefault<T, D>
impl<T, D> TryFrom<usize> for TypeWithDefault<T, D>
Sourceimpl<T, D> TryFrom<TypeWithDefault<T, D>> for u8
impl<T, D> TryFrom<TypeWithDefault<T, D>> for u8
Sourceimpl<T, D> TryFrom<TypeWithDefault<T, D>> for u16
impl<T, D> TryFrom<TypeWithDefault<T, D>> for u16
Sourceimpl<T, D> TryFrom<TypeWithDefault<T, D>> for u32
impl<T, D> TryFrom<TypeWithDefault<T, D>> for u32
Sourceimpl<T, D> TryFrom<TypeWithDefault<T, D>> for u64
impl<T, D> TryFrom<TypeWithDefault<T, D>> for u64
Sourceimpl<T, D> TryFrom<TypeWithDefault<T, D>> for u128
impl<T, D> TryFrom<TypeWithDefault<T, D>> for u128
Sourceimpl<T, D> TryFrom<TypeWithDefault<T, D>> for usize
impl<T, D> TryFrom<TypeWithDefault<T, D>> for usize
Sourceimpl<T, S> TryFrom<BTreeSet<T>> for BoundedBTreeSet<T, S>
impl<T, S> TryFrom<BTreeSet<T>> for BoundedBTreeSet<T, S>
1.34.0 (const: unstable) · Sourceimpl<T, U> TryFrom<U> for Twhere
U: Into<T>,
impl<T, U> TryFrom<U> for Twhere
U: Into<T>,
type Error = Infallible
Sourceimpl<T, const CAP: usize> TryFrom<&[T]> for arrayvec::arrayvec::ArrayVec<T, CAP>where
T: Clone,
Try to create an ArrayVec from a slice. This will return an error if the slice was too big to
fit.
impl<T, const CAP: usize> TryFrom<&[T]> for arrayvec::arrayvec::ArrayVec<T, CAP>where
T: Clone,
Try to create an ArrayVec from a slice. This will return an error if the slice was too big to
fit.
use arrayvec::ArrayVec;
use std::convert::TryInto as _;
let array: ArrayVec<_, 4> = (&[1, 2, 3] as &[_]).try_into().unwrap();
assert_eq!(array.len(), 3);
assert_eq!(array.capacity(), 4);type Error = CapacityError
1.34.0 (const: unstable) · Sourceimpl<T, const N: usize> TryFrom<&[T]> for [T; N]where
T: Copy,
Tries to create an array [T; N] by copying from a slice &[T].
Succeeds if slice.len() == N.
impl<T, const N: usize> TryFrom<&[T]> for [T; N]where
T: Copy,
Tries to create an array [T; N] by copying from a slice &[T].
Succeeds if slice.len() == N.
let bytes: [u8; 3] = [1, 0, 2];
let bytes_head: [u8; 2] = <[u8; 2]>::try_from(&bytes[0..2]).unwrap();
assert_eq!(1, u16::from_le_bytes(bytes_head));
let bytes_tail: [u8; 2] = bytes[1..3].try_into().unwrap();
assert_eq!(512, u16::from_le_bytes(bytes_tail));type Error = TryFromSliceError
Sourceimpl<T, const N: usize> TryFrom<&[T]> for Simd<T, N>where
T: SimdElement,
impl<T, const N: usize> TryFrom<&[T]> for Simd<T, N>where
T: SimdElement,
type Error = TryFromSliceError
1.59.0 (const: unstable) · Sourceimpl<T, const N: usize> TryFrom<&mut [T]> for [T; N]where
T: Copy,
Tries to create an array [T; N] by copying from a mutable slice &mut [T].
Succeeds if slice.len() == N.
impl<T, const N: usize> TryFrom<&mut [T]> for [T; N]where
T: Copy,
Tries to create an array [T; N] by copying from a mutable slice &mut [T].
Succeeds if slice.len() == N.
let mut bytes: [u8; 3] = [1, 0, 2];
let bytes_head: [u8; 2] = <[u8; 2]>::try_from(&mut bytes[0..2]).unwrap();
assert_eq!(1, u16::from_le_bytes(bytes_head));
let bytes_tail: [u8; 2] = (&mut bytes[1..3]).try_into().unwrap();
assert_eq!(512, u16::from_le_bytes(bytes_tail));type Error = TryFromSliceError
Sourceimpl<T, const N: usize> TryFrom<&mut [T]> for Simd<T, N>where
T: SimdElement,
impl<T, const N: usize> TryFrom<&mut [T]> for Simd<T, N>where
T: SimdElement,
type Error = TryFromSliceError
Sourceimpl<T, const N: usize> TryFrom<[T; N]> for SetOfVec<T>where
T: DerOrd,
Available on crate feature alloc only.
impl<T, const N: usize> TryFrom<[T; N]> for SetOfVec<T>where
T: DerOrd,
alloc only.1.66.0 · Sourceimpl<T, const N: usize> TryFrom<Vec<T>> for topsoil_core::runtime::std::prelude::Box<[T; N]>
Available on non-no_global_oom_handling only.
impl<T, const N: usize> TryFrom<Vec<T>> for topsoil_core::runtime::std::prelude::Box<[T; N]>
no_global_oom_handling only.