pub trait FromStr: Sized {
type Err;
// Required method
fn from_str(s: &str) -> Result<Self, Self::Err>;
}Expand description
Parse a value from a string
FromStr’s from_str method is often used implicitly, through
str’s parse method. See parse’s documentation for examples.
FromStr does not have a lifetime parameter, and so you can only parse types
that do not contain a lifetime parameter themselves. In other words, you can
parse an i32 with FromStr, but not a &i32. You can parse a struct that
contains an i32, but not one that contains an &i32.
Input format and round-tripping
The input format expected by a type’s FromStr implementation depends on the type. Check the
type’s documentation for the input formats it knows how to parse. Note that the input format of
a type’s FromStr implementation might not necessarily accept the output format of its
Display implementation, and even if it does, the Display implementation may not be lossless
so the round-trip may lose information.
However, if a type has a lossless Display implementation whose output is meant to be
conveniently machine-parseable and not just meant for human consumption, then the type may wish
to accept the same format in FromStr, and document that usage. Having both Display and
FromStr implementations where the result of Display cannot be parsed with FromStr may
surprise users.
Examples
Basic implementation of FromStr on an example Point type:
use std::str::FromStr;
#[derive(Debug, PartialEq)]
struct Point {
x: i32,
y: i32
}
#[derive(Debug, PartialEq, Eq)]
struct ParsePointError;
impl FromStr for Point {
type Err = ParsePointError;
fn from_str(s: &str) -> Result<Self, Self::Err> {
let (x, y) = s
.strip_prefix('(')
.and_then(|s| s.strip_suffix(')'))
.and_then(|s| s.split_once(','))
.ok_or(ParsePointError)?;
let x_fromstr = x.parse::<i32>().map_err(|_| ParsePointError)?;
let y_fromstr = y.parse::<i32>().map_err(|_| ParsePointError)?;
Ok(Point { x: x_fromstr, y: y_fromstr })
}
}
let expected = Ok(Point { x: 1, y: 2 });
// Explicit call
assert_eq!(Point::from_str("(1,2)"), expected);
// Implicit calls, through parse
assert_eq!("(1,2)".parse(), expected);
assert_eq!("(1,2)".parse::<Point>(), expected);
// Invalid input string
assert!(Point::from_str("(1 2)").is_err());Required Associated Types
Required Methods
1.0.0 · Sourcefn from_str(s: &str) -> Result<Self, Self::Err>
fn from_str(s: &str) -> Result<Self, Self::Err>
Parses a string s to return a value of this type.
If parsing succeeds, return the value inside Ok, otherwise
when the string is ill-formatted return an error specific to the
inside Err. The error type is specific to the implementation of the trait.
Examples
Basic usage with i32, a type that implements FromStr:
use std::str::FromStr;
let s = "5";
let x = i32::from_str(s).unwrap();
assert_eq!(5, x);Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
Sourceimpl FromStr for Ss58AddressFormatRegistry
Available on crate feature std only.
impl FromStr for Ss58AddressFormatRegistry
std only.type Err = ParseError
1.0.0 · Sourceimpl FromStr for SocketAddr
impl FromStr for SocketAddr
type Err = AddrParseError
Sourceimpl FromStr for log::LevelFilter
impl FromStr for log::LevelFilter
type Err = ParseLevelError
Sourceimpl FromStr for ByteString
impl FromStr for ByteString
type Err = Infallible
Sourceimpl FromStr for AccountId32
Available on crate feature std only.
impl FromStr for AccountId32
std only.1.0.0 · Sourceimpl FromStr for String
Available on non-no_global_oom_handling only.
impl FromStr for String
no_global_oom_handling only.type Err = Infallible
1.5.0 · Sourceimpl FromStr for SocketAddrV4
impl FromStr for SocketAddrV4
type Err = AddrParseError
1.5.0 · Sourceimpl FromStr for SocketAddrV6
impl FromStr for SocketAddrV6
type Err = AddrParseError
Sourceimpl FromStr for ed25519::Signature
Decode a signature from hexadecimal.
impl FromStr for ed25519::Signature
Decode a signature from hexadecimal.
Upper and lower case hexadecimal are both accepted, however mixed case is rejected.
Sourceimpl FromStr for tracing_core::metadata::LevelFilter
impl FromStr for tracing_core::metadata::LevelFilter
type Err = ParseLevelFilterError
Sourceimpl<C> FromStr for ecdsa::Signature<C>where
C: PrimeCurve + CurveArithmetic,
<<C as Curve>::FieldBytesSize as Add>::Output: ArrayLength<u8>,
Available on crate feature arithmetic only.
impl<C> FromStr for ecdsa::Signature<C>where
C: PrimeCurve + CurveArithmetic,
<<C as Curve>::FieldBytesSize as Add>::Output: ArrayLength<u8>,
arithmetic only.Sourceimpl<C> FromStr for NonZeroScalar<C>where
C: CurveArithmetic,
impl<C> FromStr for NonZeroScalar<C>where
C: CurveArithmetic,
Sourceimpl<Size> FromStr for EncodedPoint<Size>where
Size: ModulusSize,
Decode a SEC1-encoded point from hexadecimal.
impl<Size> FromStr for EncodedPoint<Size>where
Size: ModulusSize,
Decode a SEC1-encoded point from hexadecimal.
Upper and lower case hexadecimal are both accepted, however mixed case is rejected.
Sourceimpl<T> FromStr for bitcoin_hashes::sha256t::Hash<T>where
T: Tag,
impl<T> FromStr for bitcoin_hashes::sha256t::Hash<T>where
T: Tag,
type Err = HexToArrayError
Sourceimpl<const CAP: usize> FromStr for ArrayString<CAP>
impl<const CAP: usize> FromStr for ArrayString<CAP>
type Err = CapacityError
Sourceimpl<const MIN: i8, const MAX: i8> FromStr for RangedI8<MIN, MAX>
impl<const MIN: i8, const MAX: i8> FromStr for RangedI8<MIN, MAX>
type Err = ParseIntError
Sourceimpl<const MIN: i16, const MAX: i16> FromStr for RangedI16<MIN, MAX>
impl<const MIN: i16, const MAX: i16> FromStr for RangedI16<MIN, MAX>
type Err = ParseIntError
Sourceimpl<const MIN: i32, const MAX: i32> FromStr for RangedI32<MIN, MAX>
impl<const MIN: i32, const MAX: i32> FromStr for RangedI32<MIN, MAX>
type Err = ParseIntError
Sourceimpl<const MIN: i64, const MAX: i64> FromStr for RangedI64<MIN, MAX>
impl<const MIN: i64, const MAX: i64> FromStr for RangedI64<MIN, MAX>
type Err = ParseIntError
Sourceimpl<const MIN: i128, const MAX: i128> FromStr for RangedI128<MIN, MAX>
impl<const MIN: i128, const MAX: i128> FromStr for RangedI128<MIN, MAX>
type Err = ParseIntError
Sourceimpl<const MIN: isize, const MAX: isize> FromStr for RangedIsize<MIN, MAX>
impl<const MIN: isize, const MAX: isize> FromStr for RangedIsize<MIN, MAX>
type Err = ParseIntError
Sourceimpl<const MIN: u8, const MAX: u8> FromStr for RangedU8<MIN, MAX>
impl<const MIN: u8, const MAX: u8> FromStr for RangedU8<MIN, MAX>
type Err = ParseIntError
Sourceimpl<const MIN: u16, const MAX: u16> FromStr for RangedU16<MIN, MAX>
impl<const MIN: u16, const MAX: u16> FromStr for RangedU16<MIN, MAX>
type Err = ParseIntError
Sourceimpl<const MIN: u32, const MAX: u32> FromStr for RangedU32<MIN, MAX>
impl<const MIN: u32, const MAX: u32> FromStr for RangedU32<MIN, MAX>
type Err = ParseIntError
Sourceimpl<const MIN: u64, const MAX: u64> FromStr for RangedU64<MIN, MAX>
impl<const MIN: u64, const MAX: u64> FromStr for RangedU64<MIN, MAX>
type Err = ParseIntError
Sourceimpl<const MIN: u128, const MAX: u128> FromStr for RangedU128<MIN, MAX>
impl<const MIN: u128, const MAX: u128> FromStr for RangedU128<MIN, MAX>
type Err = ParseIntError
Sourceimpl<const MIN: usize, const MAX: usize> FromStr for RangedUsize<MIN, MAX>
impl<const MIN: usize, const MAX: usize> FromStr for RangedUsize<MIN, MAX>
type Err = ParseIntError
Sourceimpl<const N: usize, SubTag> FromStr for CryptoBytes<N, (PublicTag, SubTag)>
Available on crate feature std only.
impl<const N: usize, SubTag> FromStr for CryptoBytes<N, (PublicTag, SubTag)>
std only.