pub struct RecvError;mpmc_channel)Expand description
An error returned from the recv function on a Receiver.
The recv operation can only fail if the sending half of a
channel (or sync_channel) is disconnected, implying that no further
messages will ever be received.