Receiver

Struct Receiver 

pub struct Receiver<T> { /* private fields */ }
🔬This is a nightly-only experimental API. (oneshot_channel)
The receiving half of a oneshot channel.

Examples

#![feature(oneshot_channel)]
use std::sync::oneshot;
use std::thread;
use std::time::Duration;

let (sender, receiver) = oneshot::channel();

thread::spawn(move || {
    thread::sleep(Duration::from_millis(100));
    sender.send("Hello after delay!").unwrap();
});

println!("Waiting for message...");
println!("{}", receiver.recv().unwrap());

Receiver cannot be sent between threads if it is receiving non-Send types.

ⓘ
let (sender, receiver) = oneshot::channel();

struct NotSend(*mut ());
sender.send(NotSend(ptr::null_mut()));

thread::spawn(move || {
    let reply = receiver.try_recv().unwrap();
});

Implementations

Source

impl<T> Receiver<T>

pub fn recv(self) -> Result<T, RecvError>

🔬This is a nightly-only experimental API. (oneshot_channel)

Receives the value from the sending end, blocking the calling thread until it gets it.

Can only fail if the corresponding Sender<T> has been dropped.

Examples
#![feature(oneshot_channel)]
use std::sync::oneshot;
use std::thread;
use std::time::Duration;

let (tx, rx) = oneshot::channel();

thread::spawn(move || {
    thread::sleep(Duration::from_millis(500));
    tx.send("Done!").unwrap();
});

// This will block until the message arrives.
println!("{}", rx.recv().unwrap());
pub fn try_recv(self) -> Result<T, TryRecvError<T>>

🔬This is a nightly-only experimental API. (oneshot_channel)

Attempts to return a pending value on this receiver without blocking.

Examples
#![feature(oneshot_channel)]
use std::sync::oneshot;
use std::thread;
use std::time::Duration;

let (sender, mut receiver) = oneshot::channel();

thread::spawn(move || {
    thread::sleep(Duration::from_millis(100));
    sender.send(42).unwrap();
});

// Keep trying until we get the message, doing other work in the process.
loop {
    match receiver.try_recv() {
        Ok(value) => {
            assert_eq!(value, 42);
            break;
        }
        Err(oneshot::TryRecvError::Empty(rx)) => {
            // Retake ownership of the receiver.
            receiver = rx;
            do_other_work();
        }
        Err(oneshot::TryRecvError::Disconnected) => panic!("Sender disconnected"),
    }
}
pub fn recv_timeout(self, timeout: Duration) -> Result<T, RecvTimeoutError<T>>

🔬This is a nightly-only experimental API. (oneshot_channel)

Attempts to wait for a value on this receiver, returning an error if the corresponding Sender half of this channel has been dropped, or if it waits more than timeout.

Examples
#![feature(oneshot_channel)]
use std::sync::oneshot;
use std::thread;
use std::time::Duration;

let (sender, receiver) = oneshot::channel();

thread::spawn(move || {
    thread::sleep(Duration::from_millis(500));
    sender.send("Success!").unwrap();
});

// Wait up to 1 second for the message
match receiver.recv_timeout(Duration::from_secs(1)) {
    Ok(msg) => println!("Received: {}", msg),
    Err(oneshot::RecvTimeoutError::Timeout(_)) => println!("Timed out!"),
    Err(oneshot::RecvTimeoutError::Disconnected) => println!("Sender dropped!"),
}
pub fn recv_deadline(self, deadline: Instant) -> Result<T, RecvTimeoutError<T>>

🔬This is a nightly-only experimental API. (oneshot_channel)

Attempts to wait for a value on this receiver, returning an error if the corresponding Sender half of this channel has been dropped, or if deadline is reached.

Examples
#![feature(oneshot_channel)]
use std::sync::oneshot;
use std::thread;
use std::time::{Duration, Instant};

let (sender, receiver) = oneshot::channel();

thread::spawn(move || {
    thread::sleep(Duration::from_millis(100));
    sender.send("Just in time!").unwrap();
});

let deadline = Instant::now() + Duration::from_millis(500);
match receiver.recv_deadline(deadline) {
    Ok(msg) => println!("Received: {}", msg),
    Err(oneshot::RecvTimeoutError::Timeout(_)) => println!("Missed deadline!"),
    Err(oneshot::RecvTimeoutError::Disconnected) => println!("Sender dropped!"),
}