pub struct BlockLength {
pub max: PerDispatchClass<u32>,
pub max_header_size: Option<u32>,
}Expand description
Block length limit configuration.
Fields
max: PerDispatchClass<u32>Maximal total length in bytes for each extrinsic class.
In the worst case, the total block length is going to be:
MAX(max)
max_header_size: Option<u32>Optional maximum header size in bytes.
It is still possible that a header goes above this limit, if the runtime deposits too many digests in the header. However, it is assumed that the runtime restricts the access for depositing digests in the header.
If None, defaults to 20% of max block length.
Implementations
Sourceimpl BlockLength
impl BlockLength
Sourcepub fn max(max: u32) -> Self
👎Deprecated: Use BlockLength::builder().max(value).build() instead. Will be removed after July 2026.
pub fn max(max: u32) -> Self
BlockLength::builder().max(value).build() instead. Will be removed after July 2026.Create new BlockLength with max for every class.
Sourcepub fn max_with_normal_ratio(max: u32, normal: Perbill) -> Self
👎Deprecated: Use BlockLength::builder().normal_ratio(value, ratio).build() instead. Will be removed after July 2026.
pub fn max_with_normal_ratio(max: u32, normal: Perbill) -> Self
BlockLength::builder().normal_ratio(value, ratio).build() instead. Will be removed after July 2026.Create new BlockLength with max for Operational & Mandatory
and normal * max for Normal.
Sourcepub fn builder() -> BlockLengthBuilder
pub fn builder() -> BlockLengthBuilder
Returns a builder to build a BlockLength.
Sourcepub fn max_header_size(&self) -> u32
pub fn max_header_size(&self) -> u32
Returns the maximum header size.